% Copyright 2026 Daniel Nagel
%
% This work may be distributed and/or modified under the
% conditions of the LaTeX Project Public License, either version 1.3c
% of this license or (at your option) any later version.
% The latest version of this license is in
%   http://www.latex-project.org/lppl.txt
% and version 1.3 or later is part of all distributions of LaTeX
% version 2005/12/01 or later.
%
% This work has the LPPL maintenance status `maintained'.
%
% The Current Maintainer of this work is Daniel Nagel
%
% This file was auto-generated by scripts/generate_binding.py
% from @phosphor-icons/web 2.1.2. DO NOT EDIT.
%

% \__phosphoricons_def_icon:nnnnnn {macro} {name} {cp}
%   {{plain-chunk}{plain-slot}} {{duo-chunk}{duo-slot}}
%   {{cp2}{duo-chunk2}{duo-slot2}}   (empty for single-layer duotone)
\__phosphoricons_def_icon:nnnnnn{\ppAcorn}{acorn}{"EB9A}{{4}{246}}{{9}{234}}{{"EB9B}{9}{235}}
\__phosphoricons_def_icon:nnnnnn{\ppActivity}{activity}{"E000}{{0}{0}}{{0}{0}}{{"E001}{0}{1}}
\__phosphoricons_def_icon:nnnnnn{\ppAddressBook}{address-book}{"E6F8}{{3}{103}}{{6}{204}}{{"E6F9}{6}{205}}
\__phosphoricons_def_icon:nnnnnn{\ppAddressBookTabs}{address-book-tabs}{"EE4E}{{5}{215}}{{11}{172}}{{"EE4F}{11}{173}}
\__phosphoricons_def_icon:nnnnnn{\ppAirTrafficControl}{air-traffic-control}{"ECD8}{{5}{78}}{{10}{154}}{{"ECD9}{10}{155}}
\__phosphoricons_def_icon:nnnnnn{\ppAirplane}{airplane}{"E002}{{0}{1}}{{0}{2}}{{"E003}{0}{3}}
\__phosphoricons_def_icon:nnnnnn{\ppAirplaneInFlight}{airplane-in-flight}{"E4FE}{{2}{108}}{{4}{214}}{{"E4FF}{4}{215}}
\__phosphoricons_def_icon:nnnnnn{\ppAirplaneLanding}{airplane-landing}{"E502}{{2}{110}}{{4}{218}}{{"E503}{4}{219}}
\__phosphoricons_def_icon:nnnnnn{\ppAirplaneTakeoff}{airplane-takeoff}{"E504}{{2}{111}}{{4}{220}}{{"E505}{4}{221}}
\__phosphoricons_def_icon:nnnnnn{\ppAirplaneTaxiing}{airplane-taxiing}{"E500}{{2}{109}}{{4}{216}}{{"E501}{4}{217}}
\__phosphoricons_def_icon:nnnnnn{\ppAirplaneTilt}{airplane-tilt}{"E5D6}{{2}{215}}{{5}{172}}{{"E5D7}{5}{173}}
\__phosphoricons_def_icon:nnnnnn{\ppAirplay}{airplay}{"E004}{{0}{2}}{{0}{4}}{{"E005}{0}{5}}
\__phosphoricons_def_icon:nnnnnn{\ppAlarm}{alarm}{"E006}{{0}{3}}{{0}{6}}{{"E007}{0}{7}}
\__phosphoricons_def_icon:nnnnnn{\ppAlien}{alien}{"E8A6}{{4}{9}}{{8}{16}}{{"E8A7}{8}{17}}
\__phosphoricons_def_icon:nnnnnn{\ppAlignBottom}{align-bottom}{"E506}{{2}{112}}{{4}{222}}{{"E507}{4}{223}}
\__phosphoricons_def_icon:nnnnnn{\ppAlignBottomSimple}{align-bottom-simple}{"EB0C}{{4}{187}}{{9}{116}}{{"EB0D}{9}{117}}
\__phosphoricons_def_icon:nnnnnn{\ppAlignCenterHorizontal}{align-center-horizontal}{"E50A}{{2}{114}}{{4}{226}}{{"E50B}{4}{227}}
\__phosphoricons_def_icon:nnnnnn{\ppAlignCenterHorizontalSimple}{align-center-horizontal-simple}{"EB0E}{{4}{188}}{{9}{118}}{{"EB0F}{9}{119}}
\__phosphoricons_def_icon:nnnnnn{\ppAlignCenterVertical}{align-center-vertical}{"E50C}{{2}{115}}{{4}{228}}{{"E50D}{4}{229}}
\__phosphoricons_def_icon:nnnnnn{\ppAlignCenterVerticalSimple}{align-center-vertical-simple}{"EB10}{{4}{189}}{{9}{120}}{{"EB11}{9}{121}}
\__phosphoricons_def_icon:nnnnnn{\ppAlignLeft}{align-left}{"E50E}{{2}{116}}{{4}{230}}{{"E50F}{4}{231}}
\__phosphoricons_def_icon:nnnnnn{\ppAlignLeftSimple}{align-left-simple}{"EAEE}{{4}{173}}{{9}{88}}{{"EAEF}{9}{89}}
\__phosphoricons_def_icon:nnnnnn{\ppAlignRight}{align-right}{"E510}{{2}{117}}{{4}{232}}{{"E511}{4}{233}}
\__phosphoricons_def_icon:nnnnnn{\ppAlignRightSimple}{align-right-simple}{"EB12}{{4}{190}}{{9}{122}}{{"EB13}{9}{123}}
\__phosphoricons_def_icon:nnnnnn{\ppAlignTop}{align-top}{"E512}{{2}{118}}{{4}{234}}{{"E513}{4}{235}}
\__phosphoricons_def_icon:nnnnnn{\ppAlignTopSimple}{align-top-simple}{"EB14}{{4}{191}}{{9}{124}}{{"EB15}{9}{125}}
\__phosphoricons_def_icon:nnnnnn{\ppAmazonLogo}{amazon-logo}{"E96C}{{4}{60}}{{8}{118}}{{"E96D}{8}{119}}
\__phosphoricons_def_icon:nnnnnn{\ppAmbulance}{ambulance}{"E572}{{2}{166}}{{5}{74}}{{"E573}{5}{75}}
\__phosphoricons_def_icon:nnnnnn{\ppAnchor}{anchor}{"E514}{{2}{119}}{{4}{236}}{{"E515}{4}{237}}
\__phosphoricons_def_icon:nnnnnn{\ppAnchorSimple}{anchor-simple}{"E5D8}{{2}{216}}{{5}{174}}{{"E5D9}{5}{175}}
\__phosphoricons_def_icon:nnnnnn{\ppAndroidLogo}{android-logo}{"E008}{{0}{4}}{{0}{8}}{{"E009}{0}{9}}
\__phosphoricons_def_icon:nnnnnn{\ppAngle}{angle}{"E7BC}{{3}{188}}{{7}{118}}{{"E7BD}{7}{119}}
\__phosphoricons_def_icon:nnnnnn{\ppAngularLogo}{angular-logo}{"EB80}{{4}{239}}{{9}{220}}{{"EB81}{9}{221}}
\__phosphoricons_def_icon:nnnnnn{\ppAperture}{aperture}{"E00A}{{0}{5}}{{0}{10}}{{"E00B}{0}{11}}
\__phosphoricons_def_icon:nnnnnn{\ppAppStoreLogo}{app-store-logo}{"E974}{{4}{61}}{{8}{120}}{{"E975}{8}{121}}
\__phosphoricons_def_icon:nnnnnn{\ppAppWindow}{app-window}{"E5DA}{{2}{217}}{{5}{176}}{{"E5DB}{5}{177}}
\__phosphoricons_def_icon:nnnnnn{\ppAppleLogo}{apple-logo}{"E516}{{2}{120}}{{4}{238}}{{"E517}{4}{239}}
\__phosphoricons_def_icon:nnnnnn{\ppApplePodcastsLogo}{apple-podcasts-logo}{"EB96}{{4}{244}}{{9}{230}}{{"EB97}{9}{231}}
\__phosphoricons_def_icon:nnnnnn{\ppApproximateEquals}{approximate-equals}{"EDAA}{{5}{154}}{{11}{50}}{{"EDAB}{11}{51}}
\__phosphoricons_def_icon:nnnnnn{\ppArchive}{archive}{"E00C}{{0}{6}}{{0}{12}}{{"E00D}{0}{13}}
\__phosphoricons_def_icon:nnnnnn{\ppArchiveBox}{archive-box}{"E00E}{{0}{7}}{{0}{14}}{{"E00F}{0}{15}}
\__phosphoricons_def_icon:nnnnnn{\ppArchiveTray}{archive-tray}{"E010}{{0}{8}}{{0}{16}}{{"E011}{0}{17}}
\__phosphoricons_def_icon:nnnnnn{\ppArmchair}{armchair}{"E012}{{0}{9}}{{0}{18}}{{"E013}{0}{19}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowArcLeft}{arrow-arc-left}{"E014}{{0}{10}}{{0}{20}}{{"E015}{0}{21}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowArcRight}{arrow-arc-right}{"E016}{{0}{11}}{{0}{22}}{{"E017}{0}{23}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowBendDoubleUpLeft}{arrow-bend-double-up-left}{"E03A}{{0}{29}}{{0}{58}}{{"E03B}{0}{59}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowBendDoubleUpRight}{arrow-bend-double-up-right}{"E03C}{{0}{30}}{{0}{60}}{{"E03D}{0}{61}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowBendDownLeft}{arrow-bend-down-left}{"E018}{{0}{12}}{{0}{24}}{{"E019}{0}{25}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowBendDownRight}{arrow-bend-down-right}{"E01A}{{0}{13}}{{0}{26}}{{"E01B}{0}{27}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowBendLeftDown}{arrow-bend-left-down}{"E01C}{{0}{14}}{{0}{28}}{{"E01D}{0}{29}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowBendLeftUp}{arrow-bend-left-up}{"E01E}{{0}{15}}{{0}{30}}{{"E01F}{0}{31}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowBendRightDown}{arrow-bend-right-down}{"E020}{{0}{16}}{{0}{32}}{{"E021}{0}{33}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowBendRightUp}{arrow-bend-right-up}{"E022}{{0}{17}}{{0}{34}}{{"E023}{0}{35}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowBendUpLeft}{arrow-bend-up-left}{"E024}{{0}{18}}{{0}{36}}{{"E025}{0}{37}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowBendUpRight}{arrow-bend-up-right}{"E026}{{0}{19}}{{0}{38}}{{"E027}{0}{39}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowCircleDown}{arrow-circle-down}{"E028}{{0}{20}}{{0}{40}}{{"E029}{0}{41}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowCircleDownLeft}{arrow-circle-down-left}{"E02A}{{0}{21}}{{0}{42}}{{"E02B}{0}{43}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowCircleDownRight}{arrow-circle-down-right}{"E02C}{{0}{22}}{{0}{44}}{{"E02D}{0}{45}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowCircleLeft}{arrow-circle-left}{"E05A}{{0}{45}}{{0}{90}}{{"E05B}{0}{91}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowCircleRight}{arrow-circle-right}{"E02E}{{0}{23}}{{0}{46}}{{"E02F}{0}{47}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowCircleUp}{arrow-circle-up}{"E030}{{0}{24}}{{0}{48}}{{"E031}{0}{49}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowCircleUpLeft}{arrow-circle-up-left}{"E032}{{0}{25}}{{0}{50}}{{"E033}{0}{51}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowCircleUpRight}{arrow-circle-up-right}{"E034}{{0}{26}}{{0}{52}}{{"E035}{0}{53}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowClockwise}{arrow-clockwise}{"E036}{{0}{27}}{{0}{54}}{{"E037}{0}{55}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowCounterClockwise}{arrow-counter-clockwise}{"E038}{{0}{28}}{{0}{56}}{{"E039}{0}{57}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowDown}{arrow-down}{"E03E}{{0}{31}}{{0}{62}}{{"E03F}{0}{63}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowDownLeft}{arrow-down-left}{"E040}{{0}{32}}{{0}{64}}{{"E041}{0}{65}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowDownRight}{arrow-down-right}{"E042}{{0}{33}}{{0}{66}}{{"E043}{0}{67}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowElbowDownLeft}{arrow-elbow-down-left}{"E044}{{0}{34}}{{0}{68}}{{"E045}{0}{69}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowElbowDownRight}{arrow-elbow-down-right}{"E046}{{0}{35}}{{0}{70}}{{"E047}{0}{71}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowElbowLeft}{arrow-elbow-left}{"E048}{{0}{36}}{{0}{72}}{{"E049}{0}{73}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowElbowLeftDown}{arrow-elbow-left-down}{"E04A}{{0}{37}}{{0}{74}}{{"E04B}{0}{75}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowElbowLeftUp}{arrow-elbow-left-up}{"E04C}{{0}{38}}{{0}{76}}{{"E04D}{0}{77}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowElbowRight}{arrow-elbow-right}{"E04E}{{0}{39}}{{0}{78}}{{"E04F}{0}{79}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowElbowRightDown}{arrow-elbow-right-down}{"E050}{{0}{40}}{{0}{80}}{{"E051}{0}{81}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowElbowRightUp}{arrow-elbow-right-up}{"E052}{{0}{41}}{{0}{82}}{{"E053}{0}{83}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowElbowUpLeft}{arrow-elbow-up-left}{"E054}{{0}{42}}{{0}{84}}{{"E055}{0}{85}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowElbowUpRight}{arrow-elbow-up-right}{"E056}{{0}{43}}{{0}{86}}{{"E057}{0}{87}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowFatDown}{arrow-fat-down}{"E518}{{2}{121}}{{4}{240}}{{"E519}{4}{241}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowFatLeft}{arrow-fat-left}{"E51A}{{2}{122}}{{4}{242}}{{"E51B}{4}{243}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowFatLineDown}{arrow-fat-line-down}{"E51C}{{2}{123}}{{4}{244}}{{"E51D}{4}{245}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowFatLineLeft}{arrow-fat-line-left}{"E51E}{{2}{124}}{{4}{246}}{{"E51F}{4}{247}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowFatLineRight}{arrow-fat-line-right}{"E520}{{2}{125}}{{4}{248}}{{"E521}{4}{249}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowFatLineUp}{arrow-fat-line-up}{"E522}{{2}{126}}{{4}{250}}{{"E523}{4}{251}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowFatLinesDown}{arrow-fat-lines-down}{"E524}{{2}{127}}{{4}{252}}{{"E525}{4}{253}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowFatLinesLeft}{arrow-fat-lines-left}{"E526}{{2}{128}}{{4}{254}}{{"E527}{4}{255}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowFatLinesRight}{arrow-fat-lines-right}{"E528}{{2}{129}}{{5}{0}}{{"E529}{5}{1}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowFatLinesUp}{arrow-fat-lines-up}{"E52A}{{2}{130}}{{5}{2}}{{"E52B}{5}{3}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowFatRight}{arrow-fat-right}{"E52C}{{2}{131}}{{5}{4}}{{"E52D}{5}{5}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowFatUp}{arrow-fat-up}{"E52E}{{2}{132}}{{5}{6}}{{"E52F}{5}{7}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowLeft}{arrow-left}{"E058}{{0}{44}}{{0}{88}}{{"E059}{0}{89}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowLineDown}{arrow-line-down}{"E05C}{{0}{46}}{{0}{92}}{{"E05D}{0}{93}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowLineDownLeft}{arrow-line-down-left}{"E05E}{{0}{47}}{{0}{94}}{{"E05F}{0}{95}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowLineDownRight}{arrow-line-down-right}{"E060}{{0}{48}}{{0}{96}}{{"E061}{0}{97}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowLineLeft}{arrow-line-left}{"E062}{{0}{49}}{{0}{98}}{{"E063}{0}{99}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowLineRight}{arrow-line-right}{"E064}{{0}{50}}{{0}{100}}{{"E065}{0}{101}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowLineUp}{arrow-line-up}{"E066}{{0}{51}}{{0}{102}}{{"E067}{0}{103}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowLineUpLeft}{arrow-line-up-left}{"E068}{{0}{52}}{{0}{104}}{{"E069}{0}{105}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowLineUpRight}{arrow-line-up-right}{"E06A}{{0}{53}}{{0}{106}}{{"E06B}{0}{107}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowRight}{arrow-right}{"E06C}{{0}{54}}{{0}{108}}{{"E06D}{0}{109}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowSquareDown}{arrow-square-down}{"E06E}{{0}{55}}{{0}{110}}{{"E06F}{0}{111}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowSquareDownLeft}{arrow-square-down-left}{"E070}{{0}{56}}{{0}{112}}{{"E071}{0}{113}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowSquareDownRight}{arrow-square-down-right}{"E072}{{0}{57}}{{0}{114}}{{"E073}{0}{115}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowSquareIn}{arrow-square-in}{"E5DC}{{2}{218}}{{5}{178}}{{"E5DD}{5}{179}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowSquareLeft}{arrow-square-left}{"E074}{{0}{58}}{{0}{116}}{{"E075}{0}{117}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowSquareOut}{arrow-square-out}{"E5DE}{{2}{219}}{{5}{180}}{{"E5DF}{5}{181}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowSquareRight}{arrow-square-right}{"E076}{{0}{59}}{{0}{118}}{{"E077}{0}{119}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowSquareUp}{arrow-square-up}{"E078}{{0}{60}}{{0}{120}}{{"E079}{0}{121}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowSquareUpLeft}{arrow-square-up-left}{"E07A}{{0}{61}}{{0}{122}}{{"E07B}{0}{123}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowSquareUpRight}{arrow-square-up-right}{"E07C}{{0}{62}}{{0}{124}}{{"E07D}{0}{125}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowUDownLeft}{arrow-u-down-left}{"E07E}{{0}{63}}{{0}{126}}{{"E07F}{0}{127}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowUDownRight}{arrow-u-down-right}{"E080}{{0}{64}}{{0}{128}}{{"E081}{0}{129}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowULeftDown}{arrow-u-left-down}{"E082}{{0}{65}}{{0}{130}}{{"E083}{0}{131}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowULeftUp}{arrow-u-left-up}{"E084}{{0}{66}}{{0}{132}}{{"E085}{0}{133}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowURightDown}{arrow-u-right-down}{"E086}{{0}{67}}{{0}{134}}{{"E087}{0}{135}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowURightUp}{arrow-u-right-up}{"E088}{{0}{68}}{{0}{136}}{{"E089}{0}{137}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowUUpLeft}{arrow-u-up-left}{"E08A}{{0}{69}}{{0}{138}}{{"E08B}{0}{139}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowUUpRight}{arrow-u-up-right}{"E08C}{{0}{70}}{{0}{140}}{{"E08D}{0}{141}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowUp}{arrow-up}{"E08E}{{0}{71}}{{0}{142}}{{"E08F}{0}{143}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowUpLeft}{arrow-up-left}{"E090}{{0}{72}}{{0}{144}}{{"E091}{0}{145}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowUpRight}{arrow-up-right}{"E092}{{0}{73}}{{0}{146}}{{"E093}{0}{147}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowsClockwise}{arrows-clockwise}{"E094}{{0}{74}}{{0}{148}}{{"E095}{0}{149}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowsCounterClockwise}{arrows-counter-clockwise}{"E096}{{0}{75}}{{0}{150}}{{"E097}{0}{151}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowsDownUp}{arrows-down-up}{"E098}{{0}{76}}{{0}{152}}{{"E099}{0}{153}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowsHorizontal}{arrows-horizontal}{"EB06}{{4}{184}}{{9}{110}}{{"EB07}{9}{111}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowsIn}{arrows-in}{"E09A}{{0}{77}}{{0}{154}}{{"E09B}{0}{155}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowsInCardinal}{arrows-in-cardinal}{"E09C}{{0}{78}}{{0}{156}}{{"E09D}{0}{157}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowsInLineHorizontal}{arrows-in-line-horizontal}{"E530}{{2}{133}}{{5}{8}}{{"E531}{5}{9}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowsInLineVertical}{arrows-in-line-vertical}{"E532}{{2}{134}}{{5}{10}}{{"E533}{5}{11}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowsInSimple}{arrows-in-simple}{"E09E}{{0}{79}}{{0}{158}}{{"E09F}{0}{159}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowsLeftRight}{arrows-left-right}{"E0A0}{{0}{80}}{{0}{160}}{{"E0A1}{0}{161}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowsMerge}{arrows-merge}{"ED3E}{{5}{112}}{{10}{222}}{{"ED3F}{10}{223}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowsOut}{arrows-out}{"E0A2}{{0}{81}}{{0}{162}}{{"E0A3}{0}{163}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowsOutCardinal}{arrows-out-cardinal}{"E0A4}{{0}{82}}{{0}{164}}{{"E0A5}{0}{165}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowsOutLineHorizontal}{arrows-out-line-horizontal}{"E534}{{2}{135}}{{5}{12}}{{"E535}{5}{13}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowsOutLineVertical}{arrows-out-line-vertical}{"E536}{{2}{136}}{{5}{14}}{{"E537}{5}{15}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowsOutSimple}{arrows-out-simple}{"E0A6}{{0}{83}}{{0}{166}}{{"E0A7}{0}{167}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowsSplit}{arrows-split}{"ED3C}{{5}{111}}{{10}{220}}{{"ED3D}{10}{221}}
\__phosphoricons_def_icon:nnnnnn{\ppArrowsVertical}{arrows-vertical}{"EB04}{{4}{183}}{{9}{108}}{{"EB05}{9}{109}}
\__phosphoricons_def_icon:nnnnnn{\ppArticle}{article}{"E0A8}{{0}{84}}{{0}{168}}{{"E0A9}{0}{169}}
\__phosphoricons_def_icon:nnnnnn{\ppArticleMedium}{article-medium}{"E5E0}{{2}{220}}{{5}{182}}{{"E5E1}{5}{183}}
\__phosphoricons_def_icon:nnnnnn{\ppArticleNyTimes}{article-ny-times}{"E5E2}{{2}{221}}{{5}{184}}{{"E5E3}{5}{185}}
\__phosphoricons_def_icon:nnnnnn{\ppAsclepius}{asclepius}{"EE34}{{5}{202}}{{11}{146}}{{"EE35}{11}{147}}
\__phosphoricons_def_icon:nnnnnn{\ppAsterisk}{asterisk}{"E0AA}{{0}{85}}{{0}{170}}{{"E0AB}{0}{171}}
\__phosphoricons_def_icon:nnnnnn{\ppAsteriskSimple}{asterisk-simple}{"E832}{{3}{235}}{{7}{212}}{{"E833}{7}{213}}
\__phosphoricons_def_icon:nnnnnn{\ppAt}{at}{"E0AC}{{0}{86}}{{0}{172}}{{"E0AD}{0}{173}}
\__phosphoricons_def_icon:nnnnnn{\ppAtom}{atom}{"E5E4}{{2}{222}}{{5}{186}}{{"E5E5}{5}{187}}
\__phosphoricons_def_icon:nnnnnn{\ppAvocado}{avocado}{"EE04}{{5}{190}}{{11}{122}}{{"EE05}{11}{123}}
\__phosphoricons_def_icon:nnnnnn{\ppAxe}{axe}{"E9FC}{{4}{94}}{{8}{186}}{{"E9FD}{8}{187}}
\__phosphoricons_def_icon:nnnnnn{\ppBaby}{baby}{"E774}{{3}{160}}{{7}{62}}{{"E775}{7}{63}}
\__phosphoricons_def_icon:nnnnnn{\ppBabyCarriage}{baby-carriage}{"E818}{{3}{225}}{{7}{192}}{{"E819}{7}{193}}
\__phosphoricons_def_icon:nnnnnn{\ppBackpack}{backpack}{"E922}{{4}{43}}{{8}{84}}{{"E923}{8}{85}}
\__phosphoricons_def_icon:nnnnnn{\ppBackspace}{backspace}{"E0AE}{{0}{87}}{{0}{174}}{{"E0AF}{0}{175}}
\__phosphoricons_def_icon:nnnnnn{\ppBag}{bag}{"E0B0}{{0}{88}}{{0}{176}}{{"E0B1}{0}{177}}
\__phosphoricons_def_icon:nnnnnn{\ppBagSimple}{bag-simple}{"E5E6}{{2}{223}}{{5}{188}}{{"E5E7}{5}{189}}
\__phosphoricons_def_icon:nnnnnn{\ppBalloon}{balloon}{"E76C}{{3}{158}}{{7}{58}}{{"E76D}{7}{59}}
\__phosphoricons_def_icon:nnnnnn{\ppBandaids}{bandaids}{"E0B2}{{0}{89}}{{0}{178}}{{"E0B3}{0}{179}}
\__phosphoricons_def_icon:nnnnnn{\ppBank}{bank}{"E0B4}{{0}{90}}{{0}{180}}{{"E0B5}{0}{181}}
\__phosphoricons_def_icon:nnnnnn{\ppBarbell}{barbell}{"E0B6}{{0}{91}}{{0}{182}}{{"E0B7}{0}{183}}
\__phosphoricons_def_icon:nnnnnn{\ppBarcode}{barcode}{"E0B8}{{0}{92}}{{0}{184}}{{"E0B9}{0}{185}}
\__phosphoricons_def_icon:nnnnnn{\ppBarn}{barn}{"EC72}{{5}{39}}{{10}{76}}{{"EC73}{10}{77}}
\__phosphoricons_def_icon:nnnnnn{\ppBarricade}{barricade}{"E948}{{4}{47}}{{8}{92}}{{"E949}{8}{93}}
\__phosphoricons_def_icon:nnnnnn{\ppBaseball}{baseball}{"E71A}{{3}{120}}{{6}{238}}{{"E71B}{6}{239}}
\__phosphoricons_def_icon:nnnnnn{\ppBaseballCap}{baseball-cap}{"EA28}{{4}{108}}{{8}{214}}{{"EA29}{8}{215}}
\__phosphoricons_def_icon:nnnnnn{\ppBaseballHelmet}{baseball-helmet}{"EE4A}{{5}{213}}{{11}{168}}{{"EE4B}{11}{169}}
\__phosphoricons_def_icon:nnnnnn{\ppBasket}{basket}{"E964}{{4}{58}}{{8}{114}}{{"E965}{8}{115}}
\__phosphoricons_def_icon:nnnnnn{\ppBasketball}{basketball}{"E724}{{3}{125}}{{6}{248}}{{"E725}{6}{249}}
\__phosphoricons_def_icon:nnnnnn{\ppBathtub}{bathtub}{"E81E}{{3}{228}}{{7}{198}}{{"E81F}{7}{199}}
\__phosphoricons_def_icon:nnnnnn{\ppBatteryCharging}{battery-charging}{"E0BA}{{0}{93}}{{0}{186}}{{"E0BB}{0}{187}}
\__phosphoricons_def_icon:nnnnnn{\ppBatteryChargingVertical}{battery-charging-vertical}{"E0BC}{{0}{94}}{{0}{188}}{{"E0BD}{0}{189}}
\__phosphoricons_def_icon:nnnnnn{\ppBatteryEmpty}{battery-empty}{"E0BE}{{0}{95}}{{0}{190}}{{"E0BF}{0}{191}}
\__phosphoricons_def_icon:nnnnnn{\ppBatteryFull}{battery-full}{"E0C0}{{0}{96}}{{0}{192}}{{"E0C1}{0}{193}}
\__phosphoricons_def_icon:nnnnnn{\ppBatteryHigh}{battery-high}{"E0C2}{{0}{97}}{{0}{194}}{{"E0C3}{0}{195}}
\__phosphoricons_def_icon:nnnnnn{\ppBatteryLow}{battery-low}{"E0C4}{{0}{98}}{{0}{196}}{{"E0C5}{0}{197}}
\__phosphoricons_def_icon:nnnnnn{\ppBatteryMedium}{battery-medium}{"E0C6}{{0}{99}}{{0}{198}}{{"E0C7}{0}{199}}
\__phosphoricons_def_icon:nnnnnn{\ppBatteryPlus}{battery-plus}{"E808}{{3}{218}}{{7}{178}}{{"E809}{7}{179}}
\__phosphoricons_def_icon:nnnnnn{\ppBatteryPlusVertical}{battery-plus-vertical}{"EC50}{{5}{27}}{{10}{52}}{{"EC51}{10}{53}}
\__phosphoricons_def_icon:nnnnnn{\ppBatteryVerticalEmpty}{battery-vertical-empty}{"E7C6}{{3}{193}}{{7}{128}}{{"E7C7}{7}{129}}
\__phosphoricons_def_icon:nnnnnn{\ppBatteryVerticalFull}{battery-vertical-full}{"E7C4}{{3}{192}}{{7}{126}}{{"E7C5}{7}{127}}
\__phosphoricons_def_icon:nnnnnn{\ppBatteryVerticalHigh}{battery-vertical-high}{"E7C2}{{3}{191}}{{7}{124}}{{"E7C3}{7}{125}}
\__phosphoricons_def_icon:nnnnnn{\ppBatteryVerticalLow}{battery-vertical-low}{"E7BE}{{3}{189}}{{7}{120}}{{"E7BF}{7}{121}}
\__phosphoricons_def_icon:nnnnnn{\ppBatteryVerticalMedium}{battery-vertical-medium}{"E7C0}{{3}{190}}{{7}{122}}{{"E7C1}{7}{123}}
\__phosphoricons_def_icon:nnnnnn{\ppBatteryWarning}{battery-warning}{"E0C8}{{0}{100}}{{0}{200}}{{"E0C9}{0}{201}}
\__phosphoricons_def_icon:nnnnnn{\ppBatteryWarningVertical}{battery-warning-vertical}{"E0CA}{{0}{101}}{{0}{202}}{{"E0CB}{0}{203}}
\__phosphoricons_def_icon:nnnnnn{\ppBeachBall}{beach-ball}{"ED24}{{5}{102}}{{10}{202}}{{"ED25}{10}{203}}
\__phosphoricons_def_icon:nnnnnn{\ppBeanie}{beanie}{"EA2A}{{4}{109}}{{8}{216}}{{"EA2B}{8}{217}}
\__phosphoricons_def_icon:nnnnnn{\ppBed}{bed}{"E0CC}{{0}{102}}{{0}{204}}{{"E0CD}{0}{205}}
\__phosphoricons_def_icon:nnnnnn{\ppBeerBottle}{beer-bottle}{"E7B0}{{3}{182}}{{7}{106}}{{"E7B1}{7}{107}}
\__phosphoricons_def_icon:nnnnnn{\ppBeerStein}{beer-stein}{"EB62}{{4}{230}}{{9}{202}}{{"EB63}{9}{203}}
\__phosphoricons_def_icon:nnnnnn{\ppBehanceLogo}{behance-logo}{"E7F4}{{3}{210}}{{7}{162}}{{"E7F5}{7}{163}}
\__phosphoricons_def_icon:nnnnnn{\ppBell}{bell}{"E0CE}{{0}{103}}{{0}{206}}{{"E0CF}{0}{207}}
\__phosphoricons_def_icon:nnnnnn{\ppBellRinging}{bell-ringing}{"E5E8}{{2}{224}}{{5}{190}}{{"E5E9}{5}{191}}
\__phosphoricons_def_icon:nnnnnn{\ppBellSimple}{bell-simple}{"E0D0}{{0}{104}}{{0}{208}}{{"E0D1}{0}{209}}
\__phosphoricons_def_icon:nnnnnn{\ppBellSimpleRinging}{bell-simple-ringing}{"E5EA}{{2}{225}}{{5}{192}}{{"E5EB}{5}{193}}
\__phosphoricons_def_icon:nnnnnn{\ppBellSimpleSlash}{bell-simple-slash}{"E0D2}{{0}{105}}{{0}{210}}{{"E0D3}{0}{211}}
\__phosphoricons_def_icon:nnnnnn{\ppBellSimpleZ}{bell-simple-z}{"E5EC}{{2}{226}}{{5}{194}}{{"E5ED}{5}{195}}
\__phosphoricons_def_icon:nnnnnn{\ppBellSlash}{bell-slash}{"E0D4}{{0}{106}}{{0}{212}}{{"E0D5}{0}{213}}
\__phosphoricons_def_icon:nnnnnn{\ppBellZ}{bell-z}{"E5EE}{{2}{227}}{{5}{196}}{{"E5EF}{5}{197}}
\__phosphoricons_def_icon:nnnnnn{\ppBelt}{belt}{"EA2C}{{4}{110}}{{8}{218}}{{"EA2D}{8}{219}}
\__phosphoricons_def_icon:nnnnnn{\ppBezierCurve}{bezier-curve}{"EB00}{{4}{181}}{{9}{104}}{{"EB01}{9}{105}}
\__phosphoricons_def_icon:nnnnnn{\ppBicycle}{bicycle}{"E0D6}{{0}{107}}{{0}{214}}{{"E0D7}{0}{215}}
\__phosphoricons_def_icon:nnnnnn{\ppBinary}{binary}{"EE60}{{5}{224}}{{11}{190}}{{"EE61}{11}{191}}
\__phosphoricons_def_icon:nnnnnn{\ppBinoculars}{binoculars}{"EA64}{{4}{128}}{{8}{254}}{{"EA65}{8}{255}}
\__phosphoricons_def_icon:nnnnnn{\ppBiohazard}{biohazard}{"E9E0}{{4}{83}}{{8}{164}}{{"E9E1}{8}{165}}
\__phosphoricons_def_icon:nnnnnn{\ppBird}{bird}{"E72C}{{3}{129}}{{7}{0}}{{"E72D}{7}{1}}
\__phosphoricons_def_icon:nnnnnn{\ppBlueprint}{blueprint}{"EDA0}{{5}{149}}{{11}{40}}{{"EDA1}{11}{41}}
\__phosphoricons_def_icon:nnnnnn{\ppBluetooth}{bluetooth}{"E0DA}{{0}{108}}{{0}{216}}{{"E0DB}{0}{217}}
\__phosphoricons_def_icon:nnnnnn{\ppBluetoothConnected}{bluetooth-connected}{"E0DC}{{0}{109}}{{0}{218}}{{"E0DD}{0}{219}}
\__phosphoricons_def_icon:nnnnnn{\ppBluetoothSlash}{bluetooth-slash}{"E0DE}{{0}{110}}{{0}{220}}{{"E0DF}{0}{221}}
\__phosphoricons_def_icon:nnnnnn{\ppBluetoothX}{bluetooth-x}{"E0E0}{{0}{111}}{{0}{222}}{{"E0E1}{0}{223}}
\__phosphoricons_def_icon:nnnnnn{\ppBoat}{boat}{"E786}{{3}{166}}{{7}{74}}{{"E787}{7}{75}}
\__phosphoricons_def_icon:nnnnnn{\ppBomb}{bomb}{"EE0A}{{5}{192}}{{11}{126}}{{"EE0B}{11}{127}}
\__phosphoricons_def_icon:nnnnnn{\ppBone}{bone}{"E7F2}{{3}{209}}{{7}{160}}{{"E7F3}{7}{161}}
\__phosphoricons_def_icon:nnnnnn{\ppBook}{book}{"E0E2}{{0}{112}}{{0}{224}}{{"E0E3}{0}{225}}
\__phosphoricons_def_icon:nnnnnn{\ppBookBookmark}{book-bookmark}{"E0E4}{{0}{113}}{{0}{226}}{{"E0E5}{0}{227}}
\__phosphoricons_def_icon:nnnnnn{\ppBookOpen}{book-open}{"E0E6}{{0}{114}}{{0}{228}}{{"E0E7}{0}{229}}
\__phosphoricons_def_icon:nnnnnn{\ppBookOpenText}{book-open-text}{"E8F2}{{4}{32}}{{8}{62}}{{"E8F3}{8}{63}}
\__phosphoricons_def_icon:nnnnnn{\ppBookOpenUser}{book-open-user}{"EDE0}{{5}{179}}{{11}{100}}{{"EDE1}{11}{101}}
\__phosphoricons_def_icon:nnnnnn{\ppBookmark}{bookmark}{"E0E8}{{0}{115}}{{0}{230}}{{"E0E9}{0}{231}}
\__phosphoricons_def_icon:nnnnnn{\ppBookmarkSimple}{bookmark-simple}{"E0EA}{{0}{116}}{{0}{232}}{{"E0EB}{0}{233}}
\__phosphoricons_def_icon:nnnnnn{\ppBookmarks}{bookmarks}{"E0EC}{{0}{117}}{{0}{234}}{{"E0ED}{0}{235}}
\__phosphoricons_def_icon:nnnnnn{\ppBookmarksSimple}{bookmarks-simple}{"E5F0}{{2}{228}}{{5}{198}}{{"E5F1}{5}{199}}
\__phosphoricons_def_icon:nnnnnn{\ppBooks}{books}{"E758}{{3}{149}}{{7}{40}}{{"E759}{7}{41}}
\__phosphoricons_def_icon:nnnnnn{\ppBoot}{boot}{"ECCA}{{5}{73}}{{10}{144}}{{"ECCB}{10}{145}}
\__phosphoricons_def_icon:nnnnnn{\ppBoules}{boules}{"E722}{{3}{124}}{{6}{246}}{{"E723}{6}{247}}
\__phosphoricons_def_icon:nnnnnn{\ppBoundingBox}{bounding-box}{"E6CE}{{3}{82}}{{6}{162}}{{"E6CF}{6}{163}}
\__phosphoricons_def_icon:nnnnnn{\ppBowlFood}{bowl-food}{"EAA4}{{4}{152}}{{9}{46}}{{"EAA5}{9}{47}}
\__phosphoricons_def_icon:nnnnnn{\ppBowlSteam}{bowl-steam}{"E8E4}{{4}{28}}{{8}{54}}{{"E8E5}{8}{55}}
\__phosphoricons_def_icon:nnnnnn{\ppBowlingBall}{bowling-ball}{"EA34}{{4}{112}}{{8}{222}}{{"EA35}{8}{223}}
\__phosphoricons_def_icon:nnnnnn{\ppBoxArrowDown}{box-arrow-down}{"E00E}{{0}{7}}{{0}{14}}{{"E00F}{0}{15}}
\__phosphoricons_def_icon:nnnnnn{\ppBoxArrowUp}{box-arrow-up}{"EE54}{{5}{218}}{{11}{178}}{{"EE55}{11}{179}}
\__phosphoricons_def_icon:nnnnnn{\ppBoxingGlove}{boxing-glove}{"EA36}{{4}{113}}{{8}{224}}{{"EA37}{8}{225}}
\__phosphoricons_def_icon:nnnnnn{\ppBracketsAngle}{brackets-angle}{"E862}{{3}{245}}{{7}{232}}{{"E863}{7}{233}}
\__phosphoricons_def_icon:nnnnnn{\ppBracketsCurly}{brackets-curly}{"E860}{{3}{244}}{{7}{230}}{{"E861}{7}{231}}
\__phosphoricons_def_icon:nnnnnn{\ppBracketsRound}{brackets-round}{"E864}{{3}{246}}{{7}{234}}{{"E865}{7}{235}}
\__phosphoricons_def_icon:nnnnnn{\ppBracketsSquare}{brackets-square}{"E85E}{{3}{243}}{{7}{228}}{{"E85F}{7}{229}}
\__phosphoricons_def_icon:nnnnnn{\ppBrain}{brain}{"E74E}{{3}{144}}{{7}{30}}{{"E74F}{7}{31}}
\__phosphoricons_def_icon:nnnnnn{\ppBrandy}{brandy}{"E6B4}{{3}{69}}{{6}{136}}{{"E6B5}{6}{137}}
\__phosphoricons_def_icon:nnnnnn{\ppBread}{bread}{"E81C}{{3}{227}}{{7}{196}}{{"E81D}{7}{197}}
\__phosphoricons_def_icon:nnnnnn{\ppBridge}{bridge}{"EA68}{{4}{130}}{{9}{2}}{{"EA69}{9}{3}}
\__phosphoricons_def_icon:nnnnnn{\ppBriefcase}{briefcase}{"E0EE}{{0}{118}}{{0}{236}}{{"E0EF}{0}{237}}
\__phosphoricons_def_icon:nnnnnn{\ppBriefcaseMetal}{briefcase-metal}{"E5F2}{{2}{229}}{{5}{200}}{{"E5F3}{5}{201}}
\__phosphoricons_def_icon:nnnnnn{\ppBroadcast}{broadcast}{"E0F2}{{0}{119}}{{0}{238}}{{"E0F3}{0}{239}}
\__phosphoricons_def_icon:nnnnnn{\ppBroom}{broom}{"EC54}{{5}{28}}{{10}{54}}{{"EC55}{10}{55}}
\__phosphoricons_def_icon:nnnnnn{\ppBrowser}{browser}{"E0F4}{{0}{120}}{{0}{240}}{{"E0F5}{0}{241}}
\__phosphoricons_def_icon:nnnnnn{\ppBrowsers}{browsers}{"E0F6}{{0}{121}}{{0}{242}}{{"E0F7}{0}{243}}
\__phosphoricons_def_icon:nnnnnn{\ppBug}{bug}{"E5F4}{{2}{230}}{{5}{202}}{{"E5F5}{5}{203}}
\__phosphoricons_def_icon:nnnnnn{\ppBugBeetle}{bug-beetle}{"E5F6}{{2}{231}}{{5}{204}}{{"E5F7}{5}{205}}
\__phosphoricons_def_icon:nnnnnn{\ppBugDroid}{bug-droid}{"E5F8}{{2}{232}}{{5}{206}}{{"E5F9}{5}{207}}
\__phosphoricons_def_icon:nnnnnn{\ppBuilding}{building}{"E100}{{0}{125}}{{0}{248}}{{"E101}{0}{249}}
\__phosphoricons_def_icon:nnnnnn{\ppBuildingApartment}{building-apartment}{"E0FE}{{0}{123}}{{0}{246}}{{"E103}{0}{251}}
\__phosphoricons_def_icon:nnnnnn{\ppBuildingOffice}{building-office}{"E0FF}{{0}{124}}{{0}{247}}{{"E104}{0}{252}}
\__phosphoricons_def_icon:nnnnnn{\ppBuildings}{buildings}{"E102}{{0}{126}}{{0}{250}}{{"E105}{0}{253}}
\__phosphoricons_def_icon:nnnnnn{\ppBulldozer}{bulldozer}{"EC6C}{{5}{36}}{{10}{70}}{{"EC6D}{10}{71}}
\__phosphoricons_def_icon:nnnnnn{\ppBus}{bus}{"E106}{{0}{127}}{{0}{254}}{{"E107}{0}{255}}
\__phosphoricons_def_icon:nnnnnn{\ppButterfly}{butterfly}{"EA6E}{{4}{132}}{{9}{6}}{{"EA6F}{9}{7}}
\__phosphoricons_def_icon:nnnnnn{\ppCableCar}{cable-car}{"E49C}{{2}{61}}{{4}{121}}{{"E49D}{4}{122}}
\__phosphoricons_def_icon:nnnnnn{\ppCactus}{cactus}{"E918}{{4}{41}}{{8}{80}}{{"E919}{8}{81}}
\__phosphoricons_def_icon:nnnnnn{\ppCaduceus}{caduceus}{"EE34}{{5}{202}}{{11}{146}}{{"EE35}{11}{147}}
\__phosphoricons_def_icon:nnnnnn{\ppCake}{cake}{"E780}{{3}{164}}{{7}{70}}{{"E781}{7}{71}}
\__phosphoricons_def_icon:nnnnnn{\ppCalculator}{calculator}{"E538}{{2}{137}}{{5}{16}}{{"E539}{5}{17}}
\__phosphoricons_def_icon:nnnnnn{\ppCalendar}{calendar}{"E108}{{0}{128}}{{1}{0}}{{"E109}{1}{1}}
\__phosphoricons_def_icon:nnnnnn{\ppCalendarBlank}{calendar-blank}{"E10A}{{0}{129}}{{1}{2}}{{"E10B}{1}{3}}
\__phosphoricons_def_icon:nnnnnn{\ppCalendarCheck}{calendar-check}{"E712}{{3}{116}}{{6}{230}}{{"E713}{6}{231}}
\__phosphoricons_def_icon:nnnnnn{\ppCalendarDot}{calendar-dot}{"E7B2}{{3}{183}}{{7}{108}}{{"E7B3}{7}{109}}
\__phosphoricons_def_icon:nnnnnn{\ppCalendarDots}{calendar-dots}{"E7B4}{{3}{184}}{{7}{110}}{{"E7B5}{7}{111}}
\__phosphoricons_def_icon:nnnnnn{\ppCalendarHeart}{calendar-heart}{"E8B0}{{4}{11}}{{8}{20}}{{"E8B1}{8}{21}}
\__phosphoricons_def_icon:nnnnnn{\ppCalendarMinus}{calendar-minus}{"EA14}{{4}{101}}{{8}{200}}{{"EA15}{8}{201}}
\__phosphoricons_def_icon:nnnnnn{\ppCalendarPlus}{calendar-plus}{"E714}{{3}{117}}{{6}{232}}{{"E715}{6}{233}}
\__phosphoricons_def_icon:nnnnnn{\ppCalendarSlash}{calendar-slash}{"EA12}{{4}{100}}{{8}{198}}{{"EA13}{8}{199}}
\__phosphoricons_def_icon:nnnnnn{\ppCalendarStar}{calendar-star}{"E8B2}{{4}{12}}{{8}{22}}{{"E8B3}{8}{23}}
\__phosphoricons_def_icon:nnnnnn{\ppCalendarX}{calendar-x}{"E10C}{{0}{130}}{{1}{4}}{{"E10D}{1}{5}}
\__phosphoricons_def_icon:nnnnnn{\ppCallBell}{call-bell}{"E7DE}{{3}{202}}{{7}{146}}{{"E7DF}{7}{147}}
\__phosphoricons_def_icon:nnnnnn{\ppCamera}{camera}{"E10E}{{0}{131}}{{1}{6}}{{"E10F}{1}{7}}
\__phosphoricons_def_icon:nnnnnn{\ppCameraPlus}{camera-plus}{"EC58}{{5}{30}}{{10}{58}}{{"EC59}{10}{59}}
\__phosphoricons_def_icon:nnnnnn{\ppCameraRotate}{camera-rotate}{"E7A4}{{3}{179}}{{7}{100}}{{"E7A5}{7}{101}}
\__phosphoricons_def_icon:nnnnnn{\ppCameraSlash}{camera-slash}{"E110}{{0}{132}}{{1}{8}}{{"E111}{1}{9}}
\__phosphoricons_def_icon:nnnnnn{\ppCampfire}{campfire}{"E9D8}{{4}{80}}{{8}{158}}{{"E9D9}{8}{159}}
\__phosphoricons_def_icon:nnnnnn{\ppCar}{car}{"E112}{{0}{133}}{{1}{10}}{{"E113}{1}{11}}
\__phosphoricons_def_icon:nnnnnn{\ppCarBattery}{car-battery}{"EE30}{{5}{200}}{{11}{142}}{{"EE31}{11}{143}}
\__phosphoricons_def_icon:nnnnnn{\ppCarProfile}{car-profile}{"E8CC}{{4}{21}}{{8}{40}}{{"E8CD}{8}{41}}
\__phosphoricons_def_icon:nnnnnn{\ppCarSimple}{car-simple}{"E114}{{0}{134}}{{1}{12}}{{"E115}{1}{13}}
\__phosphoricons_def_icon:nnnnnn{\ppCardholder}{cardholder}{"E5FA}{{2}{233}}{{5}{208}}{{"E5FB}{5}{209}}
\__phosphoricons_def_icon:nnnnnn{\ppCards}{cards}{"E0F8}{{0}{122}}{{0}{244}}{{"E0F9}{0}{245}}
\__phosphoricons_def_icon:nnnnnn{\ppCardsThree}{cards-three}{"EE50}{{5}{216}}{{11}{174}}{{"EE51}{11}{175}}
\__phosphoricons_def_icon:nnnnnn{\ppCaretCircleDoubleDown}{caret-circle-double-down}{"E116}{{0}{135}}{{1}{14}}{{"E117}{1}{15}}
\__phosphoricons_def_icon:nnnnnn{\ppCaretCircleDoubleLeft}{caret-circle-double-left}{"E118}{{0}{136}}{{1}{16}}{{"E119}{1}{17}}
\__phosphoricons_def_icon:nnnnnn{\ppCaretCircleDoubleRight}{caret-circle-double-right}{"E11A}{{0}{137}}{{1}{18}}{{"E11B}{1}{19}}
\__phosphoricons_def_icon:nnnnnn{\ppCaretCircleDoubleUp}{caret-circle-double-up}{"E11C}{{0}{138}}{{1}{20}}{{"E11D}{1}{21}}
\__phosphoricons_def_icon:nnnnnn{\ppCaretCircleDown}{caret-circle-down}{"E11E}{{0}{139}}{{1}{22}}{{"E11F}{1}{23}}
\__phosphoricons_def_icon:nnnnnn{\ppCaretCircleLeft}{caret-circle-left}{"E120}{{0}{140}}{{1}{24}}{{"E121}{1}{25}}
\__phosphoricons_def_icon:nnnnnn{\ppCaretCircleRight}{caret-circle-right}{"E122}{{0}{141}}{{1}{26}}{{"E123}{1}{27}}
\__phosphoricons_def_icon:nnnnnn{\ppCaretCircleUp}{caret-circle-up}{"E124}{{0}{142}}{{1}{28}}{{"E125}{1}{29}}
\__phosphoricons_def_icon:nnnnnn{\ppCaretCircleUpDown}{caret-circle-up-down}{"E13E}{{0}{155}}{{1}{54}}{{"E13F}{1}{55}}
\__phosphoricons_def_icon:nnnnnn{\ppCaretDoubleDown}{caret-double-down}{"E126}{{0}{143}}{{1}{30}}{{"E127}{1}{31}}
\__phosphoricons_def_icon:nnnnnn{\ppCaretDoubleLeft}{caret-double-left}{"E128}{{0}{144}}{{1}{32}}{{"E129}{1}{33}}
\__phosphoricons_def_icon:nnnnnn{\ppCaretDoubleRight}{caret-double-right}{"E12A}{{0}{145}}{{1}{34}}{{"E12B}{1}{35}}
\__phosphoricons_def_icon:nnnnnn{\ppCaretDoubleUp}{caret-double-up}{"E12C}{{0}{146}}{{1}{36}}{{"E12D}{1}{37}}
\__phosphoricons_def_icon:nnnnnn{\ppCaretDown}{caret-down}{"E136}{{0}{151}}{{1}{46}}{{"E137}{1}{47}}
\__phosphoricons_def_icon:nnnnnn{\ppCaretLeft}{caret-left}{"E138}{{0}{152}}{{1}{48}}{{"E139}{1}{49}}
\__phosphoricons_def_icon:nnnnnn{\ppCaretLineDown}{caret-line-down}{"E134}{{0}{150}}{{1}{44}}{{"E135}{1}{45}}
\__phosphoricons_def_icon:nnnnnn{\ppCaretLineLeft}{caret-line-left}{"E132}{{0}{149}}{{1}{42}}{{"E133}{1}{43}}
\__phosphoricons_def_icon:nnnnnn{\ppCaretLineRight}{caret-line-right}{"E130}{{0}{148}}{{1}{40}}{{"E131}{1}{41}}
\__phosphoricons_def_icon:nnnnnn{\ppCaretLineUp}{caret-line-up}{"E12E}{{0}{147}}{{1}{38}}{{"E12F}{1}{39}}
\__phosphoricons_def_icon:nnnnnn{\ppCaretRight}{caret-right}{"E13A}{{0}{153}}{{1}{50}}{{"E13B}{1}{51}}
\__phosphoricons_def_icon:nnnnnn{\ppCaretUp}{caret-up}{"E13C}{{0}{154}}{{1}{52}}{{"E13D}{1}{53}}
\__phosphoricons_def_icon:nnnnnn{\ppCaretUpDown}{caret-up-down}{"E140}{{0}{156}}{{1}{56}}{{"E141}{1}{57}}
\__phosphoricons_def_icon:nnnnnn{\ppCarrot}{carrot}{"ED38}{{5}{109}}{{10}{216}}{{"ED39}{10}{217}}
\__phosphoricons_def_icon:nnnnnn{\ppCashRegister}{cash-register}{"ED80}{{5}{138}}{{11}{18}}{{"ED81}{11}{19}}
\__phosphoricons_def_icon:nnnnnn{\ppCassetteTape}{cassette-tape}{"ED2E}{{5}{104}}{{10}{206}}{{"ED2F}{10}{207}}
\__phosphoricons_def_icon:nnnnnn{\ppCastleTurret}{castle-turret}{"E9D0}{{4}{79}}{{8}{156}}{{"E9D1}{8}{157}}
\__phosphoricons_def_icon:nnnnnn{\ppCat}{cat}{"E748}{{3}{142}}{{7}{26}}{{"E749}{7}{27}}
\__phosphoricons_def_icon:nnnnnn{\ppCellSignalFull}{cell-signal-full}{"E142}{{0}{157}}{{1}{58}}{{"E143}{1}{59}}
\__phosphoricons_def_icon:nnnnnn{\ppCellSignalHigh}{cell-signal-high}{"E144}{{0}{158}}{{1}{60}}{{"E145}{1}{61}}
\__phosphoricons_def_icon:nnnnnn{\ppCellSignalLow}{cell-signal-low}{"E146}{{0}{159}}{{1}{62}}{{"E147}{1}{63}}
\__phosphoricons_def_icon:nnnnnn{\ppCellSignalMedium}{cell-signal-medium}{"E148}{{0}{160}}{{1}{64}}{{"E149}{1}{65}}
\__phosphoricons_def_icon:nnnnnn{\ppCellSignalNone}{cell-signal-none}{"E14A}{{0}{161}}{{1}{66}}{}
\__phosphoricons_def_icon:nnnnnn{\ppCellSignalSlash}{cell-signal-slash}{"E14C}{{0}{162}}{{1}{67}}{{"E14D}{1}{68}}
\__phosphoricons_def_icon:nnnnnn{\ppCellSignalX}{cell-signal-x}{"E14E}{{0}{163}}{{1}{69}}{{"E14F}{1}{70}}
\__phosphoricons_def_icon:nnnnnn{\ppCellTower}{cell-tower}{"EBAA}{{4}{252}}{{9}{246}}{{"EBAB}{9}{247}}
\__phosphoricons_def_icon:nnnnnn{\ppCertificate}{certificate}{"E766}{{3}{156}}{{7}{54}}{{"E767}{7}{55}}
\__phosphoricons_def_icon:nnnnnn{\ppChair}{chair}{"E950}{{4}{50}}{{8}{98}}{{"E951}{8}{99}}
\__phosphoricons_def_icon:nnnnnn{\ppChalkboard}{chalkboard}{"E5FC}{{2}{234}}{{5}{210}}{{"E5FD}{5}{211}}
\__phosphoricons_def_icon:nnnnnn{\ppChalkboardSimple}{chalkboard-simple}{"E5FE}{{2}{235}}{{5}{212}}{{"E5FF}{5}{213}}
\__phosphoricons_def_icon:nnnnnn{\ppChalkboardTeacher}{chalkboard-teacher}{"E600}{{2}{236}}{{5}{214}}{{"E601}{5}{215}}
\__phosphoricons_def_icon:nnnnnn{\ppChampagne}{champagne}{"EACA}{{4}{162}}{{9}{66}}{{"EACB}{9}{67}}
\__phosphoricons_def_icon:nnnnnn{\ppChargingStation}{charging-station}{"E8D0}{{4}{23}}{{8}{44}}{{"E8D1}{8}{45}}
\__phosphoricons_def_icon:nnnnnn{\ppChartBar}{chart-bar}{"E150}{{0}{164}}{{1}{71}}{{"E151}{1}{72}}
\__phosphoricons_def_icon:nnnnnn{\ppChartBarHorizontal}{chart-bar-horizontal}{"E152}{{0}{165}}{{1}{73}}{{"E153}{1}{74}}
\__phosphoricons_def_icon:nnnnnn{\ppChartDonut}{chart-donut}{"EAA6}{{4}{153}}{{9}{48}}{{"EAA7}{9}{49}}
\__phosphoricons_def_icon:nnnnnn{\ppChartLine}{chart-line}{"E154}{{0}{166}}{{1}{75}}{{"E155}{1}{76}}
\__phosphoricons_def_icon:nnnnnn{\ppChartLineDown}{chart-line-down}{"E8B6}{{4}{13}}{{8}{24}}{{"E8B7}{8}{25}}
\__phosphoricons_def_icon:nnnnnn{\ppChartLineUp}{chart-line-up}{"E156}{{0}{167}}{{1}{77}}{{"E157}{1}{78}}
\__phosphoricons_def_icon:nnnnnn{\ppChartPie}{chart-pie}{"E158}{{0}{168}}{{1}{79}}{{"E159}{1}{80}}
\__phosphoricons_def_icon:nnnnnn{\ppChartPieSlice}{chart-pie-slice}{"E15A}{{0}{169}}{{1}{81}}{{"E15B}{1}{82}}
\__phosphoricons_def_icon:nnnnnn{\ppChartPolar}{chart-polar}{"EAA8}{{4}{154}}{{9}{50}}{{"EAA9}{9}{51}}
\__phosphoricons_def_icon:nnnnnn{\ppChartScatter}{chart-scatter}{"EAAC}{{4}{155}}{{9}{52}}{{"EAAD}{9}{53}}
\__phosphoricons_def_icon:nnnnnn{\ppChat}{chat}{"E15C}{{0}{170}}{{1}{83}}{{"E15D}{1}{84}}
\__phosphoricons_def_icon:nnnnnn{\ppChatCentered}{chat-centered}{"E160}{{0}{172}}{{1}{87}}{{"E161}{1}{88}}
\__phosphoricons_def_icon:nnnnnn{\ppChatCenteredDots}{chat-centered-dots}{"E164}{{0}{174}}{{1}{91}}{{"E165}{1}{92}}
\__phosphoricons_def_icon:nnnnnn{\ppChatCenteredSlash}{chat-centered-slash}{"E162}{{0}{173}}{{1}{89}}{{"E163}{1}{90}}
\__phosphoricons_def_icon:nnnnnn{\ppChatCenteredText}{chat-centered-text}{"E166}{{0}{175}}{{1}{93}}{{"E167}{1}{94}}
\__phosphoricons_def_icon:nnnnnn{\ppChatCircle}{chat-circle}{"E168}{{0}{176}}{{1}{95}}{{"E169}{1}{96}}
\__phosphoricons_def_icon:nnnnnn{\ppChatCircleDots}{chat-circle-dots}{"E16C}{{0}{178}}{{1}{99}}{{"E16D}{1}{100}}
\__phosphoricons_def_icon:nnnnnn{\ppChatCircleSlash}{chat-circle-slash}{"E16A}{{0}{177}}{{1}{97}}{{"E16B}{1}{98}}
\__phosphoricons_def_icon:nnnnnn{\ppChatCircleText}{chat-circle-text}{"E16E}{{0}{179}}{{1}{101}}{{"E16F}{1}{102}}
\__phosphoricons_def_icon:nnnnnn{\ppChatDots}{chat-dots}{"E170}{{0}{180}}{{1}{103}}{{"E171}{1}{104}}
\__phosphoricons_def_icon:nnnnnn{\ppChatSlash}{chat-slash}{"E15E}{{0}{171}}{{1}{85}}{{"E15F}{1}{86}}
\__phosphoricons_def_icon:nnnnnn{\ppChatTeardrop}{chat-teardrop}{"E172}{{0}{181}}{{1}{105}}{{"E173}{1}{106}}
\__phosphoricons_def_icon:nnnnnn{\ppChatTeardropDots}{chat-teardrop-dots}{"E176}{{0}{183}}{{1}{109}}{{"E177}{1}{110}}
\__phosphoricons_def_icon:nnnnnn{\ppChatTeardropSlash}{chat-teardrop-slash}{"E174}{{0}{182}}{{1}{107}}{{"E175}{1}{108}}
\__phosphoricons_def_icon:nnnnnn{\ppChatTeardropText}{chat-teardrop-text}{"E178}{{0}{184}}{{1}{111}}{{"E179}{1}{112}}
\__phosphoricons_def_icon:nnnnnn{\ppChatText}{chat-text}{"E17A}{{0}{185}}{{1}{113}}{{"E17B}{1}{114}}
\__phosphoricons_def_icon:nnnnnn{\ppChats}{chats}{"E17C}{{0}{186}}{{1}{115}}{{"E17D}{1}{116}}
\__phosphoricons_def_icon:nnnnnn{\ppChatsCircle}{chats-circle}{"E17E}{{0}{187}}{{1}{117}}{{"E17F}{1}{118}}
\__phosphoricons_def_icon:nnnnnn{\ppChatsTeardrop}{chats-teardrop}{"E180}{{0}{188}}{{1}{119}}{{"E181}{1}{120}}
\__phosphoricons_def_icon:nnnnnn{\ppCheck}{check}{"E182}{{0}{189}}{{1}{121}}{{"E183}{1}{122}}
\__phosphoricons_def_icon:nnnnnn{\ppCheckCircle}{check-circle}{"E184}{{0}{190}}{{1}{123}}{{"E185}{1}{124}}
\__phosphoricons_def_icon:nnnnnn{\ppCheckFat}{check-fat}{"EBA6}{{4}{251}}{{9}{244}}{{"EBA7}{9}{245}}
\__phosphoricons_def_icon:nnnnnn{\ppCheckSquare}{check-square}{"E186}{{0}{191}}{{1}{125}}{{"E187}{1}{126}}
\__phosphoricons_def_icon:nnnnnn{\ppCheckSquareOffset}{check-square-offset}{"E188}{{0}{192}}{{1}{127}}{{"E189}{1}{128}}
\__phosphoricons_def_icon:nnnnnn{\ppCheckerboard}{checkerboard}{"E8C4}{{4}{18}}{{8}{34}}{{"E8C5}{8}{35}}
\__phosphoricons_def_icon:nnnnnn{\ppChecks}{checks}{"E53A}{{2}{138}}{{5}{18}}{{"E53B}{5}{19}}
\__phosphoricons_def_icon:nnnnnn{\ppCheers}{cheers}{"EA4A}{{4}{122}}{{8}{242}}{{"EA4B}{8}{243}}
\__phosphoricons_def_icon:nnnnnn{\ppCheese}{cheese}{"E9FE}{{4}{95}}{{8}{188}}{{"E9FF}{8}{189}}
\__phosphoricons_def_icon:nnnnnn{\ppChefHat}{chef-hat}{"ED8E}{{5}{143}}{{11}{28}}{{"ED8F}{11}{29}}
\__phosphoricons_def_icon:nnnnnn{\ppCherries}{cherries}{"E830}{{3}{234}}{{7}{210}}{{"E831}{7}{211}}
\__phosphoricons_def_icon:nnnnnn{\ppChurch}{church}{"ECEA}{{5}{82}}{{10}{162}}{{"ECEB}{10}{163}}
\__phosphoricons_def_icon:nnnnnn{\ppCigarette}{cigarette}{"ED90}{{5}{144}}{{11}{30}}{{"ED91}{11}{31}}
\__phosphoricons_def_icon:nnnnnn{\ppCigaretteSlash}{cigarette-slash}{"ED92}{{5}{145}}{{11}{32}}{{"ED93}{11}{33}}
\__phosphoricons_def_icon:nnnnnn{\ppCircle}{circle}{"E18A}{{0}{193}}{{1}{129}}{{"E18B}{1}{130}}
\__phosphoricons_def_icon:nnnnnn{\ppCircleDashed}{circle-dashed}{"E602}{{2}{237}}{{5}{216}}{{"E603}{5}{217}}
\__phosphoricons_def_icon:nnnnnn{\ppCircleHalf}{circle-half}{"E18C}{{0}{194}}{{1}{131}}{{"E18D}{1}{132}}
\__phosphoricons_def_icon:nnnnnn{\ppCircleHalfTilt}{circle-half-tilt}{"E18E}{{0}{195}}{{1}{133}}{{"E18F}{1}{134}}
\__phosphoricons_def_icon:nnnnnn{\ppCircleNotch}{circle-notch}{"EB44}{{4}{216}}{{9}{172}}{{"EB45}{9}{173}}
\__phosphoricons_def_icon:nnnnnn{\ppCircleWavy}{circle-wavy}{"E604}{{2}{238}}{{5}{218}}{{"E605}{5}{219}}
\__phosphoricons_def_icon:nnnnnn{\ppCircleWavyCheck}{circle-wavy-check}{"E606}{{2}{239}}{{5}{220}}{{"E607}{5}{221}}
\__phosphoricons_def_icon:nnnnnn{\ppCircleWavyQuestion}{circle-wavy-question}{"E608}{{2}{240}}{{5}{222}}{{"E609}{5}{223}}
\__phosphoricons_def_icon:nnnnnn{\ppCircleWavyWarning}{circle-wavy-warning}{"E60C}{{2}{242}}{{5}{226}}{{"E60D}{5}{227}}
\__phosphoricons_def_icon:nnnnnn{\ppCirclesFour}{circles-four}{"E190}{{0}{196}}{{1}{135}}{{"E191}{1}{136}}
\__phosphoricons_def_icon:nnnnnn{\ppCirclesThree}{circles-three}{"E192}{{0}{197}}{{1}{137}}{{"E193}{1}{138}}
\__phosphoricons_def_icon:nnnnnn{\ppCirclesThreePlus}{circles-three-plus}{"E194}{{0}{198}}{{1}{139}}{{"E195}{1}{140}}
\__phosphoricons_def_icon:nnnnnn{\ppCircuitry}{circuitry}{"E9C2}{{4}{75}}{{8}{148}}{{"E9C3}{8}{149}}
\__phosphoricons_def_icon:nnnnnn{\ppCity}{city}{"EA6A}{{4}{131}}{{9}{4}}{{"EA6B}{9}{5}}
\__phosphoricons_def_icon:nnnnnn{\ppClipboard}{clipboard}{"E196}{{0}{199}}{{1}{141}}{{"E197}{1}{142}}
\__phosphoricons_def_icon:nnnnnn{\ppClipboardText}{clipboard-text}{"E198}{{0}{200}}{{1}{143}}{{"E199}{1}{144}}
\__phosphoricons_def_icon:nnnnnn{\ppClock}{clock}{"E19A}{{0}{201}}{{1}{145}}{{"E19B}{1}{146}}
\__phosphoricons_def_icon:nnnnnn{\ppClockAfternoon}{clock-afternoon}{"E19C}{{0}{202}}{{1}{147}}{{"E19D}{1}{148}}
\__phosphoricons_def_icon:nnnnnn{\ppClockClockwise}{clock-clockwise}{"E19E}{{0}{203}}{{1}{149}}{{"E19F}{1}{150}}
\__phosphoricons_def_icon:nnnnnn{\ppClockCountdown}{clock-countdown}{"ED2C}{{5}{103}}{{10}{204}}{{"ED2D}{10}{205}}
\__phosphoricons_def_icon:nnnnnn{\ppClockCounterClockwise}{clock-counter-clockwise}{"E1A0}{{0}{204}}{{1}{151}}{{"E1A1}{1}{152}}
\__phosphoricons_def_icon:nnnnnn{\ppClockUser}{clock-user}{"EDEC}{{5}{183}}{{11}{108}}{{"EDED}{11}{109}}
\__phosphoricons_def_icon:nnnnnn{\ppClosedCaptioning}{closed-captioning}{"E1A4}{{0}{205}}{{1}{153}}{{"E1A5}{1}{154}}
\__phosphoricons_def_icon:nnnnnn{\ppCloud}{cloud}{"E1AA}{{0}{208}}{{1}{159}}{{"E1AB}{1}{160}}
\__phosphoricons_def_icon:nnnnnn{\ppCloudArrowDown}{cloud-arrow-down}{"E1AC}{{0}{209}}{{1}{161}}{{"E1AD}{1}{162}}
\__phosphoricons_def_icon:nnnnnn{\ppCloudArrowUp}{cloud-arrow-up}{"E1AE}{{0}{210}}{{1}{163}}{{"E1AF}{1}{164}}
\__phosphoricons_def_icon:nnnnnn{\ppCloudCheck}{cloud-check}{"E1B0}{{0}{211}}{{1}{165}}{{"E1B1}{1}{166}}
\__phosphoricons_def_icon:nnnnnn{\ppCloudFog}{cloud-fog}{"E53C}{{2}{139}}{{5}{20}}{{"E53D}{5}{21}}
\__phosphoricons_def_icon:nnnnnn{\ppCloudLightning}{cloud-lightning}{"E1B2}{{0}{212}}{{1}{167}}{{"E1B3}{1}{168}}
\__phosphoricons_def_icon:nnnnnn{\ppCloudMoon}{cloud-moon}{"E53E}{{2}{140}}{{5}{22}}{{"E53F}{5}{23}}
\__phosphoricons_def_icon:nnnnnn{\ppCloudRain}{cloud-rain}{"E1B4}{{0}{213}}{{1}{169}}{{"E1B5}{1}{170}}
\__phosphoricons_def_icon:nnnnnn{\ppCloudSlash}{cloud-slash}{"E1B6}{{0}{214}}{{1}{171}}{{"E1B7}{1}{172}}
\__phosphoricons_def_icon:nnnnnn{\ppCloudSnow}{cloud-snow}{"E1B8}{{0}{215}}{{1}{173}}{{"E1B9}{1}{174}}
\__phosphoricons_def_icon:nnnnnn{\ppCloudSun}{cloud-sun}{"E540}{{2}{141}}{{5}{24}}{{"E541}{5}{25}}
\__phosphoricons_def_icon:nnnnnn{\ppCloudWarning}{cloud-warning}{"EA98}{{4}{146}}{{9}{34}}{{"EA99}{9}{35}}
\__phosphoricons_def_icon:nnnnnn{\ppCloudX}{cloud-x}{"EA96}{{4}{145}}{{9}{32}}{{"EA97}{9}{33}}
\__phosphoricons_def_icon:nnnnnn{\ppClover}{clover}{"EDC8}{{5}{169}}{{11}{80}}{{"EDC9}{11}{81}}
\__phosphoricons_def_icon:nnnnnn{\ppClub}{club}{"E1BA}{{0}{216}}{{1}{175}}{{"E1BB}{1}{176}}
\__phosphoricons_def_icon:nnnnnn{\ppCoatHanger}{coat-hanger}{"E7FE}{{3}{213}}{{7}{168}}{{"E7FF}{7}{169}}
\__phosphoricons_def_icon:nnnnnn{\ppCodaLogo}{coda-logo}{"E7CE}{{3}{196}}{{7}{134}}{{"E7CF}{7}{135}}
\__phosphoricons_def_icon:nnnnnn{\ppCode}{code}{"E1BC}{{0}{217}}{{1}{177}}{{"E1BD}{1}{178}}
\__phosphoricons_def_icon:nnnnnn{\ppCodeBlock}{code-block}{"EAFE}{{4}{180}}{{9}{102}}{{"EAFF}{9}{103}}
\__phosphoricons_def_icon:nnnnnn{\ppCodeSimple}{code-simple}{"E1BE}{{0}{218}}{{1}{179}}{{"E1BF}{1}{180}}
\__phosphoricons_def_icon:nnnnnn{\ppCodepenLogo}{codepen-logo}{"E978}{{4}{63}}{{8}{124}}{{"E979}{8}{125}}
\__phosphoricons_def_icon:nnnnnn{\ppCodesandboxLogo}{codesandbox-logo}{"EA06}{{4}{97}}{{8}{192}}{{"EA07}{8}{193}}
\__phosphoricons_def_icon:nnnnnn{\ppCoffee}{coffee}{"E1C2}{{0}{220}}{{1}{183}}{{"E1C3}{1}{184}}
\__phosphoricons_def_icon:nnnnnn{\ppCoffeeBean}{coffee-bean}{"E1C0}{{0}{219}}{{1}{181}}{{"E1C1}{1}{182}}
\__phosphoricons_def_icon:nnnnnn{\ppCoin}{coin}{"E60E}{{2}{243}}{{5}{228}}{{"E60F}{5}{229}}
\__phosphoricons_def_icon:nnnnnn{\ppCoinVertical}{coin-vertical}{"EB48}{{4}{218}}{{9}{176}}{{"EB49}{9}{177}}
\__phosphoricons_def_icon:nnnnnn{\ppCoins}{coins}{"E78E}{{3}{169}}{{7}{80}}{{"E78F}{7}{81}}
\__phosphoricons_def_icon:nnnnnn{\ppColumns}{columns}{"E546}{{2}{144}}{{5}{30}}{{"E547}{5}{31}}
\__phosphoricons_def_icon:nnnnnn{\ppColumnsPlusLeft}{columns-plus-left}{"E544}{{2}{143}}{{5}{28}}{{"E545}{5}{29}}
\__phosphoricons_def_icon:nnnnnn{\ppColumnsPlusRight}{columns-plus-right}{"E542}{{2}{142}}{{5}{26}}{{"E543}{5}{27}}
\__phosphoricons_def_icon:nnnnnn{\ppCommand}{command}{"E1C4}{{0}{221}}{{1}{185}}{{"E1C5}{1}{186}}
\__phosphoricons_def_icon:nnnnnn{\ppCompass}{compass}{"E1C8}{{0}{223}}{{1}{189}}{{"E1C9}{1}{190}}
\__phosphoricons_def_icon:nnnnnn{\ppCompassRose}{compass-rose}{"E1C6}{{0}{222}}{{1}{187}}{{"E1C7}{1}{188}}
\__phosphoricons_def_icon:nnnnnn{\ppCompassTool}{compass-tool}{"EA0E}{{4}{99}}{{8}{196}}{{"EA0F}{8}{197}}
\__phosphoricons_def_icon:nnnnnn{\ppComputerTower}{computer-tower}{"E548}{{2}{145}}{{5}{32}}{{"E549}{5}{33}}
\__phosphoricons_def_icon:nnnnnn{\ppConfetti}{confetti}{"E81A}{{3}{226}}{{7}{194}}{{"E81B}{7}{195}}
\__phosphoricons_def_icon:nnnnnn{\ppContactlessPayment}{contactless-payment}{"ED42}{{5}{114}}{{10}{226}}{{"ED43}{10}{227}}
\__phosphoricons_def_icon:nnnnnn{\ppControl}{control}{"ECA6}{{5}{57}}{{10}{112}}{{"ECA7}{10}{113}}
\__phosphoricons_def_icon:nnnnnn{\ppCookie}{cookie}{"E6CA}{{3}{80}}{{6}{158}}{{"E6CB}{6}{159}}
\__phosphoricons_def_icon:nnnnnn{\ppCookingPot}{cooking-pot}{"E764}{{3}{155}}{{7}{52}}{{"E765}{7}{53}}
\__phosphoricons_def_icon:nnnnnn{\ppCopy}{copy}{"E1CA}{{0}{224}}{{1}{191}}{{"E1CB}{1}{192}}
\__phosphoricons_def_icon:nnnnnn{\ppCopySimple}{copy-simple}{"E1CC}{{0}{225}}{{1}{193}}{{"E1CD}{1}{194}}
\__phosphoricons_def_icon:nnnnnn{\ppCopyleft}{copyleft}{"E86A}{{3}{247}}{{7}{236}}{{"E86B}{7}{237}}
\__phosphoricons_def_icon:nnnnnn{\ppCopyright}{copyright}{"E54A}{{2}{146}}{{5}{34}}{{"E54B}{5}{35}}
\__phosphoricons_def_icon:nnnnnn{\ppCornersIn}{corners-in}{"E1CE}{{0}{226}}{{1}{195}}{{"E1CF}{1}{196}}
\__phosphoricons_def_icon:nnnnnn{\ppCornersOut}{corners-out}{"E1D0}{{0}{227}}{{1}{197}}{{"E1D1}{1}{198}}
\__phosphoricons_def_icon:nnnnnn{\ppCouch}{couch}{"E7F6}{{3}{211}}{{7}{164}}{{"E7F7}{7}{165}}
\__phosphoricons_def_icon:nnnnnn{\ppCourtBasketball}{court-basketball}{"EE36}{{5}{203}}{{11}{148}}{{"EE37}{11}{149}}
\__phosphoricons_def_icon:nnnnnn{\ppCow}{cow}{"EABE}{{4}{159}}{{9}{60}}{{"EABF}{9}{61}}
\__phosphoricons_def_icon:nnnnnn{\ppCowboyHat}{cowboy-hat}{"ED12}{{5}{99}}{{10}{196}}{{"ED13}{10}{197}}
\__phosphoricons_def_icon:nnnnnn{\ppCpu}{cpu}{"E610}{{2}{244}}{{5}{230}}{{"E611}{5}{231}}
\__phosphoricons_def_icon:nnnnnn{\ppCrane}{crane}{"ED48}{{5}{116}}{{10}{230}}{{"ED4B}{10}{233}}
\__phosphoricons_def_icon:nnnnnn{\ppCraneTower}{crane-tower}{"ED49}{{5}{117}}{{10}{231}}{{"ED4D}{10}{235}}
\__phosphoricons_def_icon:nnnnnn{\ppCreditCard}{credit-card}{"E1D2}{{0}{228}}{{1}{199}}{{"E1D3}{1}{200}}
\__phosphoricons_def_icon:nnnnnn{\ppCricket}{cricket}{"EE12}{{5}{194}}{{11}{130}}{{"EE13}{11}{131}}
\__phosphoricons_def_icon:nnnnnn{\ppCrop}{crop}{"E1D4}{{0}{229}}{{1}{201}}{{"E1D5}{1}{202}}
\__phosphoricons_def_icon:nnnnnn{\ppCross}{cross}{"E8A0}{{4}{8}}{{8}{14}}{{"E8A1}{8}{15}}
\__phosphoricons_def_icon:nnnnnn{\ppCrosshair}{crosshair}{"E1D6}{{0}{230}}{{1}{203}}{{"E1D7}{1}{204}}
\__phosphoricons_def_icon:nnnnnn{\ppCrosshairSimple}{crosshair-simple}{"E1D8}{{0}{231}}{{1}{205}}{{"E1D9}{1}{206}}
\__phosphoricons_def_icon:nnnnnn{\ppCrown}{crown}{"E614}{{2}{246}}{{5}{234}}{{"E615}{5}{235}}
\__phosphoricons_def_icon:nnnnnn{\ppCrownCross}{crown-cross}{"EE5E}{{5}{223}}{{11}{188}}{{"EE5F}{11}{189}}
\__phosphoricons_def_icon:nnnnnn{\ppCrownSimple}{crown-simple}{"E616}{{2}{247}}{{5}{236}}{{"E617}{5}{237}}
\__phosphoricons_def_icon:nnnnnn{\ppCube}{cube}{"E1DA}{{0}{232}}{{1}{207}}{{"E1DB}{1}{208}}
\__phosphoricons_def_icon:nnnnnn{\ppCubeFocus}{cube-focus}{"ED0A}{{5}{95}}{{10}{188}}{{"ED0B}{10}{189}}
\__phosphoricons_def_icon:nnnnnn{\ppCubeTransparent}{cube-transparent}{"EC7C}{{5}{42}}{{10}{82}}{{"EC7D}{10}{83}}
\__phosphoricons_def_icon:nnnnnn{\ppCurrencyBtc}{currency-btc}{"E618}{{2}{248}}{{5}{238}}{{"E619}{5}{239}}
\__phosphoricons_def_icon:nnnnnn{\ppCurrencyCircleDollar}{currency-circle-dollar}{"E54C}{{2}{147}}{{5}{36}}{{"E54D}{5}{37}}
\__phosphoricons_def_icon:nnnnnn{\ppCurrencyCny}{currency-cny}{"E54E}{{2}{148}}{{5}{38}}{{"E54F}{5}{39}}
\__phosphoricons_def_icon:nnnnnn{\ppCurrencyDollar}{currency-dollar}{"E550}{{2}{149}}{{5}{40}}{{"E551}{5}{41}}
\__phosphoricons_def_icon:nnnnnn{\ppCurrencyDollarSimple}{currency-dollar-simple}{"E552}{{2}{150}}{{5}{42}}{{"E553}{5}{43}}
\__phosphoricons_def_icon:nnnnnn{\ppCurrencyEth}{currency-eth}{"EADA}{{4}{166}}{{9}{74}}{{"EADB}{9}{75}}
\__phosphoricons_def_icon:nnnnnn{\ppCurrencyEur}{currency-eur}{"E554}{{2}{151}}{{5}{44}}{{"E555}{5}{45}}
\__phosphoricons_def_icon:nnnnnn{\ppCurrencyGbp}{currency-gbp}{"E556}{{2}{152}}{{5}{46}}{{"E557}{5}{47}}
\__phosphoricons_def_icon:nnnnnn{\ppCurrencyInr}{currency-inr}{"E558}{{2}{153}}{{5}{48}}{{"E559}{5}{49}}
\__phosphoricons_def_icon:nnnnnn{\ppCurrencyJpy}{currency-jpy}{"E55A}{{2}{154}}{{5}{50}}{{"E55B}{5}{51}}
\__phosphoricons_def_icon:nnnnnn{\ppCurrencyKrw}{currency-krw}{"E55C}{{2}{155}}{{5}{52}}{{"E55D}{5}{53}}
\__phosphoricons_def_icon:nnnnnn{\ppCurrencyKzt}{currency-kzt}{"EC4C}{{5}{26}}{{10}{50}}{{"EC4D}{10}{51}}
\__phosphoricons_def_icon:nnnnnn{\ppCurrencyNgn}{currency-ngn}{"EB52}{{4}{222}}{{9}{186}}{{"EB53}{9}{187}}
\__phosphoricons_def_icon:nnnnnn{\ppCurrencyRub}{currency-rub}{"E55E}{{2}{156}}{{5}{54}}{{"E55F}{5}{55}}
\__phosphoricons_def_icon:nnnnnn{\ppCursor}{cursor}{"E1DC}{{0}{233}}{{1}{209}}{{"E1DD}{1}{210}}
\__phosphoricons_def_icon:nnnnnn{\ppCursorClick}{cursor-click}{"E7C8}{{3}{194}}{{7}{130}}{{"E7C9}{7}{131}}
\__phosphoricons_def_icon:nnnnnn{\ppCursorText}{cursor-text}{"E7D8}{{3}{201}}{{7}{144}}{{"E7D9}{7}{145}}
\__phosphoricons_def_icon:nnnnnn{\ppCylinder}{cylinder}{"E8FC}{{4}{36}}{{8}{70}}{{"E8FD}{8}{71}}
\__phosphoricons_def_icon:nnnnnn{\ppDatabase}{database}{"E1DE}{{0}{234}}{{1}{211}}{{"E1DF}{1}{212}}
\__phosphoricons_def_icon:nnnnnn{\ppDesk}{desk}{"ED16}{{5}{100}}{{10}{198}}{{"ED17}{10}{199}}
\__phosphoricons_def_icon:nnnnnn{\ppDesktop}{desktop}{"E560}{{2}{157}}{{5}{56}}{{"E561}{5}{57}}
\__phosphoricons_def_icon:nnnnnn{\ppDesktopTower}{desktop-tower}{"E562}{{2}{158}}{{5}{58}}{{"E563}{5}{59}}
\__phosphoricons_def_icon:nnnnnn{\ppDetective}{detective}{"E83E}{{3}{240}}{{7}{222}}{{"E83F}{7}{223}}
\__phosphoricons_def_icon:nnnnnn{\ppDevToLogo}{dev-to-logo}{"ED0E}{{5}{97}}{{10}{192}}{{"ED0F}{10}{193}}
\__phosphoricons_def_icon:nnnnnn{\ppDeviceMobile}{device-mobile}{"E1E0}{{0}{235}}{{1}{213}}{{"E1E1}{1}{214}}
\__phosphoricons_def_icon:nnnnnn{\ppDeviceMobileCamera}{device-mobile-camera}{"E1E2}{{0}{236}}{{1}{215}}{{"E1E3}{1}{216}}
\__phosphoricons_def_icon:nnnnnn{\ppDeviceMobileSlash}{device-mobile-slash}{"EE46}{{5}{211}}{{11}{164}}{{"EE47}{11}{165}}
\__phosphoricons_def_icon:nnnnnn{\ppDeviceMobileSpeaker}{device-mobile-speaker}{"E1E4}{{0}{237}}{{1}{217}}{{"E1E5}{1}{218}}
\__phosphoricons_def_icon:nnnnnn{\ppDeviceRotate}{device-rotate}{"EDF2}{{5}{185}}{{11}{112}}{{"EDF3}{11}{113}}
\__phosphoricons_def_icon:nnnnnn{\ppDeviceTablet}{device-tablet}{"E1E6}{{0}{238}}{{1}{219}}{{"E1E7}{1}{220}}
\__phosphoricons_def_icon:nnnnnn{\ppDeviceTabletCamera}{device-tablet-camera}{"E1E8}{{0}{239}}{{1}{221}}{{"E1E9}{1}{222}}
\__phosphoricons_def_icon:nnnnnn{\ppDeviceTabletSpeaker}{device-tablet-speaker}{"E1EA}{{0}{240}}{{1}{223}}{{"E1EB}{1}{224}}
\__phosphoricons_def_icon:nnnnnn{\ppDevices}{devices}{"EBA4}{{4}{250}}{{9}{242}}{{"EBA5}{9}{243}}
\__phosphoricons_def_icon:nnnnnn{\ppDiamond}{diamond}{"E1EC}{{0}{241}}{{1}{225}}{{"E1ED}{1}{226}}
\__phosphoricons_def_icon:nnnnnn{\ppDiamondsFour}{diamonds-four}{"E8F4}{{4}{33}}{{8}{64}}{{"E8F5}{8}{65}}
\__phosphoricons_def_icon:nnnnnn{\ppDiceFive}{dice-five}{"E1EE}{{0}{242}}{{1}{227}}{{"E1EF}{1}{228}}
\__phosphoricons_def_icon:nnnnnn{\ppDiceFour}{dice-four}{"E1F0}{{0}{243}}{{1}{229}}{{"E1F1}{1}{230}}
\__phosphoricons_def_icon:nnnnnn{\ppDiceOne}{dice-one}{"E1F2}{{0}{244}}{{1}{231}}{{"E1F3}{1}{232}}
\__phosphoricons_def_icon:nnnnnn{\ppDiceSix}{dice-six}{"E1F4}{{0}{245}}{{1}{233}}{{"E1F5}{1}{234}}
\__phosphoricons_def_icon:nnnnnn{\ppDiceThree}{dice-three}{"E1F6}{{0}{246}}{{1}{235}}{{"E1F7}{1}{236}}
\__phosphoricons_def_icon:nnnnnn{\ppDiceTwo}{dice-two}{"E1F8}{{0}{247}}{{1}{237}}{{"E1F9}{1}{238}}
\__phosphoricons_def_icon:nnnnnn{\ppDisc}{disc}{"E564}{{2}{159}}{{5}{60}}{{"E565}{5}{61}}
\__phosphoricons_def_icon:nnnnnn{\ppDiscoBall}{disco-ball}{"ED98}{{5}{146}}{{11}{34}}{{"ED99}{11}{35}}
\__phosphoricons_def_icon:nnnnnn{\ppDiscordLogo}{discord-logo}{"E61A}{{2}{249}}{{5}{240}}{{"E61B}{5}{241}}
\__phosphoricons_def_icon:nnnnnn{\ppDivide}{divide}{"E1FA}{{0}{248}}{{1}{239}}{{"E1FB}{1}{240}}
\__phosphoricons_def_icon:nnnnnn{\ppDna}{dna}{"E924}{{4}{44}}{{8}{86}}{{"E925}{8}{87}}
\__phosphoricons_def_icon:nnnnnn{\ppDog}{dog}{"E74A}{{3}{143}}{{7}{28}}{{"E74B}{7}{29}}
\__phosphoricons_def_icon:nnnnnn{\ppDoor}{door}{"E61C}{{2}{250}}{{5}{242}}{{"E61D}{5}{243}}
\__phosphoricons_def_icon:nnnnnn{\ppDoorOpen}{door-open}{"E7E6}{{3}{207}}{{7}{154}}{{"E7E7}{7}{155}}
\__phosphoricons_def_icon:nnnnnn{\ppDot}{dot}{"ECDE}{{5}{80}}{{10}{158}}{{"ECDF}{10}{159}}
\__phosphoricons_def_icon:nnnnnn{\ppDotOutline}{dot-outline}{"ECE0}{{5}{81}}{{10}{160}}{{"ECE1}{10}{161}}
\__phosphoricons_def_icon:nnnnnn{\ppDotsNine}{dots-nine}{"E1FC}{{0}{249}}{{1}{241}}{{"E1FD}{1}{242}}
\__phosphoricons_def_icon:nnnnnn{\ppDotsSix}{dots-six}{"E794}{{3}{172}}{{7}{86}}{{"E795}{7}{87}}
\__phosphoricons_def_icon:nnnnnn{\ppDotsSixVertical}{dots-six-vertical}{"EAE2}{{4}{170}}{{9}{82}}{{"EAE3}{9}{83}}
\__phosphoricons_def_icon:nnnnnn{\ppDotsThree}{dots-three}{"E1FE}{{0}{250}}{{1}{243}}{{"E1FF}{1}{244}}
\__phosphoricons_def_icon:nnnnnn{\ppDotsThreeCircle}{dots-three-circle}{"E200}{{0}{251}}{{1}{245}}{{"E201}{1}{246}}
\__phosphoricons_def_icon:nnnnnn{\ppDotsThreeCircleVertical}{dots-three-circle-vertical}{"E202}{{0}{252}}{{1}{247}}{{"E203}{1}{248}}
\__phosphoricons_def_icon:nnnnnn{\ppDotsThreeOutline}{dots-three-outline}{"E204}{{0}{253}}{{1}{249}}{{"E205}{1}{250}}
\__phosphoricons_def_icon:nnnnnn{\ppDotsThreeOutlineVertical}{dots-three-outline-vertical}{"E206}{{0}{254}}{{1}{251}}{{"E207}{1}{252}}
\__phosphoricons_def_icon:nnnnnn{\ppDotsThreeVertical}{dots-three-vertical}{"E208}{{0}{255}}{{1}{253}}{{"E209}{1}{254}}
\__phosphoricons_def_icon:nnnnnn{\ppDownload}{download}{"E20A}{{1}{0}}{{1}{255}}{{"E20B}{2}{0}}
\__phosphoricons_def_icon:nnnnnn{\ppDownloadSimple}{download-simple}{"E20C}{{1}{1}}{{2}{1}}{{"E20D}{2}{2}}
\__phosphoricons_def_icon:nnnnnn{\ppDress}{dress}{"EA7E}{{4}{135}}{{9}{12}}{{"EA7F}{9}{13}}
\__phosphoricons_def_icon:nnnnnn{\ppDresser}{dresser}{"E94E}{{4}{49}}{{8}{96}}{{"E94F}{8}{97}}
\__phosphoricons_def_icon:nnnnnn{\ppDribbbleLogo}{dribbble-logo}{"E20E}{{1}{2}}{{2}{3}}{{"E20F}{2}{4}}
\__phosphoricons_def_icon:nnnnnn{\ppDrone}{drone}{"ED74}{{5}{134}}{{11}{10}}{{"ED75}{11}{11}}
\__phosphoricons_def_icon:nnnnnn{\ppDrop}{drop}{"E210}{{1}{3}}{{2}{5}}{{"E211}{2}{6}}
\__phosphoricons_def_icon:nnnnnn{\ppDropHalf}{drop-half}{"E566}{{2}{160}}{{5}{62}}{{"E567}{5}{63}}
\__phosphoricons_def_icon:nnnnnn{\ppDropHalfBottom}{drop-half-bottom}{"EB40}{{4}{214}}{{9}{168}}{{"EB41}{9}{169}}
\__phosphoricons_def_icon:nnnnnn{\ppDropSimple}{drop-simple}{"EE32}{{5}{201}}{{11}{144}}{{"EE33}{11}{145}}
\__phosphoricons_def_icon:nnnnnn{\ppDropSlash}{drop-slash}{"E954}{{4}{51}}{{8}{100}}{{"E955}{8}{101}}
\__phosphoricons_def_icon:nnnnnn{\ppDropboxLogo}{dropbox-logo}{"E7D0}{{3}{197}}{{7}{136}}{{"E7D1}{7}{137}}
\__phosphoricons_def_icon:nnnnnn{\ppEar}{ear}{"E70C}{{3}{113}}{{6}{224}}{{"E70D}{6}{225}}
\__phosphoricons_def_icon:nnnnnn{\ppEarSlash}{ear-slash}{"E70E}{{3}{114}}{{6}{226}}{{"E70F}{6}{227}}
\__phosphoricons_def_icon:nnnnnn{\ppEgg}{egg}{"E812}{{3}{223}}{{7}{188}}{{"E813}{7}{189}}
\__phosphoricons_def_icon:nnnnnn{\ppEggCrack}{egg-crack}{"EB64}{{4}{231}}{{9}{204}}{{"EB65}{9}{205}}
\__phosphoricons_def_icon:nnnnnn{\ppEject}{eject}{"E212}{{1}{4}}{{2}{7}}{{"E213}{2}{8}}
\__phosphoricons_def_icon:nnnnnn{\ppEjectSimple}{eject-simple}{"E6AE}{{3}{67}}{{6}{132}}{{"E6AF}{6}{133}}
\__phosphoricons_def_icon:nnnnnn{\ppElevator}{elevator}{"ECC0}{{5}{68}}{{10}{134}}{{"ECC1}{10}{135}}
\__phosphoricons_def_icon:nnnnnn{\ppEmpty}{empty}{"EDBC}{{5}{163}}{{11}{68}}{{"EDBD}{11}{69}}
\__phosphoricons_def_icon:nnnnnn{\ppEngine}{engine}{"EA80}{{4}{136}}{{9}{14}}{{"EA81}{9}{15}}
\__phosphoricons_def_icon:nnnnnn{\ppEnvelope}{envelope}{"E214}{{1}{5}}{{2}{9}}{{"E215}{2}{10}}
\__phosphoricons_def_icon:nnnnnn{\ppEnvelopeOpen}{envelope-open}{"E216}{{1}{6}}{{2}{11}}{{"E217}{2}{12}}
\__phosphoricons_def_icon:nnnnnn{\ppEnvelopeSimple}{envelope-simple}{"E218}{{1}{7}}{{2}{13}}{{"E219}{2}{14}}
\__phosphoricons_def_icon:nnnnnn{\ppEnvelopeSimpleOpen}{envelope-simple-open}{"E21A}{{1}{8}}{{2}{15}}{{"E21B}{2}{16}}
\__phosphoricons_def_icon:nnnnnn{\ppEqualizer}{equalizer}{"EBBC}{{5}{1}}{{10}{0}}{{"EBBD}{10}{1}}
\__phosphoricons_def_icon:nnnnnn{\ppEquals}{equals}{"E21C}{{1}{9}}{{2}{17}}{{"E21D}{2}{18}}
\__phosphoricons_def_icon:nnnnnn{\ppEraser}{eraser}{"E21E}{{1}{10}}{{2}{19}}{{"E21F}{2}{20}}
\__phosphoricons_def_icon:nnnnnn{\ppEscalatorDown}{escalator-down}{"ECBA}{{5}{65}}{{10}{128}}{{"ECBB}{10}{129}}
\__phosphoricons_def_icon:nnnnnn{\ppEscalatorUp}{escalator-up}{"ECBC}{{5}{66}}{{10}{130}}{{"ECBD}{10}{131}}
\__phosphoricons_def_icon:nnnnnn{\ppExam}{exam}{"E742}{{3}{139}}{{7}{20}}{{"E743}{7}{21}}
\__phosphoricons_def_icon:nnnnnn{\ppExclamationMark}{exclamation-mark}{"EE44}{{5}{210}}{{11}{162}}{{"EE45}{11}{163}}
\__phosphoricons_def_icon:nnnnnn{\ppExclude}{exclude}{"E882}{{4}{2}}{{8}{2}}{{"E883}{8}{3}}
\__phosphoricons_def_icon:nnnnnn{\ppExcludeSquare}{exclude-square}{"E880}{{4}{1}}{{8}{0}}{{"E881}{8}{1}}
\__phosphoricons_def_icon:nnnnnn{\ppExport}{export}{"EAF0}{{4}{174}}{{9}{90}}{{"EAF1}{9}{91}}
\__phosphoricons_def_icon:nnnnnn{\ppEye}{eye}{"E220}{{1}{11}}{{2}{21}}{{"E221}{2}{22}}
\__phosphoricons_def_icon:nnnnnn{\ppEyeClosed}{eye-closed}{"E222}{{1}{12}}{{2}{23}}{{"E223}{2}{24}}
\__phosphoricons_def_icon:nnnnnn{\ppEyeSlash}{eye-slash}{"E224}{{1}{13}}{{2}{25}}{{"E225}{2}{26}}
\__phosphoricons_def_icon:nnnnnn{\ppEyedropper}{eyedropper}{"E568}{{2}{161}}{{5}{64}}{{"E569}{5}{65}}
\__phosphoricons_def_icon:nnnnnn{\ppEyedropperSample}{eyedropper-sample}{"EAC4}{{4}{161}}{{9}{64}}{{"EAC5}{9}{65}}
\__phosphoricons_def_icon:nnnnnn{\ppEyeglasses}{eyeglasses}{"E7BA}{{3}{187}}{{7}{116}}{{"E7BB}{7}{117}}
\__phosphoricons_def_icon:nnnnnn{\ppEyes}{eyes}{"EE5C}{{5}{222}}{{11}{186}}{{"EE5D}{11}{187}}
\__phosphoricons_def_icon:nnnnnn{\ppFaceMask}{face-mask}{"E56A}{{2}{162}}{{5}{66}}{{"E56B}{5}{67}}
\__phosphoricons_def_icon:nnnnnn{\ppFacebookLogo}{facebook-logo}{"E226}{{1}{14}}{{2}{27}}{{"E227}{2}{28}}
\__phosphoricons_def_icon:nnnnnn{\ppFactory}{factory}{"E760}{{3}{153}}{{7}{48}}{{"E761}{7}{49}}
\__phosphoricons_def_icon:nnnnnn{\ppFaders}{faders}{"E228}{{1}{15}}{{2}{29}}{{"E229}{2}{30}}
\__phosphoricons_def_icon:nnnnnn{\ppFadersHorizontal}{faders-horizontal}{"E22A}{{1}{16}}{{2}{31}}{{"E22B}{2}{32}}
\__phosphoricons_def_icon:nnnnnn{\ppFalloutShelter}{fallout-shelter}{"E9DE}{{4}{82}}{{8}{162}}{{"E9DF}{8}{163}}
\__phosphoricons_def_icon:nnnnnn{\ppFan}{fan}{"E9F2}{{4}{89}}{{8}{176}}{{"E9F3}{8}{177}}
\__phosphoricons_def_icon:nnnnnn{\ppFarm}{farm}{"EC70}{{5}{38}}{{10}{74}}{{"EC71}{10}{75}}
\__phosphoricons_def_icon:nnnnnn{\ppFastForward}{fast-forward}{"E6A6}{{3}{63}}{{6}{124}}{{"E6A7}{6}{125}}
\__phosphoricons_def_icon:nnnnnn{\ppFastForwardCircle}{fast-forward-circle}{"E22C}{{1}{17}}{{2}{33}}{{"E22D}{2}{34}}
\__phosphoricons_def_icon:nnnnnn{\ppFeather}{feather}{"E9C0}{{4}{74}}{{8}{146}}{{"E9C1}{8}{147}}
\__phosphoricons_def_icon:nnnnnn{\ppFediverseLogo}{fediverse-logo}{"ED66}{{5}{128}}{{10}{254}}{{"ED67}{10}{255}}
\__phosphoricons_def_icon:nnnnnn{\ppFigmaLogo}{figma-logo}{"E22E}{{1}{18}}{{2}{35}}{{"E22F}{2}{36}}
\__phosphoricons_def_icon:nnnnnn{\ppFile}{file}{"E230}{{1}{19}}{{2}{37}}{{"E231}{2}{38}}
\__phosphoricons_def_icon:nnnnnn{\ppFileArchive}{file-archive}{"EB2A}{{4}{202}}{{9}{146}}{{"EB2B}{9}{147}}
\__phosphoricons_def_icon:nnnnnn{\ppFileArrowDown}{file-arrow-down}{"E232}{{1}{20}}{{2}{39}}{{"E233}{2}{40}}
\__phosphoricons_def_icon:nnnnnn{\ppFileArrowUp}{file-arrow-up}{"E61E}{{2}{251}}{{5}{244}}{{"E61F}{5}{245}}
\__phosphoricons_def_icon:nnnnnn{\ppFileAudio}{file-audio}{"EA20}{{4}{105}}{{8}{208}}{{"EA21}{8}{209}}
\__phosphoricons_def_icon:nnnnnn{\ppFileC}{file-c}{"EB32}{{4}{206}}{{9}{154}}{{"EB36}{9}{158}}
\__phosphoricons_def_icon:nnnnnn{\ppFileCSharp}{file-c-sharp}{"EB30}{{4}{205}}{{9}{152}}{{"EB31}{9}{153}}
\__phosphoricons_def_icon:nnnnnn{\ppFileCloud}{file-cloud}{"E95E}{{4}{56}}{{8}{110}}{{"E95F}{8}{111}}
\__phosphoricons_def_icon:nnnnnn{\ppFileCode}{file-code}{"E914}{{4}{39}}{{8}{76}}{{"E915}{8}{77}}
\__phosphoricons_def_icon:nnnnnn{\ppFileCpp}{file-cpp}{"EB2E}{{4}{204}}{{9}{150}}{{"EB2F}{9}{151}}
\__phosphoricons_def_icon:nnnnnn{\ppFileCss}{file-css}{"EB34}{{4}{208}}{{9}{156}}{{"EB37}{9}{159}}
\__phosphoricons_def_icon:nnnnnn{\ppFileCsv}{file-csv}{"EB1C}{{4}{195}}{{9}{132}}{{"EB1D}{9}{133}}
\__phosphoricons_def_icon:nnnnnn{\ppFileDashed}{file-dashed}{"E704}{{3}{109}}{{6}{216}}{{"E705}{6}{217}}
\__phosphoricons_def_icon:nnnnnn{\ppFileDoc}{file-doc}{"EB1E}{{4}{196}}{{9}{134}}{{"EB1F}{9}{135}}
\__phosphoricons_def_icon:nnnnnn{\ppFileDotted}{file-dotted}{"E704}{{3}{109}}{{6}{216}}{{"E705}{6}{217}}
\__phosphoricons_def_icon:nnnnnn{\ppFileHtml}{file-html}{"EB38}{{4}{210}}{{9}{160}}{{"EB39}{9}{161}}
\__phosphoricons_def_icon:nnnnnn{\ppFileImage}{file-image}{"EA24}{{4}{107}}{{8}{212}}{{"EA25}{8}{213}}
\__phosphoricons_def_icon:nnnnnn{\ppFileIni}{file-ini}{"EB33}{{4}{207}}{{9}{155}}{{"EB3B}{9}{163}}
\__phosphoricons_def_icon:nnnnnn{\ppFileJpg}{file-jpg}{"EB1A}{{4}{194}}{{9}{130}}{{"EB1B}{9}{131}}
\__phosphoricons_def_icon:nnnnnn{\ppFileJs}{file-js}{"EB24}{{4}{199}}{{9}{140}}{{"EB25}{9}{141}}
\__phosphoricons_def_icon:nnnnnn{\ppFileJsx}{file-jsx}{"EB3A}{{4}{211}}{{9}{162}}{{"EB3D}{9}{165}}
\__phosphoricons_def_icon:nnnnnn{\ppFileLock}{file-lock}{"E95C}{{4}{55}}{{8}{108}}{{"E95D}{8}{109}}
\__phosphoricons_def_icon:nnnnnn{\ppFileMagnifyingGlass}{file-magnifying-glass}{"E238}{{1}{23}}{{2}{45}}{{"E239}{2}{46}}
\__phosphoricons_def_icon:nnnnnn{\ppFileMd}{file-md}{"ED50}{{5}{121}}{{10}{238}}{{"ED51}{10}{239}}
\__phosphoricons_def_icon:nnnnnn{\ppFileMinus}{file-minus}{"E234}{{1}{21}}{{2}{41}}{{"E235}{2}{42}}
\__phosphoricons_def_icon:nnnnnn{\ppFilePdf}{file-pdf}{"E702}{{3}{108}}{{6}{214}}{{"E703}{6}{215}}
\__phosphoricons_def_icon:nnnnnn{\ppFilePlus}{file-plus}{"E236}{{1}{22}}{{2}{43}}{{"E237}{2}{44}}
\__phosphoricons_def_icon:nnnnnn{\ppFilePng}{file-png}{"EB18}{{4}{193}}{{9}{128}}{{"EB19}{9}{129}}
\__phosphoricons_def_icon:nnnnnn{\ppFilePpt}{file-ppt}{"EB20}{{4}{197}}{{9}{136}}{{"EB21}{9}{137}}
\__phosphoricons_def_icon:nnnnnn{\ppFilePy}{file-py}{"EB2C}{{4}{203}}{{9}{148}}{{"EB2D}{9}{149}}
\__phosphoricons_def_icon:nnnnnn{\ppFileRs}{file-rs}{"EB28}{{4}{201}}{{9}{144}}{{"EB29}{9}{145}}
\__phosphoricons_def_icon:nnnnnn{\ppFileSearch}{file-search}{"E238}{{1}{23}}{{2}{45}}{{"E239}{2}{46}}
\__phosphoricons_def_icon:nnnnnn{\ppFileSql}{file-sql}{"ED4E}{{5}{120}}{{10}{236}}{{"ED4F}{10}{237}}
\__phosphoricons_def_icon:nnnnnn{\ppFileSvg}{file-svg}{"ED08}{{5}{94}}{{10}{186}}{{"ED09}{10}{187}}
\__phosphoricons_def_icon:nnnnnn{\ppFileText}{file-text}{"E23A}{{1}{24}}{{2}{47}}{{"E23B}{2}{48}}
\__phosphoricons_def_icon:nnnnnn{\ppFileTs}{file-ts}{"EB26}{{4}{200}}{{9}{142}}{{"EB27}{9}{143}}
\__phosphoricons_def_icon:nnnnnn{\ppFileTsx}{file-tsx}{"EB3C}{{4}{212}}{{9}{164}}{{"EB3F}{9}{167}}
\__phosphoricons_def_icon:nnnnnn{\ppFileTxt}{file-txt}{"EB35}{{4}{209}}{{9}{157}}{{"EB43}{9}{171}}
\__phosphoricons_def_icon:nnnnnn{\ppFileVideo}{file-video}{"EA22}{{4}{106}}{{8}{210}}{{"EA23}{8}{211}}
\__phosphoricons_def_icon:nnnnnn{\ppFileVue}{file-vue}{"EB3E}{{4}{213}}{{9}{166}}{{"EB47}{9}{175}}
\__phosphoricons_def_icon:nnnnnn{\ppFileX}{file-x}{"E23C}{{1}{25}}{{2}{49}}{{"E23D}{2}{50}}
\__phosphoricons_def_icon:nnnnnn{\ppFileXls}{file-xls}{"EB22}{{4}{198}}{{9}{138}}{{"EB23}{9}{139}}
\__phosphoricons_def_icon:nnnnnn{\ppFileZip}{file-zip}{"E958}{{4}{53}}{{8}{104}}{{"E959}{8}{105}}
\__phosphoricons_def_icon:nnnnnn{\ppFiles}{files}{"E710}{{3}{115}}{{6}{228}}{{"E711}{6}{229}}
\__phosphoricons_def_icon:nnnnnn{\ppFilmReel}{film-reel}{"E8C0}{{4}{16}}{{8}{30}}{{"E8C1}{8}{31}}
\__phosphoricons_def_icon:nnnnnn{\ppFilmScript}{film-script}{"EB50}{{4}{221}}{{9}{184}}{{"EB51}{9}{185}}
\__phosphoricons_def_icon:nnnnnn{\ppFilmSlate}{film-slate}{"E8C2}{{4}{17}}{{8}{32}}{{"E8C3}{8}{33}}
\__phosphoricons_def_icon:nnnnnn{\ppFilmStrip}{film-strip}{"E792}{{3}{171}}{{7}{84}}{{"E793}{7}{85}}
\__phosphoricons_def_icon:nnnnnn{\ppFingerprint}{fingerprint}{"E23E}{{1}{26}}{{2}{51}}{{"E23F}{2}{52}}
\__phosphoricons_def_icon:nnnnnn{\ppFingerprintSimple}{fingerprint-simple}{"E240}{{1}{27}}{{2}{53}}{{"E241}{2}{54}}
\__phosphoricons_def_icon:nnnnnn{\ppFinnTheHuman}{finn-the-human}{"E56C}{{2}{163}}{{5}{68}}{{"E56D}{5}{69}}
\__phosphoricons_def_icon:nnnnnn{\ppFire}{fire}{"E242}{{1}{28}}{{2}{55}}{{"E243}{2}{56}}
\__phosphoricons_def_icon:nnnnnn{\ppFireExtinguisher}{fire-extinguisher}{"E9E8}{{4}{86}}{{8}{170}}{{"E9E9}{8}{171}}
\__phosphoricons_def_icon:nnnnnn{\ppFireSimple}{fire-simple}{"E620}{{2}{252}}{{5}{246}}{{"E621}{5}{247}}
\__phosphoricons_def_icon:nnnnnn{\ppFireTruck}{fire-truck}{"E574}{{2}{167}}{{5}{76}}{{"E575}{5}{77}}
\__phosphoricons_def_icon:nnnnnn{\ppFirstAid}{first-aid}{"E56E}{{2}{164}}{{5}{70}}{{"E56F}{5}{71}}
\__phosphoricons_def_icon:nnnnnn{\ppFirstAidKit}{first-aid-kit}{"E570}{{2}{165}}{{5}{72}}{{"E571}{5}{73}}
\__phosphoricons_def_icon:nnnnnn{\ppFish}{fish}{"E728}{{3}{127}}{{6}{252}}{{"E729}{6}{253}}
\__phosphoricons_def_icon:nnnnnn{\ppFishSimple}{fish-simple}{"E72A}{{3}{128}}{{6}{254}}{{"E72B}{6}{255}}
\__phosphoricons_def_icon:nnnnnn{\ppFlag}{flag}{"E244}{{1}{29}}{{2}{57}}{{"E245}{2}{58}}
\__phosphoricons_def_icon:nnnnnn{\ppFlagBanner}{flag-banner}{"E622}{{2}{253}}{{5}{248}}{{"E623}{5}{249}}
\__phosphoricons_def_icon:nnnnnn{\ppFlagBannerFold}{flag-banner-fold}{"ECF2}{{5}{86}}{{10}{170}}{{"ECF3}{10}{171}}
\__phosphoricons_def_icon:nnnnnn{\ppFlagCheckered}{flag-checkered}{"EA38}{{4}{114}}{{8}{226}}{{"EA39}{8}{227}}
\__phosphoricons_def_icon:nnnnnn{\ppFlagPennant}{flag-pennant}{"ECF0}{{5}{85}}{{10}{168}}{{"ECF1}{10}{169}}
\__phosphoricons_def_icon:nnnnnn{\ppFlame}{flame}{"E624}{{2}{254}}{{5}{250}}{{"E625}{5}{251}}
\__phosphoricons_def_icon:nnnnnn{\ppFlashlight}{flashlight}{"E246}{{1}{30}}{{2}{59}}{{"E247}{2}{60}}
\__phosphoricons_def_icon:nnnnnn{\ppFlask}{flask}{"E79E}{{3}{176}}{{7}{94}}{{"E79F}{7}{95}}
\__phosphoricons_def_icon:nnnnnn{\ppFlipHorizontal}{flip-horizontal}{"ED6A}{{5}{130}}{{11}{2}}{{"ED6B}{11}{3}}
\__phosphoricons_def_icon:nnnnnn{\ppFlipVertical}{flip-vertical}{"ED6C}{{5}{131}}{{11}{4}}{{"ED6D}{11}{5}}
\__phosphoricons_def_icon:nnnnnn{\ppFloppyDisk}{floppy-disk}{"E248}{{1}{31}}{{2}{61}}{{"E249}{2}{62}}
\__phosphoricons_def_icon:nnnnnn{\ppFloppyDiskBack}{floppy-disk-back}{"EAF4}{{4}{176}}{{9}{94}}{{"EAF5}{9}{95}}
\__phosphoricons_def_icon:nnnnnn{\ppFlowArrow}{flow-arrow}{"E6EC}{{3}{97}}{{6}{192}}{{"E6ED}{6}{193}}
\__phosphoricons_def_icon:nnnnnn{\ppFlower}{flower}{"E75E}{{3}{152}}{{7}{46}}{{"E75F}{7}{47}}
\__phosphoricons_def_icon:nnnnnn{\ppFlowerLotus}{flower-lotus}{"E6CC}{{3}{81}}{{6}{160}}{{"E6CD}{6}{161}}
\__phosphoricons_def_icon:nnnnnn{\ppFlowerTulip}{flower-tulip}{"EACC}{{4}{163}}{{9}{68}}{{"EACD}{9}{69}}
\__phosphoricons_def_icon:nnnnnn{\ppFlyingSaucer}{flying-saucer}{"EB4A}{{4}{219}}{{9}{178}}{{"EB4B}{9}{179}}
\__phosphoricons_def_icon:nnnnnn{\ppFolder}{folder}{"E24A}{{1}{32}}{{2}{63}}{{"E24B}{2}{64}}
\__phosphoricons_def_icon:nnnnnn{\ppFolderDashed}{folder-dashed}{"E8F8}{{4}{35}}{{8}{68}}{{"E8F9}{8}{69}}
\__phosphoricons_def_icon:nnnnnn{\ppFolderDotted}{folder-dotted}{"E8F8}{{4}{35}}{{8}{68}}{{"E8F9}{8}{69}}
\__phosphoricons_def_icon:nnnnnn{\ppFolderLock}{folder-lock}{"EA3C}{{4}{116}}{{8}{230}}{{"EA3D}{8}{231}}
\__phosphoricons_def_icon:nnnnnn{\ppFolderMinus}{folder-minus}{"E254}{{1}{33}}{{2}{65}}{{"E255}{2}{66}}
\__phosphoricons_def_icon:nnnnnn{\ppFolderNotch}{folder-notch}{"E24A}{{1}{32}}{{2}{63}}{{"E24B}{2}{64}}
\__phosphoricons_def_icon:nnnnnn{\ppFolderNotchMinus}{folder-notch-minus}{"E254}{{1}{33}}{{2}{65}}{{"E255}{2}{66}}
\__phosphoricons_def_icon:nnnnnn{\ppFolderNotchOpen}{folder-notch-open}{"E256}{{1}{34}}{{2}{67}}{{"E257}{2}{68}}
\__phosphoricons_def_icon:nnnnnn{\ppFolderNotchPlus}{folder-notch-plus}{"E258}{{1}{35}}{{2}{69}}{{"E259}{2}{70}}
\__phosphoricons_def_icon:nnnnnn{\ppFolderOpen}{folder-open}{"E256}{{1}{34}}{{2}{67}}{{"E257}{2}{68}}
\__phosphoricons_def_icon:nnnnnn{\ppFolderPlus}{folder-plus}{"E258}{{1}{35}}{{2}{69}}{{"E259}{2}{70}}
\__phosphoricons_def_icon:nnnnnn{\ppFolderSimple}{folder-simple}{"E25A}{{1}{36}}{{2}{71}}{{"E25B}{2}{72}}
\__phosphoricons_def_icon:nnnnnn{\ppFolderSimpleDashed}{folder-simple-dashed}{"EC2A}{{5}{19}}{{10}{36}}{{"EC2B}{10}{37}}
\__phosphoricons_def_icon:nnnnnn{\ppFolderSimpleDotted}{folder-simple-dotted}{"EC2A}{{5}{19}}{{10}{36}}{{"EC2B}{10}{37}}
\__phosphoricons_def_icon:nnnnnn{\ppFolderSimpleLock}{folder-simple-lock}{"EB5E}{{4}{228}}{{9}{198}}{{"EB5F}{9}{199}}
\__phosphoricons_def_icon:nnnnnn{\ppFolderSimpleMinus}{folder-simple-minus}{"E25C}{{1}{37}}{{2}{73}}{{"E25D}{2}{74}}
\__phosphoricons_def_icon:nnnnnn{\ppFolderSimplePlus}{folder-simple-plus}{"E25E}{{1}{38}}{{2}{75}}{{"E25F}{2}{76}}
\__phosphoricons_def_icon:nnnnnn{\ppFolderSimpleStar}{folder-simple-star}{"EC2E}{{5}{20}}{{10}{38}}{{"EC2F}{10}{39}}
\__phosphoricons_def_icon:nnnnnn{\ppFolderSimpleUser}{folder-simple-user}{"EB60}{{4}{229}}{{9}{200}}{{"EB61}{9}{201}}
\__phosphoricons_def_icon:nnnnnn{\ppFolderStar}{folder-star}{"EA86}{{4}{138}}{{9}{18}}{{"EA87}{9}{19}}
\__phosphoricons_def_icon:nnnnnn{\ppFolderUser}{folder-user}{"EB46}{{4}{217}}{{9}{174}}{{"EB4C}{9}{180}}
\__phosphoricons_def_icon:nnnnnn{\ppFolders}{folders}{"E260}{{1}{39}}{{2}{77}}{{"E261}{2}{78}}
\__phosphoricons_def_icon:nnnnnn{\ppFootball}{football}{"E718}{{3}{119}}{{6}{236}}{{"E719}{6}{237}}
\__phosphoricons_def_icon:nnnnnn{\ppFootballHelmet}{football-helmet}{"EE4C}{{5}{214}}{{11}{170}}{{"EE4D}{11}{171}}
\__phosphoricons_def_icon:nnnnnn{\ppFootprints}{footprints}{"EA88}{{4}{139}}{{9}{20}}{{"EA89}{9}{21}}
\__phosphoricons_def_icon:nnnnnn{\ppForkKnife}{fork-knife}{"E262}{{1}{40}}{{2}{79}}{{"E263}{2}{80}}
\__phosphoricons_def_icon:nnnnnn{\ppFourK}{four-k}{"EA5C}{{4}{126}}{{8}{250}}{{"EA5D}{8}{251}}
\__phosphoricons_def_icon:nnnnnn{\ppFrameCorners}{frame-corners}{"E626}{{2}{255}}{{5}{252}}{{"E627}{5}{253}}
\__phosphoricons_def_icon:nnnnnn{\ppFramerLogo}{framer-logo}{"E264}{{1}{41}}{{2}{81}}{{"E265}{2}{82}}
\__phosphoricons_def_icon:nnnnnn{\ppFunction}{function}{"EBE4}{{5}{9}}{{10}{16}}{{"EBE5}{10}{17}}
\__phosphoricons_def_icon:nnnnnn{\ppFunnel}{funnel}{"E266}{{1}{42}}{{2}{83}}{{"E267}{2}{84}}
\__phosphoricons_def_icon:nnnnnn{\ppFunnelSimple}{funnel-simple}{"E268}{{1}{43}}{{2}{85}}{{"E269}{2}{86}}
\__phosphoricons_def_icon:nnnnnn{\ppFunnelSimpleX}{funnel-simple-x}{"E26A}{{1}{44}}{{2}{87}}{{"E26B}{2}{88}}
\__phosphoricons_def_icon:nnnnnn{\ppFunnelX}{funnel-x}{"E26C}{{1}{45}}{{2}{89}}{{"E26D}{2}{90}}
\__phosphoricons_def_icon:nnnnnn{\ppGameController}{game-controller}{"E26E}{{1}{46}}{{2}{91}}{{"E26F}{2}{92}}
\__phosphoricons_def_icon:nnnnnn{\ppGarage}{garage}{"ECD6}{{5}{77}}{{10}{152}}{{"ECD7}{10}{153}}
\__phosphoricons_def_icon:nnnnnn{\ppGasCan}{gas-can}{"E8CE}{{4}{22}}{{8}{42}}{{"E8CF}{8}{43}}
\__phosphoricons_def_icon:nnnnnn{\ppGasPump}{gas-pump}{"E768}{{3}{157}}{{7}{56}}{{"E769}{7}{57}}
\__phosphoricons_def_icon:nnnnnn{\ppGauge}{gauge}{"E628}{{3}{0}}{{5}{254}}{{"E629}{5}{255}}
\__phosphoricons_def_icon:nnnnnn{\ppGavel}{gavel}{"EA32}{{4}{111}}{{8}{220}}{{"EA33}{8}{221}}
\__phosphoricons_def_icon:nnnnnn{\ppGear}{gear}{"E270}{{1}{47}}{{2}{93}}{{"E271}{2}{94}}
\__phosphoricons_def_icon:nnnnnn{\ppGearFine}{gear-fine}{"E87C}{{3}{255}}{{7}{252}}{{"E87D}{7}{253}}
\__phosphoricons_def_icon:nnnnnn{\ppGearSix}{gear-six}{"E272}{{1}{48}}{{2}{95}}{{"E273}{2}{96}}
\__phosphoricons_def_icon:nnnnnn{\ppGenderFemale}{gender-female}{"E6E0}{{3}{91}}{{6}{180}}{{"E6E1}{6}{181}}
\__phosphoricons_def_icon:nnnnnn{\ppGenderIntersex}{gender-intersex}{"E6E6}{{3}{94}}{{6}{186}}{{"E6E7}{6}{187}}
\__phosphoricons_def_icon:nnnnnn{\ppGenderMale}{gender-male}{"E6E2}{{3}{92}}{{6}{182}}{{"E6E3}{6}{183}}
\__phosphoricons_def_icon:nnnnnn{\ppGenderNeuter}{gender-neuter}{"E6EA}{{3}{96}}{{6}{190}}{{"E6EB}{6}{191}}
\__phosphoricons_def_icon:nnnnnn{\ppGenderNonbinary}{gender-nonbinary}{"E6E4}{{3}{93}}{{6}{184}}{{"E6E5}{6}{185}}
\__phosphoricons_def_icon:nnnnnn{\ppGenderTransgender}{gender-transgender}{"E6E8}{{3}{95}}{{6}{188}}{{"E6E9}{6}{189}}
\__phosphoricons_def_icon:nnnnnn{\ppGhost}{ghost}{"E62A}{{3}{1}}{{6}{0}}{{"E62B}{6}{1}}
\__phosphoricons_def_icon:nnnnnn{\ppGif}{gif}{"E274}{{1}{49}}{{2}{97}}{{"E275}{2}{98}}
\__phosphoricons_def_icon:nnnnnn{\ppGift}{gift}{"E276}{{1}{50}}{{2}{99}}{{"E277}{2}{100}}
\__phosphoricons_def_icon:nnnnnn{\ppGitBranch}{git-branch}{"E278}{{1}{51}}{{2}{101}}{{"E279}{2}{102}}
\__phosphoricons_def_icon:nnnnnn{\ppGitCommit}{git-commit}{"E27A}{{1}{52}}{{2}{103}}{{"E27B}{2}{104}}
\__phosphoricons_def_icon:nnnnnn{\ppGitDiff}{git-diff}{"E27C}{{1}{53}}{{2}{105}}{{"E27D}{2}{106}}
\__phosphoricons_def_icon:nnnnnn{\ppGitFork}{git-fork}{"E27E}{{1}{54}}{{2}{107}}{{"E27F}{2}{108}}
\__phosphoricons_def_icon:nnnnnn{\ppGitMerge}{git-merge}{"E280}{{1}{55}}{{2}{109}}{{"E281}{2}{110}}
\__phosphoricons_def_icon:nnnnnn{\ppGitPullRequest}{git-pull-request}{"E282}{{1}{56}}{{2}{111}}{{"E283}{2}{112}}
\__phosphoricons_def_icon:nnnnnn{\ppGithubLogo}{github-logo}{"E576}{{2}{168}}{{5}{78}}{{"E577}{5}{79}}
\__phosphoricons_def_icon:nnnnnn{\ppGitlabLogo}{gitlab-logo}{"E694}{{3}{54}}{{6}{106}}{{"E695}{6}{107}}
\__phosphoricons_def_icon:nnnnnn{\ppGitlabLogoSimple}{gitlab-logo-simple}{"E696}{{3}{55}}{{6}{108}}{{"E697}{6}{109}}
\__phosphoricons_def_icon:nnnnnn{\ppGlobe}{globe}{"E288}{{1}{59}}{{2}{117}}{{"E289}{2}{118}}
\__phosphoricons_def_icon:nnnnnn{\ppGlobeHemisphereEast}{globe-hemisphere-east}{"E28A}{{1}{60}}{{2}{119}}{{"E28B}{2}{120}}
\__phosphoricons_def_icon:nnnnnn{\ppGlobeHemisphereWest}{globe-hemisphere-west}{"E28C}{{1}{61}}{{2}{121}}{{"E28D}{2}{122}}
\__phosphoricons_def_icon:nnnnnn{\ppGlobeSimple}{globe-simple}{"E28E}{{1}{62}}{{2}{123}}{{"E28F}{2}{124}}
\__phosphoricons_def_icon:nnnnnn{\ppGlobeSimpleX}{globe-simple-x}{"E284}{{1}{57}}{{2}{113}}{{"E285}{2}{114}}
\__phosphoricons_def_icon:nnnnnn{\ppGlobeStand}{globe-stand}{"E290}{{1}{63}}{{2}{125}}{{"E291}{2}{126}}
\__phosphoricons_def_icon:nnnnnn{\ppGlobeX}{globe-x}{"E286}{{1}{58}}{{2}{115}}{{"E287}{2}{116}}
\__phosphoricons_def_icon:nnnnnn{\ppGoggles}{goggles}{"ECB4}{{5}{62}}{{10}{122}}{{"ECB5}{10}{123}}
\__phosphoricons_def_icon:nnnnnn{\ppGolf}{golf}{"EA3E}{{4}{117}}{{8}{232}}{{"EA3F}{8}{233}}
\__phosphoricons_def_icon:nnnnnn{\ppGoodreadsLogo}{goodreads-logo}{"ED10}{{5}{98}}{{10}{194}}{{"ED11}{10}{195}}
\__phosphoricons_def_icon:nnnnnn{\ppGoogleCardboardLogo}{google-cardboard-logo}{"E7B6}{{3}{185}}{{7}{112}}{{"E7B7}{7}{113}}
\__phosphoricons_def_icon:nnnnnn{\ppGoogleChromeLogo}{google-chrome-logo}{"E976}{{4}{62}}{{8}{122}}{{"E977}{8}{123}}
\__phosphoricons_def_icon:nnnnnn{\ppGoogleDriveLogo}{google-drive-logo}{"E8F6}{{4}{34}}{{8}{66}}{{"E8F7}{8}{67}}
\__phosphoricons_def_icon:nnnnnn{\ppGoogleLogo}{google-logo}{"E292}{{1}{64}}{{2}{127}}{{"E293}{2}{128}}
\__phosphoricons_def_icon:nnnnnn{\ppGooglePhotosLogo}{google-photos-logo}{"EB92}{{4}{242}}{{9}{226}}{{"EB93}{9}{227}}
\__phosphoricons_def_icon:nnnnnn{\ppGooglePlayLogo}{google-play-logo}{"E294}{{1}{65}}{{2}{129}}{{"E295}{2}{130}}
\__phosphoricons_def_icon:nnnnnn{\ppGooglePodcastsLogo}{google-podcasts-logo}{"EB94}{{4}{243}}{{9}{228}}{{"EB95}{9}{229}}
\__phosphoricons_def_icon:nnnnnn{\ppGps}{gps}{"EDD8}{{5}{175}}{{11}{92}}{{"EDD9}{11}{93}}
\__phosphoricons_def_icon:nnnnnn{\ppGpsFix}{gps-fix}{"EDD6}{{5}{174}}{{11}{90}}{{"EDD7}{11}{91}}
\__phosphoricons_def_icon:nnnnnn{\ppGpsSlash}{gps-slash}{"EDD4}{{5}{173}}{{11}{88}}{{"EDD5}{11}{89}}
\__phosphoricons_def_icon:nnnnnn{\ppGradient}{gradient}{"EB42}{{4}{215}}{{9}{170}}{{"EB4D}{9}{181}}
\__phosphoricons_def_icon:nnnnnn{\ppGraduationCap}{graduation-cap}{"E62C}{{3}{2}}{{6}{2}}{{"E62D}{6}{3}}
\__phosphoricons_def_icon:nnnnnn{\ppGrains}{grains}{"EC68}{{5}{34}}{{10}{66}}{{"EC69}{10}{67}}
\__phosphoricons_def_icon:nnnnnn{\ppGrainsSlash}{grains-slash}{"EC6A}{{5}{35}}{{10}{68}}{{"EC6B}{10}{69}}
\__phosphoricons_def_icon:nnnnnn{\ppGraph}{graph}{"EB58}{{4}{225}}{{9}{192}}{{"EB59}{9}{193}}
\__phosphoricons_def_icon:nnnnnn{\ppGraphicsCard}{graphics-card}{"E612}{{2}{245}}{{5}{232}}{{"E613}{5}{233}}
\__phosphoricons_def_icon:nnnnnn{\ppGreaterThan}{greater-than}{"EDC4}{{5}{167}}{{11}{76}}{{"EDC5}{11}{77}}
\__phosphoricons_def_icon:nnnnnn{\ppGreaterThanOrEqual}{greater-than-or-equal}{"EDA2}{{5}{150}}{{11}{42}}{{"EDA3}{11}{43}}
\__phosphoricons_def_icon:nnnnnn{\ppGridFour}{grid-four}{"E296}{{1}{66}}{{2}{131}}{{"E297}{2}{132}}
\__phosphoricons_def_icon:nnnnnn{\ppGridNine}{grid-nine}{"EC8C}{{5}{47}}{{10}{92}}{{"EC8D}{10}{93}}
\__phosphoricons_def_icon:nnnnnn{\ppGuitar}{guitar}{"EA8A}{{4}{140}}{{9}{22}}{{"EA8B}{9}{23}}
\__phosphoricons_def_icon:nnnnnn{\ppHairDryer}{hair-dryer}{"EA66}{{4}{129}}{{9}{0}}{{"EA67}{9}{1}}
\__phosphoricons_def_icon:nnnnnn{\ppHamburger}{hamburger}{"E790}{{3}{170}}{{7}{82}}{{"E791}{7}{83}}
\__phosphoricons_def_icon:nnnnnn{\ppHammer}{hammer}{"E80E}{{3}{221}}{{7}{184}}{{"E80F}{7}{185}}
\__phosphoricons_def_icon:nnnnnn{\ppHand}{hand}{"E298}{{1}{67}}{{2}{133}}{{"E299}{2}{134}}
\__phosphoricons_def_icon:nnnnnn{\ppHandArrowDown}{hand-arrow-down}{"EA4E}{{4}{124}}{{8}{246}}{{"EA4F}{8}{247}}
\__phosphoricons_def_icon:nnnnnn{\ppHandArrowUp}{hand-arrow-up}{"EE5A}{{5}{221}}{{11}{184}}{{"EE5B}{11}{185}}
\__phosphoricons_def_icon:nnnnnn{\ppHandCoins}{hand-coins}{"EA8C}{{4}{141}}{{9}{24}}{{"EA8D}{9}{25}}
\__phosphoricons_def_icon:nnnnnn{\ppHandDeposit}{hand-deposit}{"EE82}{{5}{231}}{{11}{204}}{{"EE83}{11}{205}}
\__phosphoricons_def_icon:nnnnnn{\ppHandEye}{hand-eye}{"EA4C}{{4}{123}}{{8}{244}}{{"EA4D}{8}{245}}
\__phosphoricons_def_icon:nnnnnn{\ppHandFist}{hand-fist}{"E57A}{{2}{169}}{{5}{80}}{{"E57B}{5}{81}}
\__phosphoricons_def_icon:nnnnnn{\ppHandGrabbing}{hand-grabbing}{"E57C}{{2}{170}}{{5}{82}}{{"E57D}{5}{83}}
\__phosphoricons_def_icon:nnnnnn{\ppHandHeart}{hand-heart}{"E810}{{3}{222}}{{7}{186}}{{"E811}{7}{187}}
\__phosphoricons_def_icon:nnnnnn{\ppHandPalm}{hand-palm}{"E57E}{{2}{171}}{{5}{84}}{{"E57F}{5}{85}}
\__phosphoricons_def_icon:nnnnnn{\ppHandPeace}{hand-peace}{"E7CC}{{3}{195}}{{7}{132}}{{"E7CD}{7}{133}}
\__phosphoricons_def_icon:nnnnnn{\ppHandPointing}{hand-pointing}{"E29A}{{1}{68}}{{2}{135}}{{"E29B}{2}{136}}
\__phosphoricons_def_icon:nnnnnn{\ppHandSoap}{hand-soap}{"E630}{{3}{4}}{{6}{6}}{{"E631}{6}{7}}
\__phosphoricons_def_icon:nnnnnn{\ppHandSwipeLeft}{hand-swipe-left}{"EC94}{{5}{51}}{{10}{100}}{{"EC95}{10}{101}}
\__phosphoricons_def_icon:nnnnnn{\ppHandSwipeRight}{hand-swipe-right}{"EC92}{{5}{50}}{{10}{98}}{{"EC93}{10}{99}}
\__phosphoricons_def_icon:nnnnnn{\ppHandTap}{hand-tap}{"EC90}{{5}{49}}{{10}{96}}{{"EC91}{10}{97}}
\__phosphoricons_def_icon:nnnnnn{\ppHandWaving}{hand-waving}{"E580}{{2}{172}}{{5}{86}}{{"E581}{5}{87}}
\__phosphoricons_def_icon:nnnnnn{\ppHandWithdraw}{hand-withdraw}{"EE80}{{5}{230}}{{11}{202}}{{"EE81}{11}{203}}
\__phosphoricons_def_icon:nnnnnn{\ppHandbag}{handbag}{"E29C}{{1}{69}}{{2}{137}}{{"E29D}{2}{138}}
\__phosphoricons_def_icon:nnnnnn{\ppHandbagSimple}{handbag-simple}{"E62E}{{3}{3}}{{6}{4}}{{"E62F}{6}{5}}
\__phosphoricons_def_icon:nnnnnn{\ppHandsClapping}{hands-clapping}{"E6A0}{{3}{60}}{{6}{118}}{{"E6A1}{6}{119}}
\__phosphoricons_def_icon:nnnnnn{\ppHandsPraying}{hands-praying}{"ECC8}{{5}{72}}{{10}{142}}{{"ECC9}{10}{143}}
\__phosphoricons_def_icon:nnnnnn{\ppHandshake}{handshake}{"E582}{{2}{173}}{{5}{88}}{{"E583}{5}{89}}
\__phosphoricons_def_icon:nnnnnn{\ppHardDrive}{hard-drive}{"E29E}{{1}{70}}{{2}{139}}{{"E29F}{2}{140}}
\__phosphoricons_def_icon:nnnnnn{\ppHardDrives}{hard-drives}{"E2A0}{{1}{71}}{{2}{141}}{{"E2A1}{2}{142}}
\__phosphoricons_def_icon:nnnnnn{\ppHardHat}{hard-hat}{"ED46}{{5}{115}}{{10}{228}}{{"ED47}{10}{229}}
\__phosphoricons_def_icon:nnnnnn{\ppHash}{hash}{"E2A2}{{1}{72}}{{2}{143}}{{"E2A3}{2}{144}}
\__phosphoricons_def_icon:nnnnnn{\ppHashStraight}{hash-straight}{"E2A4}{{1}{73}}{{2}{145}}{{"E2A5}{2}{146}}
\__phosphoricons_def_icon:nnnnnn{\ppHeadCircuit}{head-circuit}{"E7D4}{{3}{199}}{{7}{140}}{{"E7D5}{7}{141}}
\__phosphoricons_def_icon:nnnnnn{\ppHeadlights}{headlights}{"E6FE}{{3}{106}}{{6}{210}}{{"E6FF}{6}{211}}
\__phosphoricons_def_icon:nnnnnn{\ppHeadphones}{headphones}{"E2A6}{{1}{74}}{{2}{147}}{{"E2A7}{2}{148}}
\__phosphoricons_def_icon:nnnnnn{\ppHeadset}{headset}{"E584}{{2}{174}}{{5}{90}}{{"E585}{5}{91}}
\__phosphoricons_def_icon:nnnnnn{\ppHeart}{heart}{"E2A8}{{1}{75}}{{2}{149}}{{"E2A9}{2}{150}}
\__phosphoricons_def_icon:nnnnnn{\ppHeartBreak}{heart-break}{"EBE8}{{5}{11}}{{10}{20}}{{"EBE9}{10}{21}}
\__phosphoricons_def_icon:nnnnnn{\ppHeartHalf}{heart-half}{"EC48}{{5}{24}}{{10}{46}}{{"EC49}{10}{47}}
\__phosphoricons_def_icon:nnnnnn{\ppHeartStraight}{heart-straight}{"E2AA}{{1}{76}}{{2}{151}}{{"E2AB}{2}{152}}
\__phosphoricons_def_icon:nnnnnn{\ppHeartStraightBreak}{heart-straight-break}{"EB98}{{4}{245}}{{9}{232}}{{"EB99}{9}{233}}
\__phosphoricons_def_icon:nnnnnn{\ppHeartbeat}{heartbeat}{"E2AC}{{1}{77}}{{2}{153}}{{"E2AD}{2}{154}}
\__phosphoricons_def_icon:nnnnnn{\ppHexagon}{hexagon}{"E2AE}{{1}{78}}{{2}{155}}{{"E2AF}{2}{156}}
\__phosphoricons_def_icon:nnnnnn{\ppHighDefinition}{high-definition}{"EA8E}{{4}{142}}{{9}{26}}{{"EA8F}{9}{27}}
\__phosphoricons_def_icon:nnnnnn{\ppHighHeel}{high-heel}{"E8E8}{{4}{30}}{{8}{58}}{{"E8E9}{8}{59}}
\__phosphoricons_def_icon:nnnnnn{\ppHighlighter}{highlighter}{"EC76}{{5}{40}}{{10}{78}}{{"EC77}{10}{79}}
\__phosphoricons_def_icon:nnnnnn{\ppHighlighterCircle}{highlighter-circle}{"E632}{{3}{5}}{{6}{8}}{{"E633}{6}{9}}
\__phosphoricons_def_icon:nnnnnn{\ppHockey}{hockey}{"EC86}{{5}{45}}{{10}{88}}{{"EC87}{10}{89}}
\__phosphoricons_def_icon:nnnnnn{\ppHoodie}{hoodie}{"ECD0}{{5}{75}}{{10}{148}}{{"ECD1}{10}{149}}
\__phosphoricons_def_icon:nnnnnn{\ppHorse}{horse}{"E2B0}{{1}{79}}{{2}{157}}{{"E2B1}{2}{158}}
\__phosphoricons_def_icon:nnnnnn{\ppHospital}{hospital}{"E844}{{3}{242}}{{7}{226}}{{"E845}{7}{227}}
\__phosphoricons_def_icon:nnnnnn{\ppHourglass}{hourglass}{"E2B2}{{1}{80}}{{2}{159}}{{"E2B3}{2}{160}}
\__phosphoricons_def_icon:nnnnnn{\ppHourglassHigh}{hourglass-high}{"E2B4}{{1}{81}}{{2}{161}}{{"E2B5}{2}{162}}
\__phosphoricons_def_icon:nnnnnn{\ppHourglassLow}{hourglass-low}{"E2B6}{{1}{82}}{{2}{163}}{{"E2B7}{2}{164}}
\__phosphoricons_def_icon:nnnnnn{\ppHourglassMedium}{hourglass-medium}{"E2B8}{{1}{83}}{{2}{165}}{{"E2B9}{2}{166}}
\__phosphoricons_def_icon:nnnnnn{\ppHourglassSimple}{hourglass-simple}{"E2BA}{{1}{84}}{{2}{167}}{{"E2BB}{2}{168}}
\__phosphoricons_def_icon:nnnnnn{\ppHourglassSimpleHigh}{hourglass-simple-high}{"E2BC}{{1}{85}}{{2}{169}}{{"E2BD}{2}{170}}
\__phosphoricons_def_icon:nnnnnn{\ppHourglassSimpleLow}{hourglass-simple-low}{"E2BE}{{1}{86}}{{2}{171}}{{"E2BF}{2}{172}}
\__phosphoricons_def_icon:nnnnnn{\ppHourglassSimpleMedium}{hourglass-simple-medium}{"E2C0}{{1}{87}}{{2}{173}}{{"E2C1}{2}{174}}
\__phosphoricons_def_icon:nnnnnn{\ppHouse}{house}{"E2C2}{{1}{88}}{{2}{175}}{{"E2C3}{2}{176}}
\__phosphoricons_def_icon:nnnnnn{\ppHouseLine}{house-line}{"E2C4}{{1}{89}}{{2}{177}}{{"E2C5}{2}{178}}
\__phosphoricons_def_icon:nnnnnn{\ppHouseSimple}{house-simple}{"E2C6}{{1}{90}}{{2}{179}}{{"E2C7}{2}{180}}
\__phosphoricons_def_icon:nnnnnn{\ppHurricane}{hurricane}{"E88E}{{4}{4}}{{8}{6}}{{"E88F}{8}{7}}
\__phosphoricons_def_icon:nnnnnn{\ppIceCream}{ice-cream}{"E804}{{3}{216}}{{7}{174}}{{"E805}{7}{175}}
\__phosphoricons_def_icon:nnnnnn{\ppIdentificationBadge}{identification-badge}{"E6F6}{{3}{102}}{{6}{202}}{{"E6F7}{6}{203}}
\__phosphoricons_def_icon:nnnnnn{\ppIdentificationCard}{identification-card}{"E2C8}{{1}{91}}{{2}{181}}{{"E2C9}{2}{182}}
\__phosphoricons_def_icon:nnnnnn{\ppImage}{image}{"E2CA}{{1}{92}}{{2}{183}}{{"E2CB}{2}{184}}
\__phosphoricons_def_icon:nnnnnn{\ppImageBroken}{image-broken}{"E7A8}{{3}{180}}{{7}{102}}{{"E7A9}{7}{103}}
\__phosphoricons_def_icon:nnnnnn{\ppImageSquare}{image-square}{"E2CC}{{1}{93}}{{2}{185}}{{"E2CD}{2}{186}}
\__phosphoricons_def_icon:nnnnnn{\ppImages}{images}{"E836}{{3}{237}}{{7}{216}}{{"E837}{7}{217}}
\__phosphoricons_def_icon:nnnnnn{\ppImagesSquare}{images-square}{"E834}{{3}{236}}{{7}{214}}{{"E835}{7}{215}}
\__phosphoricons_def_icon:nnnnnn{\ppInfinity}{infinity}{"E634}{{3}{6}}{{6}{10}}{{"E635}{6}{11}}
\__phosphoricons_def_icon:nnnnnn{\ppInfo}{info}{"E2CE}{{1}{94}}{{2}{187}}{{"E2CF}{2}{188}}
\__phosphoricons_def_icon:nnnnnn{\ppInstagramLogo}{instagram-logo}{"E2D0}{{1}{95}}{{2}{189}}{{"E2D1}{2}{190}}
\__phosphoricons_def_icon:nnnnnn{\ppIntersect}{intersect}{"E2D2}{{1}{96}}{{2}{191}}{{"E2D3}{2}{192}}
\__phosphoricons_def_icon:nnnnnn{\ppIntersectSquare}{intersect-square}{"E87A}{{3}{254}}{{7}{250}}{{"E87B}{7}{251}}
\__phosphoricons_def_icon:nnnnnn{\ppIntersectThree}{intersect-three}{"ECC4}{{5}{70}}{{10}{138}}{{"ECC5}{10}{139}}
\__phosphoricons_def_icon:nnnnnn{\ppIntersection}{intersection}{"EDBA}{{5}{162}}{{11}{66}}{{"EDBB}{11}{67}}
\__phosphoricons_def_icon:nnnnnn{\ppInvoice}{invoice}{"EE42}{{5}{209}}{{11}{160}}{{"EE43}{11}{161}}
\__phosphoricons_def_icon:nnnnnn{\ppIsland}{island}{"EE06}{{5}{191}}{{11}{124}}{{"EE07}{11}{125}}
\__phosphoricons_def_icon:nnnnnn{\ppJar}{jar}{"E7E0}{{3}{203}}{{7}{148}}{{"E7E3}{7}{151}}
\__phosphoricons_def_icon:nnnnnn{\ppJarLabel}{jar-label}{"E7E1}{{3}{204}}{{7}{149}}{{"E7E5}{7}{153}}
\__phosphoricons_def_icon:nnnnnn{\ppJeep}{jeep}{"E2D4}{{1}{97}}{{2}{193}}{{"E2D5}{2}{194}}
\__phosphoricons_def_icon:nnnnnn{\ppJoystick}{joystick}{"EA5E}{{4}{127}}{{8}{252}}{{"EA5F}{8}{253}}
\__phosphoricons_def_icon:nnnnnn{\ppKanban}{kanban}{"EB54}{{4}{223}}{{9}{188}}{{"EB55}{9}{189}}
\__phosphoricons_def_icon:nnnnnn{\ppKey}{key}{"E2D6}{{1}{98}}{{2}{195}}{{"E2D7}{2}{196}}
\__phosphoricons_def_icon:nnnnnn{\ppKeyReturn}{key-return}{"E782}{{3}{165}}{{7}{72}}{{"E783}{7}{73}}
\__phosphoricons_def_icon:nnnnnn{\ppKeyboard}{keyboard}{"E2D8}{{1}{99}}{{2}{197}}{{"E2D9}{2}{198}}
\__phosphoricons_def_icon:nnnnnn{\ppKeyhole}{keyhole}{"EA78}{{4}{133}}{{9}{8}}{{"EA79}{9}{9}}
\__phosphoricons_def_icon:nnnnnn{\ppKnife}{knife}{"E636}{{3}{7}}{{6}{12}}{{"E637}{6}{13}}
\__phosphoricons_def_icon:nnnnnn{\ppLadder}{ladder}{"E9E4}{{4}{84}}{{8}{166}}{{"E9E5}{8}{167}}
\__phosphoricons_def_icon:nnnnnn{\ppLadderSimple}{ladder-simple}{"EC26}{{5}{18}}{{10}{34}}{{"EC27}{10}{35}}
\__phosphoricons_def_icon:nnnnnn{\ppLamp}{lamp}{"E638}{{3}{8}}{{6}{14}}{{"E639}{6}{15}}
\__phosphoricons_def_icon:nnnnnn{\ppLampPendant}{lamp-pendant}{"EE2E}{{5}{199}}{{11}{140}}{{"EE2F}{11}{141}}
\__phosphoricons_def_icon:nnnnnn{\ppLaptop}{laptop}{"E586}{{2}{175}}{{5}{92}}{{"E587}{5}{93}}
\__phosphoricons_def_icon:nnnnnn{\ppLasso}{lasso}{"EDC6}{{5}{168}}{{11}{78}}{{"EDC7}{11}{79}}
\__phosphoricons_def_icon:nnnnnn{\ppLastfmLogo}{lastfm-logo}{"E842}{{3}{241}}{{7}{224}}{{"E843}{7}{225}}
\__phosphoricons_def_icon:nnnnnn{\ppLayout}{layout}{"E6D6}{{3}{86}}{{6}{170}}{{"E6D7}{6}{171}}
\__phosphoricons_def_icon:nnnnnn{\ppLeaf}{leaf}{"E2DA}{{1}{100}}{{2}{199}}{{"E2DB}{2}{200}}
\__phosphoricons_def_icon:nnnnnn{\ppLectern}{lectern}{"E95A}{{4}{54}}{{8}{106}}{{"E95B}{8}{107}}
\__phosphoricons_def_icon:nnnnnn{\ppLego}{lego}{"E8C6}{{4}{19}}{{8}{36}}{{"E8C8}{8}{38}}
\__phosphoricons_def_icon:nnnnnn{\ppLegoSmiley}{lego-smiley}{"E8C7}{{4}{20}}{{8}{37}}{{"E8C9}{8}{39}}
\__phosphoricons_def_icon:nnnnnn{\ppLemniscate}{lemniscate}{"E634}{{3}{6}}{{6}{10}}{{"E635}{6}{11}}
\__phosphoricons_def_icon:nnnnnn{\ppLessThan}{less-than}{"EDAC}{{5}{155}}{{11}{52}}{{"EDAD}{11}{53}}
\__phosphoricons_def_icon:nnnnnn{\ppLessThanOrEqual}{less-than-or-equal}{"EDA4}{{5}{151}}{{11}{44}}{{"EDA5}{11}{45}}
\__phosphoricons_def_icon:nnnnnn{\ppLetterCircleH}{letter-circle-h}{"EBF8}{{5}{12}}{{10}{22}}{{"EBF9}{10}{23}}
\__phosphoricons_def_icon:nnnnnn{\ppLetterCircleP}{letter-circle-p}{"EC08}{{5}{13}}{{10}{24}}{{"EC09}{10}{25}}
\__phosphoricons_def_icon:nnnnnn{\ppLetterCircleV}{letter-circle-v}{"EC14}{{5}{14}}{{10}{26}}{{"EC15}{10}{27}}
\__phosphoricons_def_icon:nnnnnn{\ppLifebuoy}{lifebuoy}{"E63A}{{3}{9}}{{6}{16}}{{"E63B}{6}{17}}
\__phosphoricons_def_icon:nnnnnn{\ppLightbulb}{lightbulb}{"E2DC}{{1}{101}}{{2}{201}}{{"E2DD}{2}{202}}
\__phosphoricons_def_icon:nnnnnn{\ppLightbulbFilament}{lightbulb-filament}{"E63C}{{3}{10}}{{6}{18}}{{"E63D}{6}{19}}
\__phosphoricons_def_icon:nnnnnn{\ppLighthouse}{lighthouse}{"E9F6}{{4}{91}}{{8}{180}}{{"E9F7}{8}{181}}
\__phosphoricons_def_icon:nnnnnn{\ppLightning}{lightning}{"E2DE}{{1}{102}}{{2}{203}}{{"E2DF}{2}{204}}
\__phosphoricons_def_icon:nnnnnn{\ppLightningA}{lightning-a}{"EA84}{{4}{137}}{{9}{16}}{{"EA85}{9}{17}}
\__phosphoricons_def_icon:nnnnnn{\ppLightningSlash}{lightning-slash}{"E2E0}{{1}{103}}{{2}{205}}{{"E2E1}{2}{206}}
\__phosphoricons_def_icon:nnnnnn{\ppLineSegment}{line-segment}{"E6D2}{{3}{84}}{{6}{166}}{{"E6D3}{6}{167}}
\__phosphoricons_def_icon:nnnnnn{\ppLineSegments}{line-segments}{"E6D4}{{3}{85}}{{6}{168}}{{"E6D5}{6}{169}}
\__phosphoricons_def_icon:nnnnnn{\ppLineVertical}{line-vertical}{"ED70}{{5}{133}}{{11}{8}}{{"ED71}{11}{9}}
\__phosphoricons_def_icon:nnnnnn{\ppLink}{link}{"E2E2}{{1}{104}}{{2}{207}}{{"E2E3}{2}{208}}
\__phosphoricons_def_icon:nnnnnn{\ppLinkBreak}{link-break}{"E2E4}{{1}{105}}{{2}{209}}{{"E2E5}{2}{210}}
\__phosphoricons_def_icon:nnnnnn{\ppLinkSimple}{link-simple}{"E2E6}{{1}{106}}{{2}{211}}{{"E2E7}{2}{212}}
\__phosphoricons_def_icon:nnnnnn{\ppLinkSimpleBreak}{link-simple-break}{"E2E8}{{1}{107}}{{2}{213}}{{"E2E9}{2}{214}}
\__phosphoricons_def_icon:nnnnnn{\ppLinkSimpleHorizontal}{link-simple-horizontal}{"E2EA}{{1}{108}}{{2}{215}}{{"E2EB}{2}{216}}
\__phosphoricons_def_icon:nnnnnn{\ppLinkSimpleHorizontalBreak}{link-simple-horizontal-break}{"E2EC}{{1}{109}}{{2}{217}}{{"E2ED}{2}{218}}
\__phosphoricons_def_icon:nnnnnn{\ppLinkedinLogo}{linkedin-logo}{"E2EE}{{1}{110}}{{2}{219}}{{"E2EF}{2}{220}}
\__phosphoricons_def_icon:nnnnnn{\ppLinktreeLogo}{linktree-logo}{"EDEE}{{5}{184}}{{11}{110}}{{"EDEF}{11}{111}}
\__phosphoricons_def_icon:nnnnnn{\ppLinuxLogo}{linux-logo}{"EB02}{{4}{182}}{{9}{106}}{{"EB03}{9}{107}}
\__phosphoricons_def_icon:nnnnnn{\ppList}{list}{"E2F0}{{1}{111}}{{2}{221}}{{"E2F1}{2}{222}}
\__phosphoricons_def_icon:nnnnnn{\ppListBullets}{list-bullets}{"E2F2}{{1}{112}}{{2}{223}}{{"E2F3}{2}{224}}
\__phosphoricons_def_icon:nnnnnn{\ppListChecks}{list-checks}{"EADC}{{4}{167}}{{9}{76}}{{"EADD}{9}{77}}
\__phosphoricons_def_icon:nnnnnn{\ppListDashes}{list-dashes}{"E2F4}{{1}{113}}{{2}{225}}{{"E2F5}{2}{226}}
\__phosphoricons_def_icon:nnnnnn{\ppListHeart}{list-heart}{"EBDE}{{5}{7}}{{10}{12}}{{"EBDF}{10}{13}}
\__phosphoricons_def_icon:nnnnnn{\ppListMagnifyingGlass}{list-magnifying-glass}{"EBE0}{{5}{8}}{{10}{14}}{{"EBE1}{10}{15}}
\__phosphoricons_def_icon:nnnnnn{\ppListNumbers}{list-numbers}{"E2F6}{{1}{114}}{{2}{227}}{{"E2F7}{2}{228}}
\__phosphoricons_def_icon:nnnnnn{\ppListPlus}{list-plus}{"E2F8}{{1}{115}}{{2}{229}}{{"E2F9}{2}{230}}
\__phosphoricons_def_icon:nnnnnn{\ppListStar}{list-star}{"EBDC}{{5}{6}}{{10}{10}}{{"EBDD}{10}{11}}
\__phosphoricons_def_icon:nnnnnn{\ppLock}{lock}{"E2FA}{{1}{116}}{{2}{231}}{{"E2FB}{2}{232}}
\__phosphoricons_def_icon:nnnnnn{\ppLockKey}{lock-key}{"E2FE}{{1}{117}}{{2}{233}}{{"E2FF}{2}{234}}
\__phosphoricons_def_icon:nnnnnn{\ppLockKeyOpen}{lock-key-open}{"E300}{{1}{118}}{{2}{235}}{{"E301}{2}{236}}
\__phosphoricons_def_icon:nnnnnn{\ppLockLaminated}{lock-laminated}{"E302}{{1}{119}}{{2}{237}}{{"E303}{2}{238}}
\__phosphoricons_def_icon:nnnnnn{\ppLockLaminatedOpen}{lock-laminated-open}{"E304}{{1}{120}}{{2}{239}}{{"E305}{2}{240}}
\__phosphoricons_def_icon:nnnnnn{\ppLockOpen}{lock-open}{"E306}{{1}{121}}{{2}{241}}{{"E307}{2}{242}}
\__phosphoricons_def_icon:nnnnnn{\ppLockSimple}{lock-simple}{"E308}{{1}{122}}{{2}{243}}{{"E309}{2}{244}}
\__phosphoricons_def_icon:nnnnnn{\ppLockSimpleOpen}{lock-simple-open}{"E30A}{{1}{123}}{{2}{245}}{{"E30B}{2}{246}}
\__phosphoricons_def_icon:nnnnnn{\ppLockers}{lockers}{"ECB8}{{5}{64}}{{10}{126}}{{"ECB9}{10}{127}}
\__phosphoricons_def_icon:nnnnnn{\ppLog}{log}{"ED82}{{5}{139}}{{11}{20}}{{"ED83}{11}{21}}
\__phosphoricons_def_icon:nnnnnn{\ppMagicWand}{magic-wand}{"E6B6}{{3}{70}}{{6}{138}}{{"E6B7}{6}{139}}
\__phosphoricons_def_icon:nnnnnn{\ppMagnet}{magnet}{"E680}{{3}{44}}{{6}{86}}{{"E681}{6}{87}}
\__phosphoricons_def_icon:nnnnnn{\ppMagnetStraight}{magnet-straight}{"E682}{{3}{45}}{{6}{88}}{{"E683}{6}{89}}
\__phosphoricons_def_icon:nnnnnn{\ppMagnifyingGlass}{magnifying-glass}{"E30C}{{1}{124}}{{2}{247}}{{"E30D}{2}{248}}
\__phosphoricons_def_icon:nnnnnn{\ppMagnifyingGlassMinus}{magnifying-glass-minus}{"E30E}{{1}{125}}{{2}{249}}{{"E30F}{2}{250}}
\__phosphoricons_def_icon:nnnnnn{\ppMagnifyingGlassPlus}{magnifying-glass-plus}{"E310}{{1}{126}}{{2}{251}}{{"E311}{2}{252}}
\__phosphoricons_def_icon:nnnnnn{\ppMailbox}{mailbox}{"EC1E}{{5}{15}}{{10}{28}}{{"EC1F}{10}{29}}
\__phosphoricons_def_icon:nnnnnn{\ppMapPin}{map-pin}{"E316}{{1}{128}}{{2}{255}}{{"E317}{3}{0}}
\__phosphoricons_def_icon:nnnnnn{\ppMapPinArea}{map-pin-area}{"EE3A}{{5}{205}}{{11}{152}}{{"EE3B}{11}{153}}
\__phosphoricons_def_icon:nnnnnn{\ppMapPinLine}{map-pin-line}{"E318}{{1}{129}}{{3}{1}}{{"E319}{3}{2}}
\__phosphoricons_def_icon:nnnnnn{\ppMapPinPlus}{map-pin-plus}{"E314}{{1}{127}}{{2}{253}}{{"E315}{2}{254}}
\__phosphoricons_def_icon:nnnnnn{\ppMapPinSimple}{map-pin-simple}{"EE3E}{{5}{207}}{{11}{156}}{{"EE3F}{11}{157}}
\__phosphoricons_def_icon:nnnnnn{\ppMapPinSimpleArea}{map-pin-simple-area}{"EE3C}{{5}{206}}{{11}{154}}{{"EE3D}{11}{155}}
\__phosphoricons_def_icon:nnnnnn{\ppMapPinSimpleLine}{map-pin-simple-line}{"EE38}{{5}{204}}{{11}{150}}{{"EE39}{11}{151}}
\__phosphoricons_def_icon:nnnnnn{\ppMapTrifold}{map-trifold}{"E31A}{{1}{130}}{{3}{3}}{{"E31B}{3}{4}}
\__phosphoricons_def_icon:nnnnnn{\ppMarkdownLogo}{markdown-logo}{"E508}{{2}{113}}{{4}{224}}{{"E509}{4}{225}}
\__phosphoricons_def_icon:nnnnnn{\ppMarkerCircle}{marker-circle}{"E640}{{3}{12}}{{6}{22}}{{"E641}{6}{23}}
\__phosphoricons_def_icon:nnnnnn{\ppMartini}{martini}{"E31C}{{1}{131}}{{3}{5}}{{"E31D}{3}{6}}
\__phosphoricons_def_icon:nnnnnn{\ppMaskHappy}{mask-happy}{"E9F4}{{4}{90}}{{8}{178}}{{"E9F5}{8}{179}}
\__phosphoricons_def_icon:nnnnnn{\ppMaskSad}{mask-sad}{"EB9E}{{4}{248}}{{9}{238}}{{"EB9F}{9}{239}}
\__phosphoricons_def_icon:nnnnnn{\ppMastodonLogo}{mastodon-logo}{"ED68}{{5}{129}}{{11}{0}}{{"ED69}{11}{1}}
\__phosphoricons_def_icon:nnnnnn{\ppMathOperations}{math-operations}{"E31E}{{1}{132}}{{3}{7}}{{"E31F}{3}{8}}
\__phosphoricons_def_icon:nnnnnn{\ppMatrixLogo}{matrix-logo}{"ED64}{{5}{127}}{{10}{252}}{{"ED65}{10}{253}}
\__phosphoricons_def_icon:nnnnnn{\ppMedal}{medal}{"E320}{{1}{133}}{{3}{9}}{{"E321}{3}{10}}
\__phosphoricons_def_icon:nnnnnn{\ppMedalMilitary}{medal-military}{"ECFC}{{5}{91}}{{10}{180}}{{"ECFD}{10}{181}}
\__phosphoricons_def_icon:nnnnnn{\ppMediumLogo}{medium-logo}{"E322}{{1}{134}}{{3}{11}}{{"E323}{3}{12}}
\__phosphoricons_def_icon:nnnnnn{\ppMegaphone}{megaphone}{"E324}{{1}{135}}{{3}{13}}{{"E325}{3}{14}}
\__phosphoricons_def_icon:nnnnnn{\ppMegaphoneSimple}{megaphone-simple}{"E642}{{3}{13}}{{6}{24}}{{"E643}{6}{25}}
\__phosphoricons_def_icon:nnnnnn{\ppMemberOf}{member-of}{"EDC2}{{5}{166}}{{11}{74}}{{"EDC3}{11}{75}}
\__phosphoricons_def_icon:nnnnnn{\ppMemory}{memory}{"E9C4}{{4}{76}}{{8}{150}}{{"E9C5}{8}{151}}
\__phosphoricons_def_icon:nnnnnn{\ppMessengerLogo}{messenger-logo}{"E6D8}{{3}{87}}{{6}{172}}{{"E6D9}{6}{173}}
\__phosphoricons_def_icon:nnnnnn{\ppMetaLogo}{meta-logo}{"ED02}{{5}{93}}{{10}{184}}{{"ED03}{10}{185}}
\__phosphoricons_def_icon:nnnnnn{\ppMeteor}{meteor}{"E9BA}{{4}{73}}{{8}{144}}{{"E9BB}{8}{145}}
\__phosphoricons_def_icon:nnnnnn{\ppMetronome}{metronome}{"EC8E}{{5}{48}}{{10}{94}}{{"EC8F}{10}{95}}
\__phosphoricons_def_icon:nnnnnn{\ppMicrophone}{microphone}{"E326}{{1}{136}}{{3}{15}}{{"E327}{3}{16}}
\__phosphoricons_def_icon:nnnnnn{\ppMicrophoneSlash}{microphone-slash}{"E328}{{1}{137}}{{3}{17}}{{"E329}{3}{18}}
\__phosphoricons_def_icon:nnnnnn{\ppMicrophoneStage}{microphone-stage}{"E75C}{{3}{151}}{{7}{44}}{{"E75D}{7}{45}}
\__phosphoricons_def_icon:nnnnnn{\ppMicroscope}{microscope}{"EC7A}{{5}{41}}{{10}{80}}{{"EC7B}{10}{81}}
\__phosphoricons_def_icon:nnnnnn{\ppMicrosoftExcelLogo}{microsoft-excel-logo}{"EB6C}{{4}{234}}{{9}{210}}{{"EB6D}{9}{211}}
\__phosphoricons_def_icon:nnnnnn{\ppMicrosoftOutlookLogo}{microsoft-outlook-logo}{"EB70}{{4}{235}}{{9}{212}}{{"EB71}{9}{213}}
\__phosphoricons_def_icon:nnnnnn{\ppMicrosoftPowerpointLogo}{microsoft-powerpoint-logo}{"EACE}{{4}{164}}{{9}{70}}{{"EACF}{9}{71}}
\__phosphoricons_def_icon:nnnnnn{\ppMicrosoftTeamsLogo}{microsoft-teams-logo}{"EB66}{{4}{232}}{{9}{206}}{{"EB67}{9}{207}}
\__phosphoricons_def_icon:nnnnnn{\ppMicrosoftWordLogo}{microsoft-word-logo}{"EB6A}{{4}{233}}{{9}{208}}{{"EB6B}{9}{209}}
\__phosphoricons_def_icon:nnnnnn{\ppMinus}{minus}{"E32A}{{1}{138}}{{3}{19}}{{"E32B}{3}{20}}
\__phosphoricons_def_icon:nnnnnn{\ppMinusCircle}{minus-circle}{"E32C}{{1}{139}}{{3}{21}}{{"E32D}{3}{22}}
\__phosphoricons_def_icon:nnnnnn{\ppMinusSquare}{minus-square}{"ED4C}{{5}{119}}{{10}{234}}{{"ED53}{10}{241}}
\__phosphoricons_def_icon:nnnnnn{\ppMoney}{money}{"E588}{{2}{176}}{{5}{94}}{{"E589}{5}{95}}
\__phosphoricons_def_icon:nnnnnn{\ppMoneyWavy}{money-wavy}{"EE68}{{5}{228}}{{11}{198}}{{"EE69}{11}{199}}
\__phosphoricons_def_icon:nnnnnn{\ppMonitor}{monitor}{"E32E}{{1}{140}}{{3}{23}}{{"E32F}{3}{24}}
\__phosphoricons_def_icon:nnnnnn{\ppMonitorArrowUp}{monitor-arrow-up}{"E58A}{{2}{177}}{{5}{96}}{{"E58B}{5}{97}}
\__phosphoricons_def_icon:nnnnnn{\ppMonitorPlay}{monitor-play}{"E58C}{{2}{178}}{{5}{98}}{{"E58D}{5}{99}}
\__phosphoricons_def_icon:nnnnnn{\ppMoon}{moon}{"E330}{{1}{141}}{{3}{25}}{{"E331}{3}{26}}
\__phosphoricons_def_icon:nnnnnn{\ppMoonStars}{moon-stars}{"E58E}{{2}{179}}{{5}{100}}{{"E58F}{5}{101}}
\__phosphoricons_def_icon:nnnnnn{\ppMoped}{moped}{"E824}{{3}{231}}{{7}{204}}{{"E825}{7}{205}}
\__phosphoricons_def_icon:nnnnnn{\ppMopedFront}{moped-front}{"E822}{{3}{230}}{{7}{202}}{{"E823}{7}{203}}
\__phosphoricons_def_icon:nnnnnn{\ppMosque}{mosque}{"ECEE}{{5}{84}}{{10}{166}}{{"ECEF}{10}{167}}
\__phosphoricons_def_icon:nnnnnn{\ppMotorcycle}{motorcycle}{"E80A}{{3}{219}}{{7}{180}}{{"E80B}{7}{181}}
\__phosphoricons_def_icon:nnnnnn{\ppMountains}{mountains}{"E7AE}{{3}{181}}{{7}{104}}{{"E7AF}{7}{105}}
\__phosphoricons_def_icon:nnnnnn{\ppMouse}{mouse}{"E33A}{{1}{146}}{{3}{35}}{{"E33B}{3}{36}}
\__phosphoricons_def_icon:nnnnnn{\ppMouseLeftClick}{mouse-left-click}{"E334}{{1}{143}}{{3}{29}}{{"E335}{3}{30}}
\__phosphoricons_def_icon:nnnnnn{\ppMouseMiddleClick}{mouse-middle-click}{"E338}{{1}{145}}{{3}{33}}{{"E339}{3}{34}}
\__phosphoricons_def_icon:nnnnnn{\ppMouseRightClick}{mouse-right-click}{"E336}{{1}{144}}{{3}{31}}{{"E337}{3}{32}}
\__phosphoricons_def_icon:nnnnnn{\ppMouseScroll}{mouse-scroll}{"E332}{{1}{142}}{{3}{27}}{{"E333}{3}{28}}
\__phosphoricons_def_icon:nnnnnn{\ppMouseSimple}{mouse-simple}{"E644}{{3}{14}}{{6}{26}}{{"E645}{6}{27}}
\__phosphoricons_def_icon:nnnnnn{\ppMusicNote}{music-note}{"E33C}{{1}{147}}{{3}{37}}{{"E33D}{3}{38}}
\__phosphoricons_def_icon:nnnnnn{\ppMusicNoteSimple}{music-note-simple}{"E33E}{{1}{148}}{{3}{39}}{{"E33F}{3}{40}}
\__phosphoricons_def_icon:nnnnnn{\ppMusicNotes}{music-notes}{"E340}{{1}{149}}{{3}{41}}{{"E341}{3}{42}}
\__phosphoricons_def_icon:nnnnnn{\ppMusicNotesMinus}{music-notes-minus}{"EE0C}{{5}{193}}{{11}{128}}{{"EE0D}{11}{129}}
\__phosphoricons_def_icon:nnnnnn{\ppMusicNotesPlus}{music-notes-plus}{"EB7C}{{4}{238}}{{9}{218}}{{"EB7D}{9}{219}}
\__phosphoricons_def_icon:nnnnnn{\ppMusicNotesSimple}{music-notes-simple}{"E342}{{1}{150}}{{3}{43}}{{"E343}{3}{44}}
\__phosphoricons_def_icon:nnnnnn{\ppNavigationArrow}{navigation-arrow}{"EADE}{{4}{168}}{{9}{78}}{{"EADF}{9}{79}}
\__phosphoricons_def_icon:nnnnnn{\ppNeedle}{needle}{"E82E}{{3}{233}}{{7}{208}}{{"E82F}{7}{209}}
\__phosphoricons_def_icon:nnnnnn{\ppNetwork}{network}{"EDDE}{{5}{178}}{{11}{98}}{{"EDDF}{11}{99}}
\__phosphoricons_def_icon:nnnnnn{\ppNetworkSlash}{network-slash}{"EDDC}{{5}{177}}{{11}{96}}{{"EDDD}{11}{97}}
\__phosphoricons_def_icon:nnnnnn{\ppNetworkX}{network-x}{"EDDA}{{5}{176}}{{11}{94}}{{"EDDB}{11}{95}}
\__phosphoricons_def_icon:nnnnnn{\ppNewspaper}{newspaper}{"E344}{{1}{151}}{{3}{45}}{{"E345}{3}{46}}
\__phosphoricons_def_icon:nnnnnn{\ppNewspaperClipping}{newspaper-clipping}{"E346}{{1}{152}}{{3}{47}}{{"E347}{3}{48}}
\__phosphoricons_def_icon:nnnnnn{\ppNotEquals}{not-equals}{"EDA6}{{5}{152}}{{11}{46}}{{"EDA7}{11}{47}}
\__phosphoricons_def_icon:nnnnnn{\ppNotMemberOf}{not-member-of}{"EDAE}{{5}{156}}{{11}{54}}{{"EDAF}{11}{55}}
\__phosphoricons_def_icon:nnnnnn{\ppNotSubsetOf}{not-subset-of}{"EDB0}{{5}{157}}{{11}{56}}{{"EDB1}{11}{57}}
\__phosphoricons_def_icon:nnnnnn{\ppNotSupersetOf}{not-superset-of}{"EDB2}{{5}{158}}{{11}{58}}{{"EDB3}{11}{59}}
\__phosphoricons_def_icon:nnnnnn{\ppNotches}{notches}{"ED3A}{{5}{110}}{{10}{218}}{{"ED3B}{10}{219}}
\__phosphoricons_def_icon:nnnnnn{\ppNote}{note}{"E348}{{1}{153}}{{3}{49}}{{"E349}{3}{50}}
\__phosphoricons_def_icon:nnnnnn{\ppNoteBlank}{note-blank}{"E34A}{{1}{154}}{{3}{51}}{{"E34B}{3}{52}}
\__phosphoricons_def_icon:nnnnnn{\ppNotePencil}{note-pencil}{"E34C}{{1}{155}}{{3}{53}}{{"E34D}{3}{54}}
\__phosphoricons_def_icon:nnnnnn{\ppNotebook}{notebook}{"E34E}{{1}{156}}{{3}{55}}{{"E34F}{3}{56}}
\__phosphoricons_def_icon:nnnnnn{\ppNotepad}{notepad}{"E63E}{{3}{11}}{{6}{20}}{{"E63F}{6}{21}}
\__phosphoricons_def_icon:nnnnnn{\ppNotification}{notification}{"E6FA}{{3}{104}}{{6}{206}}{{"E6FB}{6}{207}}
\__phosphoricons_def_icon:nnnnnn{\ppNotionLogo}{notion-logo}{"E9A0}{{4}{66}}{{8}{130}}{{"E9A1}{8}{131}}
\__phosphoricons_def_icon:nnnnnn{\ppNuclearPlant}{nuclear-plant}{"ED7C}{{5}{137}}{{11}{14}}{{"ED7D}{11}{15}}
\__phosphoricons_def_icon:nnnnnn{\ppNumberCircleEight}{number-circle-eight}{"E352}{{1}{158}}{{3}{59}}{{"E353}{3}{60}}
\__phosphoricons_def_icon:nnnnnn{\ppNumberCircleFive}{number-circle-five}{"E358}{{1}{161}}{{3}{65}}{{"E359}{3}{66}}
\__phosphoricons_def_icon:nnnnnn{\ppNumberCircleFour}{number-circle-four}{"E35E}{{1}{164}}{{3}{71}}{{"E35F}{3}{72}}
\__phosphoricons_def_icon:nnnnnn{\ppNumberCircleNine}{number-circle-nine}{"E364}{{1}{167}}{{3}{77}}{{"E365}{3}{78}}
\__phosphoricons_def_icon:nnnnnn{\ppNumberCircleOne}{number-circle-one}{"E36A}{{1}{170}}{{3}{83}}{{"E36B}{3}{84}}
\__phosphoricons_def_icon:nnnnnn{\ppNumberCircleSeven}{number-circle-seven}{"E370}{{1}{173}}{{3}{89}}{{"E371}{3}{90}}
\__phosphoricons_def_icon:nnnnnn{\ppNumberCircleSix}{number-circle-six}{"E376}{{1}{176}}{{3}{95}}{{"E377}{3}{96}}
\__phosphoricons_def_icon:nnnnnn{\ppNumberCircleThree}{number-circle-three}{"E37C}{{1}{179}}{{3}{101}}{{"E37D}{3}{102}}
\__phosphoricons_def_icon:nnnnnn{\ppNumberCircleTwo}{number-circle-two}{"E382}{{1}{182}}{{3}{107}}{{"E383}{3}{108}}
\__phosphoricons_def_icon:nnnnnn{\ppNumberCircleZero}{number-circle-zero}{"E388}{{1}{185}}{{3}{113}}{{"E389}{3}{114}}
\__phosphoricons_def_icon:nnnnnn{\ppNumberEight}{number-eight}{"E350}{{1}{157}}{{3}{57}}{{"E351}{3}{58}}
\__phosphoricons_def_icon:nnnnnn{\ppNumberFive}{number-five}{"E356}{{1}{160}}{{3}{63}}{{"E357}{3}{64}}
\__phosphoricons_def_icon:nnnnnn{\ppNumberFour}{number-four}{"E35C}{{1}{163}}{{3}{69}}{{"E35D}{3}{70}}
\__phosphoricons_def_icon:nnnnnn{\ppNumberNine}{number-nine}{"E362}{{1}{166}}{{3}{75}}{{"E363}{3}{76}}
\__phosphoricons_def_icon:nnnnnn{\ppNumberOne}{number-one}{"E368}{{1}{169}}{{3}{81}}{{"E369}{3}{82}}
\__phosphoricons_def_icon:nnnnnn{\ppNumberSeven}{number-seven}{"E36E}{{1}{172}}{{3}{87}}{{"E36F}{3}{88}}
\__phosphoricons_def_icon:nnnnnn{\ppNumberSix}{number-six}{"E374}{{1}{175}}{{3}{93}}{{"E375}{3}{94}}
\__phosphoricons_def_icon:nnnnnn{\ppNumberSquareEight}{number-square-eight}{"E354}{{1}{159}}{{3}{61}}{{"E355}{3}{62}}
\__phosphoricons_def_icon:nnnnnn{\ppNumberSquareFive}{number-square-five}{"E35A}{{1}{162}}{{3}{67}}{{"E35B}{3}{68}}
\__phosphoricons_def_icon:nnnnnn{\ppNumberSquareFour}{number-square-four}{"E360}{{1}{165}}{{3}{73}}{{"E361}{3}{74}}
\__phosphoricons_def_icon:nnnnnn{\ppNumberSquareNine}{number-square-nine}{"E366}{{1}{168}}{{3}{79}}{{"E367}{3}{80}}
\__phosphoricons_def_icon:nnnnnn{\ppNumberSquareOne}{number-square-one}{"E36C}{{1}{171}}{{3}{85}}{{"E36D}{3}{86}}
\__phosphoricons_def_icon:nnnnnn{\ppNumberSquareSeven}{number-square-seven}{"E372}{{1}{174}}{{3}{91}}{{"E373}{3}{92}}
\__phosphoricons_def_icon:nnnnnn{\ppNumberSquareSix}{number-square-six}{"E378}{{1}{177}}{{3}{97}}{{"E379}{3}{98}}
\__phosphoricons_def_icon:nnnnnn{\ppNumberSquareThree}{number-square-three}{"E37E}{{1}{180}}{{3}{103}}{{"E37F}{3}{104}}
\__phosphoricons_def_icon:nnnnnn{\ppNumberSquareTwo}{number-square-two}{"E384}{{1}{183}}{{3}{109}}{{"E385}{3}{110}}
\__phosphoricons_def_icon:nnnnnn{\ppNumberSquareZero}{number-square-zero}{"E38A}{{1}{186}}{{3}{115}}{{"E38B}{3}{116}}
\__phosphoricons_def_icon:nnnnnn{\ppNumberThree}{number-three}{"E37A}{{1}{178}}{{3}{99}}{{"E37B}{3}{100}}
\__phosphoricons_def_icon:nnnnnn{\ppNumberTwo}{number-two}{"E380}{{1}{181}}{{3}{105}}{{"E381}{3}{106}}
\__phosphoricons_def_icon:nnnnnn{\ppNumberZero}{number-zero}{"E386}{{1}{184}}{{3}{111}}{{"E387}{3}{112}}
\__phosphoricons_def_icon:nnnnnn{\ppNumpad}{numpad}{"E3C8}{{1}{215}}{{3}{173}}{{"E3C9}{3}{174}}
\__phosphoricons_def_icon:nnnnnn{\ppNut}{nut}{"E38C}{{1}{187}}{{3}{117}}{{"E38D}{3}{118}}
\__phosphoricons_def_icon:nnnnnn{\ppNyTimesLogo}{ny-times-logo}{"E646}{{3}{15}}{{6}{28}}{{"E647}{6}{29}}
\__phosphoricons_def_icon:nnnnnn{\ppOctagon}{octagon}{"E38E}{{1}{188}}{{3}{119}}{{"E38F}{3}{120}}
\__phosphoricons_def_icon:nnnnnn{\ppOfficeChair}{office-chair}{"EA46}{{4}{120}}{{8}{238}}{{"EA47}{8}{239}}
\__phosphoricons_def_icon:nnnnnn{\ppOnigiri}{onigiri}{"EE2C}{{5}{198}}{{11}{138}}{{"EE2D}{11}{139}}
\__phosphoricons_def_icon:nnnnnn{\ppOpenAiLogo}{open-ai-logo}{"E7D2}{{3}{198}}{{7}{138}}{{"E7D3}{7}{139}}
\__phosphoricons_def_icon:nnnnnn{\ppOption}{option}{"E8A8}{{4}{10}}{{8}{18}}{{"E8A9}{8}{19}}
\__phosphoricons_def_icon:nnnnnn{\ppOrange}{orange}{"EE40}{{5}{208}}{{11}{158}}{{"EE41}{11}{159}}
\__phosphoricons_def_icon:nnnnnn{\ppOrangeSlice}{orange-slice}{"ED36}{{5}{108}}{{10}{214}}{{"ED37}{10}{215}}
\__phosphoricons_def_icon:nnnnnn{\ppOven}{oven}{"ED8C}{{5}{142}}{{11}{26}}{{"ED8D}{11}{27}}
\__phosphoricons_def_icon:nnnnnn{\ppPackage}{package}{"E390}{{1}{189}}{{3}{121}}{{"E391}{3}{122}}
\__phosphoricons_def_icon:nnnnnn{\ppPaintBrush}{paint-brush}{"E6F0}{{3}{99}}{{6}{196}}{{"E6F1}{6}{197}}
\__phosphoricons_def_icon:nnnnnn{\ppPaintBrushBroad}{paint-brush-broad}{"E590}{{2}{180}}{{5}{102}}{{"E591}{5}{103}}
\__phosphoricons_def_icon:nnnnnn{\ppPaintBrushHousehold}{paint-brush-household}{"E6F2}{{3}{100}}{{6}{198}}{{"E6F3}{6}{199}}
\__phosphoricons_def_icon:nnnnnn{\ppPaintBucket}{paint-bucket}{"E392}{{1}{190}}{{3}{123}}{{"E393}{3}{124}}
\__phosphoricons_def_icon:nnnnnn{\ppPaintRoller}{paint-roller}{"E6F4}{{3}{101}}{{6}{200}}{{"E6F5}{6}{201}}
\__phosphoricons_def_icon:nnnnnn{\ppPalette}{palette}{"E6C8}{{3}{79}}{{6}{156}}{{"E6C9}{6}{157}}
\__phosphoricons_def_icon:nnnnnn{\ppPanorama}{panorama}{"EAA2}{{4}{151}}{{9}{44}}{{"EAA3}{9}{45}}
\__phosphoricons_def_icon:nnnnnn{\ppPants}{pants}{"EC88}{{5}{46}}{{10}{90}}{{"EC89}{10}{91}}
\__phosphoricons_def_icon:nnnnnn{\ppPaperPlane}{paper-plane}{"E394}{{1}{191}}{{3}{125}}{{"E395}{3}{126}}
\__phosphoricons_def_icon:nnnnnn{\ppPaperPlaneRight}{paper-plane-right}{"E396}{{1}{192}}{{3}{127}}{{"E397}{3}{128}}
\__phosphoricons_def_icon:nnnnnn{\ppPaperPlaneTilt}{paper-plane-tilt}{"E398}{{1}{193}}{{3}{129}}{{"E399}{3}{130}}
\__phosphoricons_def_icon:nnnnnn{\ppPaperclip}{paperclip}{"E39A}{{1}{194}}{{3}{131}}{{"E39B}{3}{132}}
\__phosphoricons_def_icon:nnnnnn{\ppPaperclipHorizontal}{paperclip-horizontal}{"E592}{{2}{181}}{{5}{104}}{{"E593}{5}{105}}
\__phosphoricons_def_icon:nnnnnn{\ppParachute}{parachute}{"EA7C}{{4}{134}}{{9}{10}}{{"EA7D}{9}{11}}
\__phosphoricons_def_icon:nnnnnn{\ppParagraph}{paragraph}{"E960}{{4}{57}}{{8}{112}}{{"E961}{8}{113}}
\__phosphoricons_def_icon:nnnnnn{\ppParallelogram}{parallelogram}{"ECC6}{{5}{71}}{{10}{140}}{{"ECC7}{10}{141}}
\__phosphoricons_def_icon:nnnnnn{\ppPark}{park}{"ECB2}{{5}{61}}{{10}{120}}{{"ECB3}{10}{121}}
\__phosphoricons_def_icon:nnnnnn{\ppPassword}{password}{"E752}{{3}{146}}{{7}{34}}{{"E753}{7}{35}}
\__phosphoricons_def_icon:nnnnnn{\ppPath}{path}{"E39C}{{1}{195}}{{3}{133}}{{"E39D}{3}{134}}
\__phosphoricons_def_icon:nnnnnn{\ppPatreonLogo}{patreon-logo}{"E98A}{{4}{64}}{{8}{126}}{{"E98B}{8}{127}}
\__phosphoricons_def_icon:nnnnnn{\ppPause}{pause}{"E39E}{{1}{196}}{{3}{135}}{{"E39F}{3}{136}}
\__phosphoricons_def_icon:nnnnnn{\ppPauseCircle}{pause-circle}{"E3A0}{{1}{197}}{{3}{137}}{{"E3A1}{3}{138}}
\__phosphoricons_def_icon:nnnnnn{\ppPawPrint}{paw-print}{"E648}{{3}{16}}{{6}{30}}{{"E649}{6}{31}}
\__phosphoricons_def_icon:nnnnnn{\ppPaypalLogo}{paypal-logo}{"E98C}{{4}{65}}{{8}{128}}{{"E98D}{8}{129}}
\__phosphoricons_def_icon:nnnnnn{\ppPeace}{peace}{"E3A2}{{1}{198}}{{3}{139}}{{"E3A3}{3}{140}}
\__phosphoricons_def_icon:nnnnnn{\ppPen}{pen}{"E3AA}{{1}{200}}{{3}{143}}{{"E3AB}{3}{144}}
\__phosphoricons_def_icon:nnnnnn{\ppPenNib}{pen-nib}{"E3AC}{{1}{201}}{{3}{145}}{{"E3AD}{3}{146}}
\__phosphoricons_def_icon:nnnnnn{\ppPenNibStraight}{pen-nib-straight}{"E64A}{{3}{17}}{{6}{32}}{{"E64B}{6}{33}}
\__phosphoricons_def_icon:nnnnnn{\ppPencil}{pencil}{"E3AE}{{1}{202}}{{3}{147}}{{"E3AF}{3}{148}}
\__phosphoricons_def_icon:nnnnnn{\ppPencilCircle}{pencil-circle}{"E3B0}{{1}{203}}{{3}{149}}{{"E3B1}{3}{150}}
\__phosphoricons_def_icon:nnnnnn{\ppPencilLine}{pencil-line}{"E3B2}{{1}{204}}{{3}{151}}{{"E3B3}{3}{152}}
\__phosphoricons_def_icon:nnnnnn{\ppPencilRuler}{pencil-ruler}{"E906}{{4}{38}}{{8}{74}}{{"E907}{8}{75}}
\__phosphoricons_def_icon:nnnnnn{\ppPencilSimple}{pencil-simple}{"E3B4}{{1}{205}}{{3}{153}}{{"E3B5}{3}{154}}
\__phosphoricons_def_icon:nnnnnn{\ppPencilSimpleLine}{pencil-simple-line}{"EBC6}{{5}{3}}{{10}{4}}{{"EBC7}{10}{5}}
\__phosphoricons_def_icon:nnnnnn{\ppPencilSimpleSlash}{pencil-simple-slash}{"ECF6}{{5}{88}}{{10}{174}}{{"ECF7}{10}{175}}
\__phosphoricons_def_icon:nnnnnn{\ppPencilSlash}{pencil-slash}{"ECF8}{{5}{89}}{{10}{176}}{{"ECF9}{10}{177}}
\__phosphoricons_def_icon:nnnnnn{\ppPentagon}{pentagon}{"EC7E}{{5}{43}}{{10}{84}}{{"EC7F}{10}{85}}
\__phosphoricons_def_icon:nnnnnn{\ppPentagram}{pentagram}{"EC5C}{{5}{31}}{{10}{60}}{{"EC5D}{10}{61}}
\__phosphoricons_def_icon:nnnnnn{\ppPepper}{pepper}{"E94A}{{4}{48}}{{8}{94}}{{"E94B}{8}{95}}
\__phosphoricons_def_icon:nnnnnn{\ppPercent}{percent}{"E3B6}{{1}{206}}{{3}{155}}{{"E3B7}{3}{156}}
\__phosphoricons_def_icon:nnnnnn{\ppPerson}{person}{"E3A8}{{1}{199}}{{3}{141}}{{"E3A9}{3}{142}}
\__phosphoricons_def_icon:nnnnnn{\ppPersonArmsSpread}{person-arms-spread}{"ECFE}{{5}{92}}{{10}{182}}{{"ECFF}{10}{183}}
\__phosphoricons_def_icon:nnnnnn{\ppPersonSimple}{person-simple}{"E72E}{{3}{130}}{{7}{2}}{{"E72F}{7}{3}}
\__phosphoricons_def_icon:nnnnnn{\ppPersonSimpleBike}{person-simple-bike}{"E734}{{3}{133}}{{7}{8}}{{"E735}{7}{9}}
\__phosphoricons_def_icon:nnnnnn{\ppPersonSimpleCircle}{person-simple-circle}{"EE58}{{5}{220}}{{11}{182}}{{"EE59}{11}{183}}
\__phosphoricons_def_icon:nnnnnn{\ppPersonSimpleHike}{person-simple-hike}{"ED54}{{5}{123}}{{10}{242}}{{"ED55}{10}{243}}
\__phosphoricons_def_icon:nnnnnn{\ppPersonSimpleRun}{person-simple-run}{"E730}{{3}{131}}{{7}{4}}{{"E731}{7}{5}}
\__phosphoricons_def_icon:nnnnnn{\ppPersonSimpleSki}{person-simple-ski}{"E71C}{{3}{121}}{{6}{240}}{{"E71D}{6}{241}}
\__phosphoricons_def_icon:nnnnnn{\ppPersonSimpleSnowboard}{person-simple-snowboard}{"E71E}{{3}{122}}{{6}{242}}{{"E71F}{6}{243}}
\__phosphoricons_def_icon:nnnnnn{\ppPersonSimpleSwim}{person-simple-swim}{"E736}{{3}{134}}{{7}{10}}{{"E737}{7}{11}}
\__phosphoricons_def_icon:nnnnnn{\ppPersonSimpleTaiChi}{person-simple-tai-chi}{"ED5C}{{5}{124}}{{10}{246}}{{"ED5D}{10}{247}}
\__phosphoricons_def_icon:nnnnnn{\ppPersonSimpleThrow}{person-simple-throw}{"E732}{{3}{132}}{{7}{6}}{{"E733}{7}{7}}
\__phosphoricons_def_icon:nnnnnn{\ppPersonSimpleWalk}{person-simple-walk}{"E73A}{{3}{135}}{{7}{12}}{{"E73B}{7}{13}}
\__phosphoricons_def_icon:nnnnnn{\ppPerspective}{perspective}{"EBE6}{{5}{10}}{{10}{18}}{{"EBE7}{10}{19}}
\__phosphoricons_def_icon:nnnnnn{\ppPhone}{phone}{"E3B8}{{1}{207}}{{3}{157}}{{"E3B9}{3}{158}}
\__phosphoricons_def_icon:nnnnnn{\ppPhoneCall}{phone-call}{"E3BA}{{1}{208}}{{3}{159}}{{"E3BB}{3}{160}}
\__phosphoricons_def_icon:nnnnnn{\ppPhoneDisconnect}{phone-disconnect}{"E3BC}{{1}{209}}{{3}{161}}{{"E3BD}{3}{162}}
\__phosphoricons_def_icon:nnnnnn{\ppPhoneIncoming}{phone-incoming}{"E3BE}{{1}{210}}{{3}{163}}{{"E3BF}{3}{164}}
\__phosphoricons_def_icon:nnnnnn{\ppPhoneList}{phone-list}{"E3CC}{{1}{217}}{{3}{177}}{{"E3CD}{3}{178}}
\__phosphoricons_def_icon:nnnnnn{\ppPhoneOutgoing}{phone-outgoing}{"E3C0}{{1}{211}}{{3}{165}}{{"E3C1}{3}{166}}
\__phosphoricons_def_icon:nnnnnn{\ppPhonePause}{phone-pause}{"E3CA}{{1}{216}}{{3}{175}}{{"E3CB}{3}{176}}
\__phosphoricons_def_icon:nnnnnn{\ppPhonePlus}{phone-plus}{"EC56}{{5}{29}}{{10}{56}}{{"EC57}{10}{57}}
\__phosphoricons_def_icon:nnnnnn{\ppPhoneSlash}{phone-slash}{"E3C2}{{1}{212}}{{3}{167}}{{"E3C3}{3}{168}}
\__phosphoricons_def_icon:nnnnnn{\ppPhoneTransfer}{phone-transfer}{"E3C6}{{1}{214}}{{3}{171}}{{"E3C7}{3}{172}}
\__phosphoricons_def_icon:nnnnnn{\ppPhoneX}{phone-x}{"E3C4}{{1}{213}}{{3}{169}}{{"E3C5}{3}{170}}
\__phosphoricons_def_icon:nnnnnn{\ppPhosphorLogo}{phosphor-logo}{"E3CE}{{1}{218}}{{3}{179}}{{"E3CF}{3}{180}}
\__phosphoricons_def_icon:nnnnnn{\ppPi}{pi}{"EC80}{{5}{44}}{{10}{86}}{{"EC81}{10}{87}}
\__phosphoricons_def_icon:nnnnnn{\ppPianoKeys}{piano-keys}{"E9C8}{{4}{77}}{{8}{152}}{{"E9C9}{8}{153}}
\__phosphoricons_def_icon:nnnnnn{\ppPicnicTable}{picnic-table}{"EE26}{{5}{195}}{{11}{132}}{{"EE27}{11}{133}}
\__phosphoricons_def_icon:nnnnnn{\ppPictureInPicture}{picture-in-picture}{"E64C}{{3}{18}}{{6}{34}}{{"E64D}{6}{35}}
\__phosphoricons_def_icon:nnnnnn{\ppPiggyBank}{piggy-bank}{"EA04}{{4}{96}}{{8}{190}}{{"EA05}{8}{191}}
\__phosphoricons_def_icon:nnnnnn{\ppPill}{pill}{"E700}{{3}{107}}{{6}{212}}{{"E701}{6}{213}}
\__phosphoricons_def_icon:nnnnnn{\ppPingPong}{ping-pong}{"EA42}{{4}{118}}{{8}{234}}{{"EA43}{8}{235}}
\__phosphoricons_def_icon:nnnnnn{\ppPintGlass}{pint-glass}{"EDD0}{{5}{171}}{{11}{84}}{{"EDD1}{11}{85}}
\__phosphoricons_def_icon:nnnnnn{\ppPinterestLogo}{pinterest-logo}{"E64E}{{3}{19}}{{6}{36}}{{"E64F}{6}{37}}
\__phosphoricons_def_icon:nnnnnn{\ppPinwheel}{pinwheel}{"EB9C}{{4}{247}}{{9}{236}}{{"EB9D}{9}{237}}
\__phosphoricons_def_icon:nnnnnn{\ppPipe}{pipe}{"ED86}{{5}{140}}{{11}{22}}{{"ED87}{11}{23}}
\__phosphoricons_def_icon:nnnnnn{\ppPipeWrench}{pipe-wrench}{"ED88}{{5}{141}}{{11}{24}}{{"ED89}{11}{25}}
\__phosphoricons_def_icon:nnnnnn{\ppPixLogo}{pix-logo}{"ECC2}{{5}{69}}{{10}{136}}{{"ECC3}{10}{137}}
\__phosphoricons_def_icon:nnnnnn{\ppPizza}{pizza}{"E796}{{3}{173}}{{7}{88}}{{"E797}{7}{89}}
\__phosphoricons_def_icon:nnnnnn{\ppPlaceholder}{placeholder}{"E650}{{3}{20}}{{6}{38}}{{"E651}{6}{39}}
\__phosphoricons_def_icon:nnnnnn{\ppPlanet}{planet}{"E652}{{3}{21}}{{6}{40}}{{"E653}{6}{41}}
\__phosphoricons_def_icon:nnnnnn{\ppPlant}{plant}{"EBAE}{{4}{254}}{{9}{250}}{{"EBAF}{9}{251}}
\__phosphoricons_def_icon:nnnnnn{\ppPlay}{play}{"E3D0}{{1}{219}}{{3}{181}}{{"E3D1}{3}{182}}
\__phosphoricons_def_icon:nnnnnn{\ppPlayCircle}{play-circle}{"E3D2}{{1}{220}}{{3}{183}}{{"E3D3}{3}{184}}
\__phosphoricons_def_icon:nnnnnn{\ppPlayPause}{play-pause}{"E8BE}{{4}{15}}{{8}{28}}{{"E8BF}{8}{29}}
\__phosphoricons_def_icon:nnnnnn{\ppPlaylist}{playlist}{"E6AA}{{3}{65}}{{6}{128}}{{"E6AB}{6}{129}}
\__phosphoricons_def_icon:nnnnnn{\ppPlug}{plug}{"E946}{{4}{46}}{{8}{90}}{{"E947}{8}{91}}
\__phosphoricons_def_icon:nnnnnn{\ppPlugCharging}{plug-charging}{"EB5C}{{4}{227}}{{9}{196}}{{"EB5D}{9}{197}}
\__phosphoricons_def_icon:nnnnnn{\ppPlugs}{plugs}{"EB56}{{4}{224}}{{9}{190}}{{"EB57}{9}{191}}
\__phosphoricons_def_icon:nnnnnn{\ppPlugsConnected}{plugs-connected}{"EB5A}{{4}{226}}{{9}{194}}{{"EB5B}{9}{195}}
\__phosphoricons_def_icon:nnnnnn{\ppPlus}{plus}{"E3D4}{{1}{221}}{{3}{185}}{{"E3D5}{3}{186}}
\__phosphoricons_def_icon:nnnnnn{\ppPlusCircle}{plus-circle}{"E3D6}{{1}{222}}{{3}{187}}{{"E3D7}{3}{188}}
\__phosphoricons_def_icon:nnnnnn{\ppPlusMinus}{plus-minus}{"E3D8}{{1}{223}}{{3}{189}}{{"E3D9}{3}{190}}
\__phosphoricons_def_icon:nnnnnn{\ppPlusSquare}{plus-square}{"ED4A}{{5}{118}}{{10}{232}}{{"ED56}{10}{244}}
\__phosphoricons_def_icon:nnnnnn{\ppPokerChip}{poker-chip}{"E594}{{2}{182}}{{5}{106}}{{"E595}{5}{107}}
\__phosphoricons_def_icon:nnnnnn{\ppPoliceCar}{police-car}{"EC4A}{{5}{25}}{{10}{48}}{{"EC4B}{10}{49}}
\__phosphoricons_def_icon:nnnnnn{\ppPolygon}{polygon}{"E6D0}{{3}{83}}{{6}{164}}{{"E6D1}{6}{165}}
\__phosphoricons_def_icon:nnnnnn{\ppPopcorn}{popcorn}{"EB4E}{{4}{220}}{{9}{182}}{{"EB4F}{9}{183}}
\__phosphoricons_def_icon:nnnnnn{\ppPopsicle}{popsicle}{"EBBE}{{5}{2}}{{10}{2}}{{"EBBF}{10}{3}}
\__phosphoricons_def_icon:nnnnnn{\ppPottedPlant}{potted-plant}{"EC22}{{5}{16}}{{10}{30}}{{"EC23}{10}{31}}
\__phosphoricons_def_icon:nnnnnn{\ppPower}{power}{"E3DA}{{1}{224}}{{3}{191}}{{"E3DB}{3}{192}}
\__phosphoricons_def_icon:nnnnnn{\ppPrescription}{prescription}{"E7A2}{{3}{178}}{{7}{98}}{{"E7A3}{7}{99}}
\__phosphoricons_def_icon:nnnnnn{\ppPresentation}{presentation}{"E654}{{3}{22}}{{6}{42}}{{"E655}{6}{43}}
\__phosphoricons_def_icon:nnnnnn{\ppPresentationChart}{presentation-chart}{"E656}{{3}{23}}{{6}{44}}{{"E657}{6}{45}}
\__phosphoricons_def_icon:nnnnnn{\ppPrinter}{printer}{"E3DC}{{1}{225}}{{3}{193}}{{"E3DD}{3}{194}}
\__phosphoricons_def_icon:nnnnnn{\ppProhibit}{prohibit}{"E3DE}{{1}{226}}{{3}{195}}{{"E3DF}{3}{196}}
\__phosphoricons_def_icon:nnnnnn{\ppProhibitInset}{prohibit-inset}{"E3E0}{{1}{227}}{{3}{197}}{{"E3E1}{3}{198}}
\__phosphoricons_def_icon:nnnnnn{\ppProjectorScreen}{projector-screen}{"E658}{{3}{24}}{{6}{46}}{{"E659}{6}{47}}
\__phosphoricons_def_icon:nnnnnn{\ppProjectorScreenChart}{projector-screen-chart}{"E65A}{{3}{25}}{{6}{48}}{{"E65B}{6}{49}}
\__phosphoricons_def_icon:nnnnnn{\ppPulse}{pulse}{"E000}{{0}{0}}{{0}{0}}{{"E001}{0}{1}}
\__phosphoricons_def_icon:nnnnnn{\ppPushPin}{push-pin}{"E3E2}{{1}{228}}{{3}{199}}{{"E3E3}{3}{200}}
\__phosphoricons_def_icon:nnnnnn{\ppPushPinSimple}{push-pin-simple}{"E65C}{{3}{26}}{{6}{50}}{{"E65D}{6}{51}}
\__phosphoricons_def_icon:nnnnnn{\ppPushPinSimpleSlash}{push-pin-simple-slash}{"E65E}{{3}{27}}{{6}{52}}{{"E65F}{6}{53}}
\__phosphoricons_def_icon:nnnnnn{\ppPushPinSlash}{push-pin-slash}{"E3E4}{{1}{229}}{{3}{201}}{{"E3E5}{3}{202}}
\__phosphoricons_def_icon:nnnnnn{\ppPuzzlePiece}{puzzle-piece}{"E596}{{2}{183}}{{5}{108}}{{"E597}{5}{109}}
\__phosphoricons_def_icon:nnnnnn{\ppQrCode}{qr-code}{"E3E6}{{1}{230}}{{3}{203}}{{"E3E7}{3}{204}}
\__phosphoricons_def_icon:nnnnnn{\ppQuestion}{question}{"E3E8}{{1}{231}}{{3}{205}}{{"E3EB}{3}{208}}
\__phosphoricons_def_icon:nnnnnn{\ppQuestionMark}{question-mark}{"E3E9}{{1}{232}}{{3}{206}}{{"E3ED}{3}{210}}
\__phosphoricons_def_icon:nnnnnn{\ppQueue}{queue}{"E6AC}{{3}{66}}{{6}{130}}{{"E6AD}{6}{131}}
\__phosphoricons_def_icon:nnnnnn{\ppQuotes}{quotes}{"E660}{{3}{28}}{{6}{54}}{{"E661}{6}{55}}
\__phosphoricons_def_icon:nnnnnn{\ppRabbit}{rabbit}{"EAC2}{{4}{160}}{{9}{62}}{{"EAC3}{9}{63}}
\__phosphoricons_def_icon:nnnnnn{\ppRacquet}{racquet}{"EE02}{{5}{189}}{{11}{120}}{{"EE03}{11}{121}}
\__phosphoricons_def_icon:nnnnnn{\ppRadical}{radical}{"E3EA}{{1}{233}}{{3}{207}}{{"E3EF}{3}{212}}
\__phosphoricons_def_icon:nnnnnn{\ppRadio}{radio}{"E77E}{{3}{163}}{{7}{68}}{{"E77F}{7}{69}}
\__phosphoricons_def_icon:nnnnnn{\ppRadioButton}{radio-button}{"EB08}{{4}{185}}{{9}{112}}{{"EB09}{9}{113}}
\__phosphoricons_def_icon:nnnnnn{\ppRadioactive}{radioactive}{"E9DC}{{4}{81}}{{8}{160}}{{"E9DD}{8}{161}}
\__phosphoricons_def_icon:nnnnnn{\ppRainbow}{rainbow}{"E598}{{2}{184}}{{5}{110}}{{"E599}{5}{111}}
\__phosphoricons_def_icon:nnnnnn{\ppRainbowCloud}{rainbow-cloud}{"E59A}{{2}{185}}{{5}{112}}{{"E59B}{5}{113}}
\__phosphoricons_def_icon:nnnnnn{\ppRanking}{ranking}{"ED62}{{5}{126}}{{10}{250}}{{"ED63}{10}{251}}
\__phosphoricons_def_icon:nnnnnn{\ppReadCvLogo}{read-cv-logo}{"ED0C}{{5}{96}}{{10}{190}}{{"ED0D}{10}{191}}
\__phosphoricons_def_icon:nnnnnn{\ppReceipt}{receipt}{"E3EC}{{1}{234}}{{3}{209}}{{"E3F1}{3}{214}}
\__phosphoricons_def_icon:nnnnnn{\ppReceiptX}{receipt-x}{"ED40}{{5}{113}}{{10}{224}}{{"ED41}{10}{225}}
\__phosphoricons_def_icon:nnnnnn{\ppRecord}{record}{"E3EE}{{1}{235}}{{3}{211}}{{"E3F3}{3}{216}}
\__phosphoricons_def_icon:nnnnnn{\ppRectangle}{rectangle}{"E3F0}{{1}{236}}{{3}{213}}{{"E3F5}{3}{218}}
\__phosphoricons_def_icon:nnnnnn{\ppRectangleDashed}{rectangle-dashed}{"E3F2}{{1}{237}}{{3}{215}}{{"E3F7}{3}{220}}
\__phosphoricons_def_icon:nnnnnn{\ppRecycle}{recycle}{"E75A}{{3}{150}}{{7}{42}}{{"E75B}{7}{43}}
\__phosphoricons_def_icon:nnnnnn{\ppRedditLogo}{reddit-logo}{"E59C}{{2}{186}}{{5}{114}}{{"E59D}{5}{115}}
\__phosphoricons_def_icon:nnnnnn{\ppRepeat}{repeat}{"E3F6}{{1}{239}}{{3}{219}}{{"E3F9}{3}{222}}
\__phosphoricons_def_icon:nnnnnn{\ppRepeatOnce}{repeat-once}{"E3F8}{{1}{240}}{{3}{221}}{{"E3FB}{3}{224}}
\__phosphoricons_def_icon:nnnnnn{\ppReplitLogo}{replit-logo}{"EB8A}{{4}{240}}{{9}{222}}{{"EB8B}{9}{223}}
\__phosphoricons_def_icon:nnnnnn{\ppResize}{resize}{"ED6E}{{5}{132}}{{11}{6}}{{"ED6F}{11}{7}}
\__phosphoricons_def_icon:nnnnnn{\ppRewind}{rewind}{"E6A8}{{3}{64}}{{6}{126}}{{"E6A9}{6}{127}}
\__phosphoricons_def_icon:nnnnnn{\ppRewindCircle}{rewind-circle}{"E3FA}{{1}{241}}{{3}{223}}{{"E3FD}{3}{226}}
\__phosphoricons_def_icon:nnnnnn{\ppRoadHorizon}{road-horizon}{"E838}{{3}{238}}{{7}{218}}{{"E839}{7}{219}}
\__phosphoricons_def_icon:nnnnnn{\ppRobot}{robot}{"E762}{{3}{154}}{{7}{50}}{{"E763}{7}{51}}
\__phosphoricons_def_icon:nnnnnn{\ppRocket}{rocket}{"E3FC}{{1}{242}}{{3}{225}}{{"E3FF}{3}{228}}
\__phosphoricons_def_icon:nnnnnn{\ppRocketLaunch}{rocket-launch}{"E3FE}{{1}{243}}{{3}{227}}{{"E401}{3}{230}}
\__phosphoricons_def_icon:nnnnnn{\ppRows}{rows}{"E5A2}{{2}{189}}{{5}{120}}{{"E5A3}{5}{121}}
\__phosphoricons_def_icon:nnnnnn{\ppRowsPlusBottom}{rows-plus-bottom}{"E59E}{{2}{187}}{{5}{116}}{{"E59F}{5}{117}}
\__phosphoricons_def_icon:nnnnnn{\ppRowsPlusTop}{rows-plus-top}{"E5A0}{{2}{188}}{{5}{118}}{{"E5A1}{5}{119}}
\__phosphoricons_def_icon:nnnnnn{\ppRss}{rss}{"E400}{{1}{244}}{{3}{229}}{{"E403}{3}{232}}
\__phosphoricons_def_icon:nnnnnn{\ppRssSimple}{rss-simple}{"E402}{{1}{245}}{{3}{231}}{{"E405}{3}{234}}
\__phosphoricons_def_icon:nnnnnn{\ppRug}{rug}{"EA1A}{{4}{102}}{{8}{202}}{{"EA1B}{8}{203}}
\__phosphoricons_def_icon:nnnnnn{\ppRuler}{ruler}{"E6B8}{{3}{71}}{{6}{140}}{{"E6B9}{6}{141}}
\__phosphoricons_def_icon:nnnnnn{\ppSailboat}{sailboat}{"E78A}{{3}{167}}{{7}{76}}{{"E78B}{7}{77}}
\__phosphoricons_def_icon:nnnnnn{\ppScales}{scales}{"E750}{{3}{145}}{{7}{32}}{{"E751}{7}{33}}
\__phosphoricons_def_icon:nnnnnn{\ppScan}{scan}{"EBB6}{{5}{0}}{{9}{254}}{{"EBB7}{9}{255}}
\__phosphoricons_def_icon:nnnnnn{\ppScanSmiley}{scan-smiley}{"EBB4}{{4}{255}}{{9}{252}}{{"EBB5}{9}{253}}
\__phosphoricons_def_icon:nnnnnn{\ppScissors}{scissors}{"EAE0}{{4}{169}}{{9}{80}}{{"EAE1}{9}{81}}
\__phosphoricons_def_icon:nnnnnn{\ppScooter}{scooter}{"E820}{{3}{229}}{{7}{200}}{{"E821}{7}{201}}
\__phosphoricons_def_icon:nnnnnn{\ppScreencast}{screencast}{"E404}{{1}{246}}{{3}{233}}{{"E407}{3}{236}}
\__phosphoricons_def_icon:nnnnnn{\ppScrewdriver}{screwdriver}{"E86E}{{3}{248}}{{7}{238}}{{"E86F}{7}{239}}
\__phosphoricons_def_icon:nnnnnn{\ppScribble}{scribble}{"E806}{{3}{217}}{{7}{176}}{{"E807}{7}{177}}
\__phosphoricons_def_icon:nnnnnn{\ppScribbleLoop}{scribble-loop}{"E662}{{3}{29}}{{6}{56}}{{"E663}{6}{57}}
\__phosphoricons_def_icon:nnnnnn{\ppScroll}{scroll}{"EB7A}{{4}{237}}{{9}{216}}{{"EB7B}{9}{217}}
\__phosphoricons_def_icon:nnnnnn{\ppSeal}{seal}{"E604}{{2}{238}}{{5}{218}}{{"E605}{5}{219}}
\__phosphoricons_def_icon:nnnnnn{\ppSealCheck}{seal-check}{"E606}{{2}{239}}{{5}{220}}{{"E607}{5}{221}}
\__phosphoricons_def_icon:nnnnnn{\ppSealPercent}{seal-percent}{"E60A}{{2}{241}}{{5}{224}}{{"E60B}{5}{225}}
\__phosphoricons_def_icon:nnnnnn{\ppSealQuestion}{seal-question}{"E608}{{2}{240}}{{5}{222}}{{"E609}{5}{223}}
\__phosphoricons_def_icon:nnnnnn{\ppSealWarning}{seal-warning}{"E60C}{{2}{242}}{{5}{226}}{{"E60D}{5}{227}}
\__phosphoricons_def_icon:nnnnnn{\ppSeat}{seat}{"EB8E}{{4}{241}}{{9}{224}}{{"EB8F}{9}{225}}
\__phosphoricons_def_icon:nnnnnn{\ppSeatbelt}{seatbelt}{"EDFE}{{5}{188}}{{11}{118}}{{"EDFF}{11}{119}}
\__phosphoricons_def_icon:nnnnnn{\ppSecurityCamera}{security-camera}{"ECA4}{{5}{56}}{{10}{110}}{{"ECA5}{10}{111}}
\__phosphoricons_def_icon:nnnnnn{\ppSelection}{selection}{"E69A}{{3}{57}}{{6}{112}}{{"E69B}{6}{113}}
\__phosphoricons_def_icon:nnnnnn{\ppSelectionAll}{selection-all}{"E746}{{3}{141}}{{7}{24}}{{"E747}{7}{25}}
\__phosphoricons_def_icon:nnnnnn{\ppSelectionBackground}{selection-background}{"EAF8}{{4}{178}}{{9}{98}}{{"EAF9}{9}{99}}
\__phosphoricons_def_icon:nnnnnn{\ppSelectionForeground}{selection-foreground}{"EAF6}{{4}{177}}{{9}{96}}{{"EAF7}{9}{97}}
\__phosphoricons_def_icon:nnnnnn{\ppSelectionInverse}{selection-inverse}{"E744}{{3}{140}}{{7}{22}}{{"E745}{7}{23}}
\__phosphoricons_def_icon:nnnnnn{\ppSelectionPlus}{selection-plus}{"E69C}{{3}{58}}{{6}{114}}{{"E69D}{6}{115}}
\__phosphoricons_def_icon:nnnnnn{\ppSelectionSlash}{selection-slash}{"E69E}{{3}{59}}{{6}{116}}{{"E69F}{6}{117}}
\__phosphoricons_def_icon:nnnnnn{\ppShapes}{shapes}{"EC5E}{{5}{32}}{{10}{62}}{{"EC5F}{10}{63}}
\__phosphoricons_def_icon:nnnnnn{\ppShare}{share}{"E406}{{1}{247}}{{3}{235}}{{"E409}{3}{238}}
\__phosphoricons_def_icon:nnnnnn{\ppShareFat}{share-fat}{"ED52}{{5}{122}}{{10}{240}}{{"ED57}{10}{245}}
\__phosphoricons_def_icon:nnnnnn{\ppShareNetwork}{share-network}{"E408}{{1}{248}}{{3}{237}}{{"E40B}{3}{240}}
\__phosphoricons_def_icon:nnnnnn{\ppShield}{shield}{"E40A}{{1}{249}}{{3}{239}}{{"E40D}{3}{242}}
\__phosphoricons_def_icon:nnnnnn{\ppShieldCheck}{shield-check}{"E40C}{{1}{250}}{{3}{241}}{{"E40F}{3}{244}}
\__phosphoricons_def_icon:nnnnnn{\ppShieldCheckered}{shield-checkered}{"E708}{{3}{111}}{{6}{220}}{{"E709}{6}{221}}
\__phosphoricons_def_icon:nnnnnn{\ppShieldChevron}{shield-chevron}{"E40E}{{1}{251}}{{3}{243}}{{"E411}{3}{246}}
\__phosphoricons_def_icon:nnnnnn{\ppShieldPlus}{shield-plus}{"E706}{{3}{110}}{{6}{218}}{{"E707}{6}{219}}
\__phosphoricons_def_icon:nnnnnn{\ppShieldSlash}{shield-slash}{"E410}{{1}{252}}{{3}{245}}{{"E413}{3}{248}}
\__phosphoricons_def_icon:nnnnnn{\ppShieldStar}{shield-star}{"EC34}{{5}{21}}{{10}{40}}{{"EC35}{10}{41}}
\__phosphoricons_def_icon:nnnnnn{\ppShieldWarning}{shield-warning}{"E412}{{1}{253}}{{3}{247}}{{"E414}{3}{249}}
\__phosphoricons_def_icon:nnnnnn{\ppShippingContainer}{shipping-container}{"E78C}{{3}{168}}{{7}{78}}{{"E78D}{7}{79}}
\__phosphoricons_def_icon:nnnnnn{\ppShirtFolded}{shirt-folded}{"EA92}{{4}{144}}{{9}{30}}{{"EA93}{9}{31}}
\__phosphoricons_def_icon:nnnnnn{\ppShootingStar}{shooting-star}{"ECFA}{{5}{90}}{{10}{178}}{{"ECFB}{10}{179}}
\__phosphoricons_def_icon:nnnnnn{\ppShoppingBag}{shopping-bag}{"E416}{{1}{254}}{{3}{251}}{{"E417}{3}{252}}
\__phosphoricons_def_icon:nnnnnn{\ppShoppingBagOpen}{shopping-bag-open}{"E418}{{1}{255}}{{3}{253}}{{"E419}{3}{254}}
\__phosphoricons_def_icon:nnnnnn{\ppShoppingCart}{shopping-cart}{"E41E}{{2}{0}}{{3}{255}}{{"E41F}{4}{0}}
\__phosphoricons_def_icon:nnnnnn{\ppShoppingCartSimple}{shopping-cart-simple}{"E420}{{2}{1}}{{4}{1}}{{"E421}{4}{2}}
\__phosphoricons_def_icon:nnnnnn{\ppShovel}{shovel}{"E9E6}{{4}{85}}{{8}{168}}{{"E9E7}{8}{169}}
\__phosphoricons_def_icon:nnnnnn{\ppShower}{shower}{"E776}{{3}{161}}{{7}{64}}{{"E777}{7}{65}}
\__phosphoricons_def_icon:nnnnnn{\ppShrimp}{shrimp}{"EAB4}{{4}{156}}{{9}{54}}{{"EAB5}{9}{55}}
\__phosphoricons_def_icon:nnnnnn{\ppShuffle}{shuffle}{"E422}{{2}{2}}{{4}{3}}{{"E423}{4}{4}}
\__phosphoricons_def_icon:nnnnnn{\ppShuffleAngular}{shuffle-angular}{"E424}{{2}{3}}{{4}{5}}{{"E425}{4}{6}}
\__phosphoricons_def_icon:nnnnnn{\ppShuffleSimple}{shuffle-simple}{"E426}{{2}{4}}{{4}{7}}{{"E427}{4}{8}}
\__phosphoricons_def_icon:nnnnnn{\ppSidebar}{sidebar}{"EAB6}{{4}{157}}{{9}{56}}{{"EAB7}{9}{57}}
\__phosphoricons_def_icon:nnnnnn{\ppSidebarSimple}{sidebar-simple}{"EC24}{{5}{17}}{{10}{32}}{{"EC25}{10}{33}}
\__phosphoricons_def_icon:nnnnnn{\ppSigma}{sigma}{"EAB8}{{4}{158}}{{9}{58}}{{"EAB9}{9}{59}}
\__phosphoricons_def_icon:nnnnnn{\ppSignIn}{sign-in}{"E428}{{2}{5}}{{4}{9}}{{"E429}{4}{10}}
\__phosphoricons_def_icon:nnnnnn{\ppSignOut}{sign-out}{"E42A}{{2}{6}}{{4}{11}}{{"E42B}{4}{12}}
\__phosphoricons_def_icon:nnnnnn{\ppSignature}{signature}{"EBAC}{{4}{253}}{{9}{248}}{{"EBAD}{9}{249}}
\__phosphoricons_def_icon:nnnnnn{\ppSignpost}{signpost}{"E89C}{{4}{6}}{{8}{10}}{{"E89D}{8}{11}}
\__phosphoricons_def_icon:nnnnnn{\ppSimCard}{sim-card}{"E664}{{3}{30}}{{6}{58}}{{"E665}{6}{59}}
\__phosphoricons_def_icon:nnnnnn{\ppSiren}{siren}{"E9B8}{{4}{72}}{{8}{142}}{{"E9B9}{8}{143}}
\__phosphoricons_def_icon:nnnnnn{\ppSketchLogo}{sketch-logo}{"E42C}{{2}{7}}{{4}{13}}{{"E42D}{4}{14}}
\__phosphoricons_def_icon:nnnnnn{\ppSkipBack}{skip-back}{"E5A4}{{2}{190}}{{5}{122}}{{"E5A5}{5}{123}}
\__phosphoricons_def_icon:nnnnnn{\ppSkipBackCircle}{skip-back-circle}{"E42E}{{2}{8}}{{4}{15}}{{"E42F}{4}{16}}
\__phosphoricons_def_icon:nnnnnn{\ppSkipForward}{skip-forward}{"E5A6}{{2}{191}}{{5}{124}}{{"E5A7}{5}{125}}
\__phosphoricons_def_icon:nnnnnn{\ppSkipForwardCircle}{skip-forward-circle}{"E430}{{2}{9}}{{4}{17}}{{"E431}{4}{18}}
\__phosphoricons_def_icon:nnnnnn{\ppSkull}{skull}{"E916}{{4}{40}}{{8}{78}}{{"E917}{8}{79}}
\__phosphoricons_def_icon:nnnnnn{\ppSkypeLogo}{skype-logo}{"E8DC}{{4}{26}}{{8}{50}}{{"E8DD}{8}{51}}
\__phosphoricons_def_icon:nnnnnn{\ppSlackLogo}{slack-logo}{"E5A8}{{2}{192}}{{5}{126}}{{"E5A9}{5}{127}}
\__phosphoricons_def_icon:nnnnnn{\ppSliders}{sliders}{"E432}{{2}{10}}{{4}{19}}{{"E433}{4}{20}}
\__phosphoricons_def_icon:nnnnnn{\ppSlidersHorizontal}{sliders-horizontal}{"E434}{{2}{11}}{{4}{21}}{{"E435}{4}{22}}
\__phosphoricons_def_icon:nnnnnn{\ppSlideshow}{slideshow}{"ED32}{{5}{106}}{{10}{210}}{{"ED33}{10}{211}}
\__phosphoricons_def_icon:nnnnnn{\ppSmiley}{smiley}{"E436}{{2}{12}}{{4}{23}}{{"E437}{4}{24}}
\__phosphoricons_def_icon:nnnnnn{\ppSmileyAngry}{smiley-angry}{"EC62}{{5}{33}}{{10}{64}}{{"EC63}{10}{65}}
\__phosphoricons_def_icon:nnnnnn{\ppSmileyBlank}{smiley-blank}{"E438}{{2}{13}}{{4}{25}}{{"E439}{4}{26}}
\__phosphoricons_def_icon:nnnnnn{\ppSmileyMeh}{smiley-meh}{"E43A}{{2}{14}}{{4}{27}}{{"E43B}{4}{28}}
\__phosphoricons_def_icon:nnnnnn{\ppSmileyMelting}{smiley-melting}{"EE56}{{5}{219}}{{11}{180}}{{"EE57}{11}{181}}
\__phosphoricons_def_icon:nnnnnn{\ppSmileyNervous}{smiley-nervous}{"E43C}{{2}{15}}{{4}{29}}{{"E43D}{4}{30}}
\__phosphoricons_def_icon:nnnnnn{\ppSmileySad}{smiley-sad}{"E43E}{{2}{16}}{{4}{31}}{{"E43F}{4}{32}}
\__phosphoricons_def_icon:nnnnnn{\ppSmileySticker}{smiley-sticker}{"E440}{{2}{17}}{{4}{33}}{{"E441}{4}{34}}
\__phosphoricons_def_icon:nnnnnn{\ppSmileyWink}{smiley-wink}{"E666}{{3}{31}}{{6}{60}}{{"E667}{6}{61}}
\__phosphoricons_def_icon:nnnnnn{\ppSmileyXEyes}{smiley-x-eyes}{"E442}{{2}{18}}{{4}{35}}{{"E443}{4}{36}}
\__phosphoricons_def_icon:nnnnnn{\ppSnapchatLogo}{snapchat-logo}{"E668}{{3}{32}}{{6}{62}}{{"E669}{6}{63}}
\__phosphoricons_def_icon:nnnnnn{\ppSneaker}{sneaker}{"E80C}{{3}{220}}{{7}{182}}{{"E80D}{7}{183}}
\__phosphoricons_def_icon:nnnnnn{\ppSneakerMove}{sneaker-move}{"ED60}{{5}{125}}{{10}{248}}{{"ED61}{10}{249}}
\__phosphoricons_def_icon:nnnnnn{\ppSnowflake}{snowflake}{"E5AA}{{2}{193}}{{5}{128}}{{"E5AB}{5}{129}}
\__phosphoricons_def_icon:nnnnnn{\ppSoccerBall}{soccer-ball}{"E716}{{3}{118}}{{6}{234}}{{"E717}{6}{235}}
\__phosphoricons_def_icon:nnnnnn{\ppSock}{sock}{"ECCE}{{5}{74}}{{10}{146}}{{"ECCF}{10}{147}}
\__phosphoricons_def_icon:nnnnnn{\ppSolarPanel}{solar-panel}{"ED7A}{{5}{135}}{{11}{12}}{{"ED7E}{11}{16}}
\__phosphoricons_def_icon:nnnnnn{\ppSolarRoof}{solar-roof}{"ED7B}{{5}{136}}{{11}{13}}{{"ED7F}{11}{17}}
\__phosphoricons_def_icon:nnnnnn{\ppSortAscending}{sort-ascending}{"E444}{{2}{19}}{{4}{37}}{{"E445}{4}{38}}
\__phosphoricons_def_icon:nnnnnn{\ppSortDescending}{sort-descending}{"E446}{{2}{20}}{{4}{39}}{{"E447}{4}{40}}
\__phosphoricons_def_icon:nnnnnn{\ppSoundcloudLogo}{soundcloud-logo}{"E8DE}{{4}{27}}{{8}{52}}{{"E8DF}{8}{53}}
\__phosphoricons_def_icon:nnnnnn{\ppSpade}{spade}{"E448}{{2}{21}}{{4}{41}}{{"E449}{4}{42}}
\__phosphoricons_def_icon:nnnnnn{\ppSparkle}{sparkle}{"E6A2}{{3}{61}}{{6}{120}}{{"E6A3}{6}{121}}
\__phosphoricons_def_icon:nnnnnn{\ppSpeakerHifi}{speaker-hifi}{"EA08}{{4}{98}}{{8}{194}}{{"EA09}{8}{195}}
\__phosphoricons_def_icon:nnnnnn{\ppSpeakerHigh}{speaker-high}{"E44A}{{2}{22}}{{4}{43}}{{"E44B}{4}{44}}
\__phosphoricons_def_icon:nnnnnn{\ppSpeakerLow}{speaker-low}{"E44C}{{2}{23}}{{4}{45}}{{"E44D}{4}{46}}
\__phosphoricons_def_icon:nnnnnn{\ppSpeakerNone}{speaker-none}{"E44E}{{2}{24}}{{4}{47}}{{"E44F}{4}{48}}
\__phosphoricons_def_icon:nnnnnn{\ppSpeakerSimpleHigh}{speaker-simple-high}{"E450}{{2}{25}}{{4}{49}}{{"E451}{4}{50}}
\__phosphoricons_def_icon:nnnnnn{\ppSpeakerSimpleLow}{speaker-simple-low}{"E452}{{2}{26}}{{4}{51}}{{"E453}{4}{52}}
\__phosphoricons_def_icon:nnnnnn{\ppSpeakerSimpleNone}{speaker-simple-none}{"E454}{{2}{27}}{{4}{53}}{{"E455}{4}{54}}
\__phosphoricons_def_icon:nnnnnn{\ppSpeakerSimpleSlash}{speaker-simple-slash}{"E456}{{2}{28}}{{4}{55}}{{"E457}{4}{56}}
\__phosphoricons_def_icon:nnnnnn{\ppSpeakerSimpleX}{speaker-simple-x}{"E458}{{2}{29}}{{4}{57}}{{"E459}{4}{58}}
\__phosphoricons_def_icon:nnnnnn{\ppSpeakerSlash}{speaker-slash}{"E45A}{{2}{30}}{{4}{59}}{{"E45B}{4}{60}}
\__phosphoricons_def_icon:nnnnnn{\ppSpeakerX}{speaker-x}{"E45C}{{2}{31}}{{4}{61}}{{"E45D}{4}{62}}
\__phosphoricons_def_icon:nnnnnn{\ppSpeedometer}{speedometer}{"EE74}{{5}{229}}{{11}{200}}{{"EE75}{11}{201}}
\__phosphoricons_def_icon:nnnnnn{\ppSphere}{sphere}{"EE66}{{5}{227}}{{11}{196}}{{"EE67}{11}{197}}
\__phosphoricons_def_icon:nnnnnn{\ppSpinner}{spinner}{"E66A}{{3}{33}}{{6}{64}}{{"E66B}{6}{65}}
\__phosphoricons_def_icon:nnnnnn{\ppSpinnerBall}{spinner-ball}{"EE28}{{5}{196}}{{11}{134}}{{"EE29}{11}{135}}
\__phosphoricons_def_icon:nnnnnn{\ppSpinnerGap}{spinner-gap}{"E66C}{{3}{34}}{{6}{66}}{{"E66D}{6}{67}}
\__phosphoricons_def_icon:nnnnnn{\ppSpiral}{spiral}{"E9FA}{{4}{93}}{{8}{184}}{{"E9FB}{8}{185}}
\__phosphoricons_def_icon:nnnnnn{\ppSplitHorizontal}{split-horizontal}{"E872}{{3}{250}}{{7}{242}}{{"E873}{7}{243}}
\__phosphoricons_def_icon:nnnnnn{\ppSplitVertical}{split-vertical}{"E876}{{3}{252}}{{7}{246}}{{"E877}{7}{247}}
\__phosphoricons_def_icon:nnnnnn{\ppSpotifyLogo}{spotify-logo}{"E66E}{{3}{35}}{{6}{68}}{{"E66F}{6}{69}}
\__phosphoricons_def_icon:nnnnnn{\ppSprayBottle}{spray-bottle}{"E7E4}{{3}{206}}{{7}{152}}{{"E7E8}{7}{156}}
\__phosphoricons_def_icon:nnnnnn{\ppSquare}{square}{"E45E}{{2}{32}}{{4}{63}}{{"E45F}{4}{64}}
\__phosphoricons_def_icon:nnnnnn{\ppSquareHalf}{square-half}{"E462}{{2}{33}}{{4}{65}}{{"E463}{4}{66}}
\__phosphoricons_def_icon:nnnnnn{\ppSquareHalfBottom}{square-half-bottom}{"EB16}{{4}{192}}{{9}{126}}{{"EB17}{9}{127}}
\__phosphoricons_def_icon:nnnnnn{\ppSquareLogo}{square-logo}{"E690}{{3}{52}}{{6}{102}}{{"E691}{6}{103}}
\__phosphoricons_def_icon:nnnnnn{\ppSquareSplitHorizontal}{square-split-horizontal}{"E870}{{3}{249}}{{7}{240}}{{"E871}{7}{241}}
\__phosphoricons_def_icon:nnnnnn{\ppSquareSplitVertical}{square-split-vertical}{"E874}{{3}{251}}{{7}{244}}{{"E875}{7}{245}}
\__phosphoricons_def_icon:nnnnnn{\ppSquaresFour}{squares-four}{"E464}{{2}{34}}{{4}{67}}{{"E465}{4}{68}}
\__phosphoricons_def_icon:nnnnnn{\ppStack}{stack}{"E466}{{2}{35}}{{4}{69}}{{"E467}{4}{70}}
\__phosphoricons_def_icon:nnnnnn{\ppStackMinus}{stack-minus}{"EDF4}{{5}{186}}{{11}{114}}{{"EDF5}{11}{115}}
\__phosphoricons_def_icon:nnnnnn{\ppStackOverflowLogo}{stack-overflow-logo}{"EB78}{{4}{236}}{{9}{214}}{{"EB79}{9}{215}}
\__phosphoricons_def_icon:nnnnnn{\ppStackPlus}{stack-plus}{"EDF6}{{5}{187}}{{11}{116}}{{"EDF7}{11}{117}}
\__phosphoricons_def_icon:nnnnnn{\ppStackSimple}{stack-simple}{"E468}{{2}{36}}{{4}{71}}{{"E469}{4}{72}}
\__phosphoricons_def_icon:nnnnnn{\ppStairs}{stairs}{"E8EC}{{4}{31}}{{8}{60}}{{"E8ED}{8}{61}}
\__phosphoricons_def_icon:nnnnnn{\ppStamp}{stamp}{"EA48}{{4}{121}}{{8}{240}}{{"EA49}{8}{241}}
\__phosphoricons_def_icon:nnnnnn{\ppStandardDefinition}{standard-definition}{"EA90}{{4}{143}}{{9}{28}}{{"EA91}{9}{29}}
\__phosphoricons_def_icon:nnnnnn{\ppStar}{star}{"E46A}{{2}{37}}{{4}{73}}{{"E46B}{4}{74}}
\__phosphoricons_def_icon:nnnnnn{\ppStarAndCrescent}{star-and-crescent}{"ECF4}{{5}{87}}{{10}{172}}{{"ECF5}{10}{173}}
\__phosphoricons_def_icon:nnnnnn{\ppStarFour}{star-four}{"E6A4}{{3}{62}}{{6}{122}}{{"E6A5}{6}{123}}
\__phosphoricons_def_icon:nnnnnn{\ppStarHalf}{star-half}{"E70A}{{3}{112}}{{6}{222}}{{"E70B}{6}{223}}
\__phosphoricons_def_icon:nnnnnn{\ppStarOfDavid}{star-of-david}{"E89E}{{4}{7}}{{8}{12}}{{"E89F}{8}{13}}
\__phosphoricons_def_icon:nnnnnn{\ppSteamLogo}{steam-logo}{"EAD4}{{4}{165}}{{9}{72}}{{"EAD5}{9}{73}}
\__phosphoricons_def_icon:nnnnnn{\ppSteeringWheel}{steering-wheel}{"E9AC}{{4}{69}}{{8}{136}}{{"E9AD}{8}{137}}
\__phosphoricons_def_icon:nnnnnn{\ppSteps}{steps}{"ECBE}{{5}{67}}{{10}{132}}{{"ECBF}{10}{133}}
\__phosphoricons_def_icon:nnnnnn{\ppStethoscope}{stethoscope}{"E7EA}{{3}{208}}{{7}{158}}{{"E7EB}{7}{159}}
\__phosphoricons_def_icon:nnnnnn{\ppSticker}{sticker}{"E5AC}{{2}{194}}{{5}{130}}{{"E5AD}{5}{131}}
\__phosphoricons_def_icon:nnnnnn{\ppStool}{stool}{"EA44}{{4}{119}}{{8}{236}}{{"EA45}{8}{237}}
\__phosphoricons_def_icon:nnnnnn{\ppStop}{stop}{"E46C}{{2}{38}}{{4}{75}}{{"E46D}{4}{76}}
\__phosphoricons_def_icon:nnnnnn{\ppStopCircle}{stop-circle}{"E46E}{{2}{39}}{{4}{77}}{{"E46F}{4}{78}}
\__phosphoricons_def_icon:nnnnnn{\ppStorefront}{storefront}{"E470}{{2}{40}}{{4}{79}}{{"E471}{4}{80}}
\__phosphoricons_def_icon:nnnnnn{\ppStrategy}{strategy}{"EA3A}{{4}{115}}{{8}{228}}{{"EA3B}{8}{229}}
\__phosphoricons_def_icon:nnnnnn{\ppStripeLogo}{stripe-logo}{"E698}{{3}{56}}{{6}{110}}{{"E699}{6}{111}}
\__phosphoricons_def_icon:nnnnnn{\ppStudent}{student}{"E73E}{{3}{137}}{{7}{16}}{{"E73F}{7}{17}}
\__phosphoricons_def_icon:nnnnnn{\ppSubsetOf}{subset-of}{"EDC0}{{5}{165}}{{11}{72}}{{"EDC1}{11}{73}}
\__phosphoricons_def_icon:nnnnnn{\ppSubsetProperOf}{subset-proper-of}{"EDB6}{{5}{160}}{{11}{62}}{{"EDB7}{11}{63}}
\__phosphoricons_def_icon:nnnnnn{\ppSubtitles}{subtitles}{"E1A8}{{0}{207}}{{1}{157}}{{"E1A9}{1}{158}}
\__phosphoricons_def_icon:nnnnnn{\ppSubtitlesSlash}{subtitles-slash}{"E1A6}{{0}{206}}{{1}{155}}{{"E1A7}{1}{156}}
\__phosphoricons_def_icon:nnnnnn{\ppSubtract}{subtract}{"EBD6}{{5}{5}}{{10}{8}}{{"EBD7}{10}{9}}
\__phosphoricons_def_icon:nnnnnn{\ppSubtractSquare}{subtract-square}{"EBD4}{{5}{4}}{{10}{6}}{{"EBD5}{10}{7}}
\__phosphoricons_def_icon:nnnnnn{\ppSubway}{subway}{"E498}{{2}{60}}{{4}{119}}{{"E499}{4}{120}}
\__phosphoricons_def_icon:nnnnnn{\ppSuitcase}{suitcase}{"E5AE}{{2}{195}}{{5}{132}}{{"E5AF}{5}{133}}
\__phosphoricons_def_icon:nnnnnn{\ppSuitcaseRolling}{suitcase-rolling}{"E9B0}{{4}{70}}{{8}{138}}{{"E9B1}{8}{139}}
\__phosphoricons_def_icon:nnnnnn{\ppSuitcaseSimple}{suitcase-simple}{"E5B0}{{2}{196}}{{5}{134}}{{"E5B1}{5}{135}}
\__phosphoricons_def_icon:nnnnnn{\ppSun}{sun}{"E472}{{2}{41}}{{4}{81}}{{"E473}{4}{82}}
\__phosphoricons_def_icon:nnnnnn{\ppSunDim}{sun-dim}{"E474}{{2}{42}}{{4}{83}}{{"E475}{4}{84}}
\__phosphoricons_def_icon:nnnnnn{\ppSunHorizon}{sun-horizon}{"E5B6}{{2}{199}}{{5}{140}}{{"E5B7}{5}{141}}
\__phosphoricons_def_icon:nnnnnn{\ppSunglasses}{sunglasses}{"E816}{{3}{224}}{{7}{190}}{{"E817}{7}{191}}
\__phosphoricons_def_icon:nnnnnn{\ppSupersetOf}{superset-of}{"EDB8}{{5}{161}}{{11}{64}}{{"EDB9}{11}{65}}
\__phosphoricons_def_icon:nnnnnn{\ppSupersetProperOf}{superset-proper-of}{"EDB4}{{5}{159}}{{11}{60}}{{"EDB5}{11}{61}}
\__phosphoricons_def_icon:nnnnnn{\ppSwap}{swap}{"E83C}{{3}{239}}{{7}{220}}{{"E83D}{7}{221}}
\__phosphoricons_def_icon:nnnnnn{\ppSwatches}{swatches}{"E5B8}{{2}{200}}{{5}{142}}{{"E5B9}{5}{143}}
\__phosphoricons_def_icon:nnnnnn{\ppSwimmingPool}{swimming-pool}{"ECB6}{{5}{63}}{{10}{124}}{{"ECB7}{10}{125}}
\__phosphoricons_def_icon:nnnnnn{\ppSword}{sword}{"E5BA}{{2}{201}}{{5}{144}}{{"E5BB}{5}{145}}
\__phosphoricons_def_icon:nnnnnn{\ppSynagogue}{synagogue}{"ECEC}{{5}{83}}{{10}{164}}{{"ECED}{10}{165}}
\__phosphoricons_def_icon:nnnnnn{\ppSyringe}{syringe}{"E968}{{4}{59}}{{8}{116}}{{"E969}{8}{117}}
\__phosphoricons_def_icon:nnnnnn{\ppTShirt}{t-shirt}{"E670}{{3}{36}}{{6}{70}}{{"E671}{6}{71}}
\__phosphoricons_def_icon:nnnnnn{\ppTable}{table}{"E476}{{2}{43}}{{4}{85}}{{"E477}{4}{86}}
\__phosphoricons_def_icon:nnnnnn{\ppTabs}{tabs}{"E778}{{3}{162}}{{7}{66}}{{"E779}{7}{67}}
\__phosphoricons_def_icon:nnnnnn{\ppTag}{tag}{"E478}{{2}{44}}{{4}{87}}{{"E479}{4}{88}}
\__phosphoricons_def_icon:nnnnnn{\ppTagChevron}{tag-chevron}{"E672}{{3}{37}}{{6}{72}}{{"E673}{6}{73}}
\__phosphoricons_def_icon:nnnnnn{\ppTagSimple}{tag-simple}{"E47A}{{2}{45}}{{4}{89}}{{"E47B}{4}{90}}
\__phosphoricons_def_icon:nnnnnn{\ppTarget}{target}{"E47C}{{2}{46}}{{4}{91}}{{"E47D}{4}{92}}
\__phosphoricons_def_icon:nnnnnn{\ppTaxi}{taxi}{"E902}{{4}{37}}{{8}{72}}{{"E903}{8}{73}}
\__phosphoricons_def_icon:nnnnnn{\ppTeaBag}{tea-bag}{"E8E6}{{4}{29}}{{8}{56}}{{"E8E7}{8}{57}}
\__phosphoricons_def_icon:nnnnnn{\ppTelegramLogo}{telegram-logo}{"E5BC}{{2}{202}}{{5}{146}}{{"E5BD}{5}{147}}
\__phosphoricons_def_icon:nnnnnn{\ppTelevision}{television}{"E754}{{3}{147}}{{7}{36}}{{"E755}{7}{37}}
\__phosphoricons_def_icon:nnnnnn{\ppTelevisionSimple}{television-simple}{"EAE6}{{4}{171}}{{9}{84}}{{"EAE7}{9}{85}}
\__phosphoricons_def_icon:nnnnnn{\ppTennisBall}{tennis-ball}{"E720}{{3}{123}}{{6}{244}}{{"E721}{6}{245}}
\__phosphoricons_def_icon:nnnnnn{\ppTent}{tent}{"E8BA}{{4}{14}}{{8}{26}}{{"E8BB}{8}{27}}
\__phosphoricons_def_icon:nnnnnn{\ppTerminal}{terminal}{"E47E}{{2}{47}}{{4}{93}}{{"E47F}{4}{94}}
\__phosphoricons_def_icon:nnnnnn{\ppTerminalWindow}{terminal-window}{"EAE8}{{4}{172}}{{9}{86}}{{"EAE9}{9}{87}}
\__phosphoricons_def_icon:nnnnnn{\ppTestTube}{test-tube}{"E7A0}{{3}{177}}{{7}{96}}{{"E7A1}{7}{97}}
\__phosphoricons_def_icon:nnnnnn{\ppTextAUnderline}{text-a-underline}{"ED34}{{5}{107}}{{10}{212}}{{"ED35}{10}{213}}
\__phosphoricons_def_icon:nnnnnn{\ppTextAa}{text-aa}{"E6EE}{{3}{98}}{{6}{194}}{{"E6EF}{6}{195}}
\__phosphoricons_def_icon:nnnnnn{\ppTextAlignCenter}{text-align-center}{"E480}{{2}{48}}{{4}{95}}{{"E481}{4}{96}}
\__phosphoricons_def_icon:nnnnnn{\ppTextAlignJustify}{text-align-justify}{"E482}{{2}{49}}{{4}{97}}{{"E483}{4}{98}}
\__phosphoricons_def_icon:nnnnnn{\ppTextAlignLeft}{text-align-left}{"E484}{{2}{50}}{{4}{99}}{{"E485}{4}{100}}
\__phosphoricons_def_icon:nnnnnn{\ppTextAlignRight}{text-align-right}{"E486}{{2}{51}}{{4}{101}}{{"E487}{4}{102}}
\__phosphoricons_def_icon:nnnnnn{\ppTextB}{text-b}{"E5BE}{{2}{203}}{{5}{148}}{{"E5BF}{5}{149}}
\__phosphoricons_def_icon:nnnnnn{\ppTextBolder}{text-bolder}{"E5BE}{{2}{203}}{{5}{148}}{{"E5BF}{5}{149}}
\__phosphoricons_def_icon:nnnnnn{\ppTextColumns}{text-columns}{"EC96}{{5}{52}}{{10}{102}}{{"EC97}{10}{103}}
\__phosphoricons_def_icon:nnnnnn{\ppTextH}{text-h}{"E6BA}{{3}{72}}{{6}{142}}{{"E6BB}{6}{143}}
\__phosphoricons_def_icon:nnnnnn{\ppTextHFive}{text-h-five}{"E6C4}{{3}{77}}{{6}{152}}{{"E6C5}{6}{153}}
\__phosphoricons_def_icon:nnnnnn{\ppTextHFour}{text-h-four}{"E6C2}{{3}{76}}{{6}{150}}{{"E6C3}{6}{151}}
\__phosphoricons_def_icon:nnnnnn{\ppTextHOne}{text-h-one}{"E6BC}{{3}{73}}{{6}{144}}{{"E6BD}{6}{145}}
\__phosphoricons_def_icon:nnnnnn{\ppTextHSix}{text-h-six}{"E6C6}{{3}{78}}{{6}{154}}{{"E6C7}{6}{155}}
\__phosphoricons_def_icon:nnnnnn{\ppTextHThree}{text-h-three}{"E6C0}{{3}{75}}{{6}{148}}{{"E6C1}{6}{149}}
\__phosphoricons_def_icon:nnnnnn{\ppTextHTwo}{text-h-two}{"E6BE}{{3}{74}}{{6}{146}}{{"E6BF}{6}{147}}
\__phosphoricons_def_icon:nnnnnn{\ppTextIndent}{text-indent}{"EA1E}{{4}{104}}{{8}{206}}{{"EA1F}{8}{207}}
\__phosphoricons_def_icon:nnnnnn{\ppTextItalic}{text-italic}{"E5C0}{{2}{204}}{{5}{150}}{{"E5C1}{5}{151}}
\__phosphoricons_def_icon:nnnnnn{\ppTextOutdent}{text-outdent}{"EA1C}{{4}{103}}{{8}{204}}{{"EA1D}{8}{205}}
\__phosphoricons_def_icon:nnnnnn{\ppTextStrikethrough}{text-strikethrough}{"E5C2}{{2}{205}}{{5}{152}}{{"E5C3}{5}{153}}
\__phosphoricons_def_icon:nnnnnn{\ppTextSubscript}{text-subscript}{"EC98}{{5}{53}}{{10}{104}}{{"EC99}{10}{105}}
\__phosphoricons_def_icon:nnnnnn{\ppTextSuperscript}{text-superscript}{"EC9A}{{5}{54}}{{10}{106}}{{"EC9B}{10}{107}}
\__phosphoricons_def_icon:nnnnnn{\ppTextT}{text-t}{"E48A}{{2}{53}}{{4}{105}}{{"E48B}{4}{106}}
\__phosphoricons_def_icon:nnnnnn{\ppTextTSlash}{text-t-slash}{"E488}{{2}{52}}{{4}{103}}{{"E489}{4}{104}}
\__phosphoricons_def_icon:nnnnnn{\ppTextUnderline}{text-underline}{"E5C4}{{2}{206}}{{5}{154}}{{"E5C5}{5}{155}}
\__phosphoricons_def_icon:nnnnnn{\ppTextbox}{textbox}{"EB0A}{{4}{186}}{{9}{114}}{{"EB0B}{9}{115}}
\__phosphoricons_def_icon:nnnnnn{\ppThermometer}{thermometer}{"E5C6}{{2}{207}}{{5}{156}}{{"E5C7}{5}{157}}
\__phosphoricons_def_icon:nnnnnn{\ppThermometerCold}{thermometer-cold}{"E5C8}{{2}{208}}{{5}{158}}{{"E5C9}{5}{159}}
\__phosphoricons_def_icon:nnnnnn{\ppThermometerHot}{thermometer-hot}{"E5CA}{{2}{209}}{{5}{160}}{{"E5CB}{5}{161}}
\__phosphoricons_def_icon:nnnnnn{\ppThermometerSimple}{thermometer-simple}{"E5CC}{{2}{210}}{{5}{162}}{{"E5CD}{5}{163}}
\__phosphoricons_def_icon:nnnnnn{\ppThreadsLogo}{threads-logo}{"ED9E}{{5}{148}}{{11}{38}}{{"ED9F}{11}{39}}
\__phosphoricons_def_icon:nnnnnn{\ppThreeD}{three-d}{"EA5A}{{4}{125}}{{8}{248}}{{"EA5B}{8}{249}}
\__phosphoricons_def_icon:nnnnnn{\ppThumbsDown}{thumbs-down}{"E48C}{{2}{54}}{{4}{107}}{{"E48D}{4}{108}}
\__phosphoricons_def_icon:nnnnnn{\ppThumbsUp}{thumbs-up}{"E48E}{{2}{55}}{{4}{109}}{{"E48F}{4}{110}}
\__phosphoricons_def_icon:nnnnnn{\ppTicket}{ticket}{"E490}{{2}{56}}{{4}{111}}{{"E491}{4}{112}}
\__phosphoricons_def_icon:nnnnnn{\ppTidalLogo}{tidal-logo}{"ED1C}{{5}{101}}{{10}{200}}{{"ED1D}{10}{201}}
\__phosphoricons_def_icon:nnnnnn{\ppTiktokLogo}{tiktok-logo}{"EAF2}{{4}{175}}{{9}{92}}{{"EAF3}{9}{93}}
\__phosphoricons_def_icon:nnnnnn{\ppTilde}{tilde}{"EDA8}{{5}{153}}{{11}{48}}{{"EDA9}{11}{49}}
\__phosphoricons_def_icon:nnnnnn{\ppTimer}{timer}{"E492}{{2}{57}}{{4}{113}}{{"E493}{4}{114}}
\__phosphoricons_def_icon:nnnnnn{\ppTipJar}{tip-jar}{"E7E2}{{3}{205}}{{7}{150}}{{"E7E9}{7}{157}}
\__phosphoricons_def_icon:nnnnnn{\ppTipi}{tipi}{"ED30}{{5}{105}}{{10}{208}}{{"ED31}{10}{209}}
\__phosphoricons_def_icon:nnnnnn{\ppTire}{tire}{"EDD2}{{5}{172}}{{11}{86}}{{"EDD3}{11}{87}}
\__phosphoricons_def_icon:nnnnnn{\ppToggleLeft}{toggle-left}{"E674}{{3}{38}}{{6}{74}}{{"E675}{6}{75}}
\__phosphoricons_def_icon:nnnnnn{\ppToggleRight}{toggle-right}{"E676}{{3}{39}}{{6}{76}}{{"E677}{6}{77}}
\__phosphoricons_def_icon:nnnnnn{\ppToilet}{toilet}{"E79A}{{3}{174}}{{7}{90}}{{"E79B}{7}{91}}
\__phosphoricons_def_icon:nnnnnn{\ppToiletPaper}{toilet-paper}{"E79C}{{3}{175}}{{7}{92}}{{"E79D}{7}{93}}
\__phosphoricons_def_icon:nnnnnn{\ppToolbox}{toolbox}{"ECA0}{{5}{55}}{{10}{108}}{{"ECA1}{10}{109}}
\__phosphoricons_def_icon:nnnnnn{\ppTooth}{tooth}{"E9CC}{{4}{78}}{{8}{154}}{{"E9CD}{8}{155}}
\__phosphoricons_def_icon:nnnnnn{\ppTornado}{tornado}{"E88C}{{4}{3}}{{8}{4}}{{"E88D}{8}{5}}
\__phosphoricons_def_icon:nnnnnn{\ppTote}{tote}{"E494}{{2}{58}}{{4}{115}}{{"E495}{4}{116}}
\__phosphoricons_def_icon:nnnnnn{\ppToteSimple}{tote-simple}{"E678}{{3}{40}}{{6}{78}}{{"E679}{6}{79}}
\__phosphoricons_def_icon:nnnnnn{\ppTowel}{towel}{"EDE6}{{5}{181}}{{11}{104}}{{"EDE7}{11}{105}}
\__phosphoricons_def_icon:nnnnnn{\ppTractor}{tractor}{"EC6E}{{5}{37}}{{10}{72}}{{"EC6F}{10}{73}}
\__phosphoricons_def_icon:nnnnnn{\ppTrademark}{trademark}{"E9F0}{{4}{88}}{{8}{174}}{{"E9F1}{8}{175}}
\__phosphoricons_def_icon:nnnnnn{\ppTrademarkRegistered}{trademark-registered}{"E3F4}{{1}{238}}{{3}{217}}{{"E415}{3}{250}}
\__phosphoricons_def_icon:nnnnnn{\ppTrafficCone}{traffic-cone}{"E9A8}{{4}{67}}{{8}{132}}{{"E9A9}{8}{133}}
\__phosphoricons_def_icon:nnnnnn{\ppTrafficSign}{traffic-sign}{"E67A}{{3}{41}}{{6}{80}}{{"E67B}{6}{81}}
\__phosphoricons_def_icon:nnnnnn{\ppTrafficSignal}{traffic-signal}{"E9AA}{{4}{68}}{{8}{134}}{{"E9AB}{8}{135}}
\__phosphoricons_def_icon:nnnnnn{\ppTrain}{train}{"E496}{{2}{59}}{{4}{117}}{{"E497}{4}{118}}
\__phosphoricons_def_icon:nnnnnn{\ppTrainRegional}{train-regional}{"E49E}{{2}{62}}{{4}{123}}{{"E49F}{4}{124}}
\__phosphoricons_def_icon:nnnnnn{\ppTrainSimple}{train-simple}{"E4A0}{{2}{63}}{{4}{125}}{{"E4A1}{4}{126}}
\__phosphoricons_def_icon:nnnnnn{\ppTram}{tram}{"E9EC}{{4}{87}}{{8}{172}}{{"E9ED}{8}{173}}
\__phosphoricons_def_icon:nnnnnn{\ppTranslate}{translate}{"E4A2}{{2}{64}}{{4}{127}}{{"E4A3}{4}{128}}
\__phosphoricons_def_icon:nnnnnn{\ppTrash}{trash}{"E4A6}{{2}{65}}{{4}{129}}{{"E4A7}{4}{130}}
\__phosphoricons_def_icon:nnnnnn{\ppTrashSimple}{trash-simple}{"E4A8}{{2}{66}}{{4}{131}}{{"E4A9}{4}{132}}
\__phosphoricons_def_icon:nnnnnn{\ppTray}{tray}{"E4AA}{{2}{67}}{{4}{133}}{{"E4AB}{4}{134}}
\__phosphoricons_def_icon:nnnnnn{\ppTrayArrowDown}{tray-arrow-down}{"E010}{{0}{8}}{{0}{16}}{{"E011}{0}{17}}
\__phosphoricons_def_icon:nnnnnn{\ppTrayArrowUp}{tray-arrow-up}{"EE52}{{5}{217}}{{11}{176}}{{"EE53}{11}{177}}
\__phosphoricons_def_icon:nnnnnn{\ppTreasureChest}{treasure-chest}{"EDE2}{{5}{180}}{{11}{102}}{{"EDE3}{11}{103}}
\__phosphoricons_def_icon:nnnnnn{\ppTree}{tree}{"E6DA}{{3}{88}}{{6}{174}}{{"E6DB}{6}{175}}
\__phosphoricons_def_icon:nnnnnn{\ppTreeEvergreen}{tree-evergreen}{"E6DC}{{3}{89}}{{6}{176}}{{"E6DD}{6}{177}}
\__phosphoricons_def_icon:nnnnnn{\ppTreePalm}{tree-palm}{"E91A}{{4}{42}}{{8}{82}}{{"E91B}{8}{83}}
\__phosphoricons_def_icon:nnnnnn{\ppTreeStructure}{tree-structure}{"E67C}{{3}{42}}{{6}{82}}{{"E67D}{6}{83}}
\__phosphoricons_def_icon:nnnnnn{\ppTreeView}{tree-view}{"EE48}{{5}{212}}{{11}{166}}{{"EE49}{11}{167}}
\__phosphoricons_def_icon:nnnnnn{\ppTrendDown}{trend-down}{"E4AC}{{2}{68}}{{4}{135}}{{"E4AD}{4}{136}}
\__phosphoricons_def_icon:nnnnnn{\ppTrendUp}{trend-up}{"E4AE}{{2}{69}}{{4}{137}}{{"E4AF}{4}{138}}
\__phosphoricons_def_icon:nnnnnn{\ppTriangle}{triangle}{"E4B0}{{2}{70}}{{4}{139}}{{"E4B1}{4}{140}}
\__phosphoricons_def_icon:nnnnnn{\ppTriangleDashed}{triangle-dashed}{"E4B2}{{2}{71}}{{4}{141}}{{"E4B3}{4}{142}}
\__phosphoricons_def_icon:nnnnnn{\ppTrolley}{trolley}{"E5B2}{{2}{197}}{{5}{136}}{{"E5B3}{5}{137}}
\__phosphoricons_def_icon:nnnnnn{\ppTrolleySuitcase}{trolley-suitcase}{"E5B4}{{2}{198}}{{5}{138}}{{"E5B5}{5}{139}}
\__phosphoricons_def_icon:nnnnnn{\ppTrophy}{trophy}{"E67E}{{3}{43}}{{6}{84}}{{"E67F}{6}{85}}
\__phosphoricons_def_icon:nnnnnn{\ppTruck}{truck}{"E4B4}{{2}{72}}{{4}{143}}{{"E4B5}{4}{144}}
\__phosphoricons_def_icon:nnnnnn{\ppTruckTrailer}{truck-trailer}{"E4B6}{{2}{73}}{{4}{145}}{{"E4B7}{4}{146}}
\__phosphoricons_def_icon:nnnnnn{\ppTumblrLogo}{tumblr-logo}{"E8D4}{{4}{25}}{{8}{48}}{{"E8D5}{8}{49}}
\__phosphoricons_def_icon:nnnnnn{\ppTwitchLogo}{twitch-logo}{"E5CE}{{2}{211}}{{5}{164}}{{"E5CF}{5}{165}}
\__phosphoricons_def_icon:nnnnnn{\ppTwitterLogo}{twitter-logo}{"E4BA}{{2}{74}}{{4}{147}}{{"E4BB}{4}{148}}
\__phosphoricons_def_icon:nnnnnn{\ppUmbrella}{umbrella}{"E684}{{3}{46}}{{6}{90}}{{"E685}{6}{91}}
\__phosphoricons_def_icon:nnnnnn{\ppUmbrellaSimple}{umbrella-simple}{"E686}{{3}{47}}{{6}{92}}{{"E687}{6}{93}}
\__phosphoricons_def_icon:nnnnnn{\ppUnion}{union}{"EDBE}{{5}{164}}{{11}{70}}{{"EDBF}{11}{71}}
\__phosphoricons_def_icon:nnnnnn{\ppUnite}{unite}{"E87E}{{4}{0}}{{7}{254}}{{"E87F}{7}{255}}
\__phosphoricons_def_icon:nnnnnn{\ppUniteSquare}{unite-square}{"E878}{{3}{253}}{{7}{248}}{{"E879}{7}{249}}
\__phosphoricons_def_icon:nnnnnn{\ppUpload}{upload}{"E4BE}{{2}{76}}{{4}{151}}{{"E4BF}{4}{152}}
\__phosphoricons_def_icon:nnnnnn{\ppUploadSimple}{upload-simple}{"E4C0}{{2}{77}}{{4}{153}}{{"E4C1}{4}{154}}
\__phosphoricons_def_icon:nnnnnn{\ppUsb}{usb}{"E956}{{4}{52}}{{8}{102}}{{"E957}{8}{103}}
\__phosphoricons_def_icon:nnnnnn{\ppUser}{user}{"E4C2}{{2}{78}}{{4}{155}}{{"E4C3}{4}{156}}
\__phosphoricons_def_icon:nnnnnn{\ppUserCheck}{user-check}{"EAFA}{{4}{179}}{{9}{100}}{{"EAFB}{9}{101}}
\__phosphoricons_def_icon:nnnnnn{\ppUserCircle}{user-circle}{"E4C4}{{2}{79}}{{4}{157}}{{"E4C5}{4}{158}}
\__phosphoricons_def_icon:nnnnnn{\ppUserCircleCheck}{user-circle-check}{"EC38}{{5}{23}}{{10}{44}}{{"EC39}{10}{45}}
\__phosphoricons_def_icon:nnnnnn{\ppUserCircleDashed}{user-circle-dashed}{"EC36}{{5}{22}}{{10}{42}}{{"EC37}{10}{43}}
\__phosphoricons_def_icon:nnnnnn{\ppUserCircleGear}{user-circle-gear}{"E4C6}{{2}{80}}{{4}{159}}{{"E4C7}{4}{160}}
\__phosphoricons_def_icon:nnnnnn{\ppUserCircleMinus}{user-circle-minus}{"E4C8}{{2}{81}}{{4}{161}}{{"E4C9}{4}{162}}
\__phosphoricons_def_icon:nnnnnn{\ppUserCirclePlus}{user-circle-plus}{"E4CA}{{2}{82}}{{4}{163}}{{"E4CB}{4}{164}}
\__phosphoricons_def_icon:nnnnnn{\ppUserFocus}{user-focus}{"E6FC}{{3}{105}}{{6}{208}}{{"E6FD}{6}{209}}
\__phosphoricons_def_icon:nnnnnn{\ppUserGear}{user-gear}{"E4CC}{{2}{83}}{{4}{165}}{{"E4CD}{4}{166}}
\__phosphoricons_def_icon:nnnnnn{\ppUserList}{user-list}{"E73C}{{3}{136}}{{7}{14}}{{"E73D}{7}{15}}
\__phosphoricons_def_icon:nnnnnn{\ppUserMinus}{user-minus}{"E4CE}{{2}{84}}{{4}{167}}{{"E4CF}{4}{168}}
\__phosphoricons_def_icon:nnnnnn{\ppUserPlus}{user-plus}{"E4D0}{{2}{85}}{{4}{169}}{{"E4D1}{4}{170}}
\__phosphoricons_def_icon:nnnnnn{\ppUserRectangle}{user-rectangle}{"E4D2}{{2}{86}}{{4}{171}}{{"E4D3}{4}{172}}
\__phosphoricons_def_icon:nnnnnn{\ppUserSound}{user-sound}{"ECA8}{{5}{58}}{{10}{114}}{{"ECA9}{10}{115}}
\__phosphoricons_def_icon:nnnnnn{\ppUserSquare}{user-square}{"E4D4}{{2}{87}}{{4}{173}}{{"E4D5}{4}{174}}
\__phosphoricons_def_icon:nnnnnn{\ppUserSwitch}{user-switch}{"E756}{{3}{148}}{{7}{38}}{{"E757}{7}{39}}
\__phosphoricons_def_icon:nnnnnn{\ppUsers}{users}{"E4D6}{{2}{88}}{{4}{175}}{{"E4D7}{4}{176}}
\__phosphoricons_def_icon:nnnnnn{\ppUsersFour}{users-four}{"E68C}{{3}{50}}{{6}{98}}{{"E68D}{6}{99}}
\__phosphoricons_def_icon:nnnnnn{\ppUsersThree}{users-three}{"E68E}{{3}{51}}{{6}{100}}{{"E68F}{6}{101}}
\__phosphoricons_def_icon:nnnnnn{\ppVan}{van}{"E826}{{3}{232}}{{7}{206}}{{"E827}{7}{207}}
\__phosphoricons_def_icon:nnnnnn{\ppVault}{vault}{"E76E}{{3}{159}}{{7}{60}}{{"E76F}{7}{61}}
\__phosphoricons_def_icon:nnnnnn{\ppVectorThree}{vector-three}{"EE62}{{5}{225}}{{11}{192}}{{"EE63}{11}{193}}
\__phosphoricons_def_icon:nnnnnn{\ppVectorTwo}{vector-two}{"EE64}{{5}{226}}{{11}{194}}{{"EE65}{11}{195}}
\__phosphoricons_def_icon:nnnnnn{\ppVibrate}{vibrate}{"E4D8}{{2}{89}}{{4}{177}}{{"E4D9}{4}{178}}
\__phosphoricons_def_icon:nnnnnn{\ppVideo}{video}{"E740}{{3}{138}}{{7}{18}}{{"E741}{7}{19}}
\__phosphoricons_def_icon:nnnnnn{\ppVideoCamera}{video-camera}{"E4DA}{{2}{90}}{{4}{179}}{{"E4DB}{4}{180}}
\__phosphoricons_def_icon:nnnnnn{\ppVideoCameraSlash}{video-camera-slash}{"E4DC}{{2}{91}}{{4}{181}}{{"E4DD}{4}{182}}
\__phosphoricons_def_icon:nnnnnn{\ppVideoConference}{video-conference}{"EDCE}{{5}{170}}{{11}{82}}{{"EDCF}{11}{83}}
\__phosphoricons_def_icon:nnnnnn{\ppVignette}{vignette}{"EBA2}{{4}{249}}{{9}{240}}{{"EBA3}{9}{241}}
\__phosphoricons_def_icon:nnnnnn{\ppVinylRecord}{vinyl-record}{"ECAC}{{5}{59}}{{10}{116}}{{"ECAD}{10}{117}}
\__phosphoricons_def_icon:nnnnnn{\ppVirtualReality}{virtual-reality}{"E7B8}{{3}{186}}{{7}{114}}{{"E7B9}{7}{115}}
\__phosphoricons_def_icon:nnnnnn{\ppVirus}{virus}{"E7D6}{{3}{200}}{{7}{142}}{{"E7D7}{7}{143}}
\__phosphoricons_def_icon:nnnnnn{\ppVisor}{visor}{"EE2A}{{5}{197}}{{11}{136}}{{"EE2B}{11}{137}}
\__phosphoricons_def_icon:nnnnnn{\ppVoicemail}{voicemail}{"E4DE}{{2}{92}}{{4}{183}}{{"E4DF}{4}{184}}
\__phosphoricons_def_icon:nnnnnn{\ppVolleyball}{volleyball}{"E726}{{3}{126}}{{6}{250}}{{"E727}{6}{251}}
\__phosphoricons_def_icon:nnnnnn{\ppWall}{wall}{"E688}{{3}{48}}{{6}{94}}{{"E689}{6}{95}}
\__phosphoricons_def_icon:nnnnnn{\ppWallet}{wallet}{"E68A}{{3}{49}}{{6}{96}}{{"E68B}{6}{97}}
\__phosphoricons_def_icon:nnnnnn{\ppWarehouse}{warehouse}{"ECD4}{{5}{76}}{{10}{150}}{{"ECD5}{10}{151}}
\__phosphoricons_def_icon:nnnnnn{\ppWarning}{warning}{"E4E0}{{2}{93}}{{4}{185}}{{"E4E1}{4}{186}}
\__phosphoricons_def_icon:nnnnnn{\ppWarningCircle}{warning-circle}{"E4E2}{{2}{94}}{{4}{187}}{{"E4E3}{4}{188}}
\__phosphoricons_def_icon:nnnnnn{\ppWarningDiamond}{warning-diamond}{"E7FC}{{3}{212}}{{7}{166}}{{"E7FD}{7}{167}}
\__phosphoricons_def_icon:nnnnnn{\ppWarningOctagon}{warning-octagon}{"E4E4}{{2}{95}}{{4}{189}}{{"E4E5}{4}{190}}
\__phosphoricons_def_icon:nnnnnn{\ppWashingMachine}{washing-machine}{"EDE8}{{5}{182}}{{11}{106}}{{"EDE9}{11}{107}}
\__phosphoricons_def_icon:nnnnnn{\ppWatch}{watch}{"E4E6}{{2}{96}}{{4}{191}}{{"E4E7}{4}{192}}
\__phosphoricons_def_icon:nnnnnn{\ppWaveSawtooth}{wave-sawtooth}{"EA9C}{{4}{148}}{{9}{38}}{{"EA9D}{9}{39}}
\__phosphoricons_def_icon:nnnnnn{\ppWaveSine}{wave-sine}{"EA9A}{{4}{147}}{{9}{36}}{{"EA9B}{9}{37}}
\__phosphoricons_def_icon:nnnnnn{\ppWaveSquare}{wave-square}{"EA9E}{{4}{149}}{{9}{40}}{{"EA9F}{9}{41}}
\__phosphoricons_def_icon:nnnnnn{\ppWaveTriangle}{wave-triangle}{"EAA0}{{4}{150}}{{9}{42}}{{"EAA1}{9}{43}}
\__phosphoricons_def_icon:nnnnnn{\ppWaveform}{waveform}{"E802}{{3}{215}}{{7}{172}}{{"E803}{7}{173}}
\__phosphoricons_def_icon:nnnnnn{\ppWaveformSlash}{waveform-slash}{"E800}{{3}{214}}{{7}{170}}{{"E801}{7}{171}}
\__phosphoricons_def_icon:nnnnnn{\ppWaves}{waves}{"E6DE}{{3}{90}}{{6}{178}}{{"E6DF}{6}{179}}
\__phosphoricons_def_icon:nnnnnn{\ppWebcam}{webcam}{"E9B2}{{4}{71}}{{8}{140}}{{"E9B3}{8}{141}}
\__phosphoricons_def_icon:nnnnnn{\ppWebcamSlash}{webcam-slash}{"ECDC}{{5}{79}}{{10}{156}}{{"ECDD}{10}{157}}
\__phosphoricons_def_icon:nnnnnn{\ppWebhooksLogo}{webhooks-logo}{"ECAE}{{5}{60}}{{10}{118}}{{"ECAF}{10}{119}}
\__phosphoricons_def_icon:nnnnnn{\ppWechatLogo}{wechat-logo}{"E8D2}{{4}{24}}{{8}{46}}{{"E8D3}{8}{47}}
\__phosphoricons_def_icon:nnnnnn{\ppWhatsappLogo}{whatsapp-logo}{"E5D0}{{2}{212}}{{5}{166}}{{"E5D1}{5}{167}}
\__phosphoricons_def_icon:nnnnnn{\ppWheelchair}{wheelchair}{"E4E8}{{2}{97}}{{4}{193}}{{"E4E9}{4}{194}}
\__phosphoricons_def_icon:nnnnnn{\ppWheelchairMotion}{wheelchair-motion}{"E89A}{{4}{5}}{{8}{8}}{{"E89B}{8}{9}}
\__phosphoricons_def_icon:nnnnnn{\ppWifiHigh}{wifi-high}{"E4EA}{{2}{98}}{{4}{195}}{{"E4EB}{4}{196}}
\__phosphoricons_def_icon:nnnnnn{\ppWifiLow}{wifi-low}{"E4EC}{{2}{99}}{{4}{197}}{{"E4ED}{4}{198}}
\__phosphoricons_def_icon:nnnnnn{\ppWifiMedium}{wifi-medium}{"E4EE}{{2}{100}}{{4}{199}}{{"E4EF}{4}{200}}
\__phosphoricons_def_icon:nnnnnn{\ppWifiNone}{wifi-none}{"E4F0}{{2}{101}}{{4}{201}}{}
\__phosphoricons_def_icon:nnnnnn{\ppWifiSlash}{wifi-slash}{"E4F2}{{2}{102}}{{4}{202}}{{"E4F3}{4}{203}}
\__phosphoricons_def_icon:nnnnnn{\ppWifiX}{wifi-x}{"E4F4}{{2}{103}}{{4}{204}}{{"E4F5}{4}{205}}
\__phosphoricons_def_icon:nnnnnn{\ppWind}{wind}{"E5D2}{{2}{213}}{{5}{168}}{{"E5D3}{5}{169}}
\__phosphoricons_def_icon:nnnnnn{\ppWindmill}{windmill}{"E9F8}{{4}{92}}{{8}{182}}{{"E9F9}{8}{183}}
\__phosphoricons_def_icon:nnnnnn{\ppWindowsLogo}{windows-logo}{"E692}{{3}{53}}{{6}{104}}{{"E693}{6}{105}}
\__phosphoricons_def_icon:nnnnnn{\ppWine}{wine}{"E6B2}{{3}{68}}{{6}{134}}{{"E6B3}{6}{135}}
\__phosphoricons_def_icon:nnnnnn{\ppWrench}{wrench}{"E5D4}{{2}{214}}{{5}{170}}{{"E5D5}{5}{171}}
\__phosphoricons_def_icon:nnnnnn{\ppX}{x}{"E4F6}{{2}{104}}{{4}{206}}{{"E4F7}{4}{207}}
\__phosphoricons_def_icon:nnnnnn{\ppXCircle}{x-circle}{"E4F8}{{2}{105}}{{4}{208}}{{"E4F9}{4}{209}}
\__phosphoricons_def_icon:nnnnnn{\ppXLogo}{x-logo}{"E4BC}{{2}{75}}{{4}{149}}{{"E4BD}{4}{150}}
\__phosphoricons_def_icon:nnnnnn{\ppXSquare}{x-square}{"E4FA}{{2}{106}}{{4}{210}}{{"E4FB}{4}{211}}
\__phosphoricons_def_icon:nnnnnn{\ppYarn}{yarn}{"ED9A}{{5}{147}}{{11}{36}}{{"ED9B}{11}{37}}
\__phosphoricons_def_icon:nnnnnn{\ppYinYang}{yin-yang}{"E92A}{{4}{45}}{{8}{88}}{{"E92B}{8}{89}}
\__phosphoricons_def_icon:nnnnnn{\ppYoutubeLogo}{youtube-logo}{"E4FC}{{2}{107}}{{4}{212}}{{"E4FD}{4}{213}}
